@@ -16,8 +16,8 @@
 # First argument ($1) expects 'multibackend' as value for setting appropriate
 # tempest conf opts, all other values will assume singlebackend installation.
 
-sudo chown -R $USER:stack $BASE/new/tempest
-sudo chown -R $USER:stack $BASE/data/tempest
+sudo chown -R jenkins:stack $BASE/new/tempest
+sudo chown -R jenkins:stack $BASE/data/tempest
 sudo chmod -R o+rx $BASE/new/devstack/files
 
 # Import devstack functions 'iniset', 'iniget' and 'trueorfalse'
@@ -70,10 +70,7 @@ RUN_MANILA_QUOTA_TESTS=${RUN_MANILA_QUOTA_TESTS:-True}
 RUN_MANILA_SHRINK_TESTS=${RUN_MANILA_SHRINK_TESTS:-True}
 RUN_MANILA_SNAPSHOT_TESTS=${RUN_MANILA_SNAPSHOT_TESTS:-True}
 RUN_MANILA_REVERT_TO_SNAPSHOT_TESTS=${RUN_MANILA_REVERT_TO_SNAPSHOT_TESTS:-False}
-
-# TODO(vponomaryov): turn 'RUN_MANILA_SG_TESTS' on back in Pike
-# RUN_MANILA_SG_TESTS=${RUN_MANILA_SG_TESTS:-${RUN_MANILA_CG_TESTS:-True}}
-RUN_MANILA_SG_TESTS=False
+RUN_MANILA_SG_TESTS=${RUN_MANILA_SG_TESTS:-${RUN_MANILA_CG_TESTS:-True}}
 RUN_MANILA_MANAGE_TESTS=${RUN_MANILA_MANAGE_TESTS:-True}
 RUN_MANILA_MANAGE_SNAPSHOT_TESTS=${RUN_MANILA_MANAGE_SNAPSHOT_TESTS:-False}
 RUN_MANILA_REPLICATION_TESTS=${RUN_MANILA_REPLICATION_TESTS:-False}
@@ -143,12 +140,7 @@ cd $BASE/new/tempest
 export MANILA_TEMPEST_CONCURRENCY=${MANILA_TEMPEST_CONCURRENCY:-6}
 export MANILA_TESTS=${MANILA_TESTS:-'manila_tempest_tests.tests.api'}
 
-if [[ "$TEST_TYPE" == "scenario" ]]; then
-    echo "Set test set to scenario only"
-    MANILA_TESTS='manila_tempest_tests.tests.scenario'
-    iniset $TEMPEST_CONFIG auth use_dynamic_credentials True
-    RUN_MANILA_HOST_ASSISTED_MIGRATION_TESTS=True
-elif [[ "$DRIVER" == "generic" ]]; then
+if [[ "$DRIVER" == "generic"* ]]; then
     RUN_MANILA_HOST_ASSISTED_MIGRATION_TESTS=True
     RUN_MANILA_MANAGE_SNAPSHOT_TESTS=True
     RUN_MANILA_CG_TESTS=False
@@ -165,6 +157,18 @@ elif [[ "$DRIVER" == "generic" ]]; then
     RUN_MANILA_SG_TESTS=False
 fi
 
+if [[ "$DRIVER" == "generic_with_custom_image" ]]; then
+    # For CI jobs that test changes to image we do not need to run lots of tests
+    # Will be enough to run simple scenario test, because
+    # if some package is lost, it is very likely to fail with each test.
+    MANILA_TESTS="(^manila_tempest_tests.tests.scenario)(?=.*\btest_write_data_to_share_created_from_snapshot\b.*)"
+elif [[ "$TEST_TYPE" == "scenario" ]]; then
+    echo "Set test set to scenario only"
+    MANILA_TESTS='manila_tempest_tests.tests.scenario'
+    iniset $TEMPEST_CONFIG auth use_dynamic_credentials True
+    RUN_MANILA_HOST_ASSISTED_MIGRATION_TESTS=True
+fi
+
 if [[ "$DRIVER" == "lvm" ]]; then
     MANILA_TESTS="(^manila_tempest_tests.tests)(?=.*\[.*\bbackend\b.*\])"
     MANILA_TEMPEST_CONCURRENCY=8
@@ -215,9 +219,7 @@ elif [[ "$DRIVER" == "zfsonlinux" ]]; then
     iniset $TEMPEST_CONFIG share capability_snapshot_support True
 elif [[ "$DRIVER" == "dummy" ]]; then
     MANILA_TEMPEST_CONCURRENCY=24
-
-    # TODO(vponomaryov): turn 'RUN_MANILA_SG_TESTS' on back in Pike
-    RUN_MANILA_SG_TESTS=False
+    RUN_MANILA_SG_TESTS=True
     RUN_MANILA_MANAGE_TESTS=False
     RUN_MANILA_DRIVER_ASSISTED_MIGRATION_TESTS=True
     RUN_MANILA_REVERT_TO_SNAPSHOT_TESTS=True
@@ -230,24 +232,36 @@ elif [[ "$DRIVER" == "dummy" ]]; then
     iniset $TEMPEST_CONFIG share build_timeout 180
     iniset $TEMPEST_CONFIG share share_creation_retry_number 0
     iniset $TEMPEST_CONFIG share capability_storage_protocol 'NFS_CIFS'
+    iniset $TEMPEST_CONFIG share capability_sg_consistent_snapshot_support 'pool'
     iniset $TEMPEST_CONFIG share enable_protocols 'nfs,cifs'
     iniset $TEMPEST_CONFIG share suppress_errors_in_cleanup False
     iniset $TEMPEST_CONFIG share multitenancy_enabled True
     iniset $TEMPEST_CONFIG share create_networks_when_multitenancy_enabled False
     iniset $TEMPEST_CONFIG share multi_backend True
-elif [[ "$DRIVER" == "container" ]]; then
+elif [[ "$DRIVER" == "container"* ]]; then
     MANILA_TESTS="(^manila_tempest_tests.tests.api)(?=.*\[.*\bbackend\b.*\])"
+    if [[ "$DRIVER" == "container_with_custom_image" ]]; then
+        # TODO(vponomaryov): set scenario tests for run when
+        # manila tempest plugin supports share protocol and rules that
+        # container driver uses.
+        # MANILA_TESTS="(^manila_tempest_tests.tests.scenario)(?=.*\btest_read_write_two_vms\b.*)"
+        :
+    fi
     MANILA_TEMPEST_CONCURRENCY=8
     RUN_MANILA_SG_TESTS=False
     RUN_MANILA_MANAGE_TESTS=False
     RUN_MANILA_QUOTA_TESTS=False
     RUN_MANILA_SHRINK_TESTS=False
     RUN_MANILA_SNAPSHOT_TESTS=False
+    RUN_MANILA_HOST_ASSISTED_MIGRATION_TESTS=False
     CAPABILITY_CREATE_SHARE_FROM_SNAPSHOT_SUPPORT=False
     iniset $TEMPEST_CONFIG share capability_storage_protocol 'CIFS'
     iniset $TEMPEST_CONFIG share enable_protocols 'cifs'
     iniset $TEMPEST_CONFIG share enable_user_rules_for_protocols 'cifs'
     iniset $TEMPEST_CONFIG share enable_ip_rules_for_protocols ''
+
+    # TODO(vponomaryov): set following to True when bug #1679715 is fixed
+    iniset $TEMPEST_CONFIG auth use_dynamic_credentials False
 fi
 
 # Enable quota tests
@@ -285,10 +299,6 @@ iniset $TEMPEST_CONFIG share run_mount_snapshot_tests $RUN_MANILA_MOUNT_SNAPSHOT
 # Create share from snapshot support
 iniset $TEMPEST_CONFIG share capability_create_share_from_snapshot_support $CAPABILITY_CREATE_SHARE_FROM_SNAPSHOT_SUPPORT
 
-# Revert share to snapshot support
-CAPABILITY_REVERT_TO_SNAPSHOT_SUPPORT=${CAPABILITY_REVERT_TO_SNAPSHOT_SUPPORT:-$RUN_MANILA_REVERT_TO_SNAPSHOT_TESTS}
-iniset $TEMPEST_CONFIG share capability_revert_to_snapshot_support $CAPABILITY_REVERT_TO_SNAPSHOT_SUPPORT
-
 iniset $TEMPEST_CONFIG validation ip_version_for_ssh 4
 iniset $TEMPEST_CONFIG validation network_for_ssh ${PRIVATE_NETWORK_NAME:-"private"}
 
@@ -319,7 +329,7 @@ for port in ${UDP_PORTS[*]}; do
 done
 
 echo "Running tempest manila test suites"
-sudo -H -u $USER tox -eall-plugin $MANILA_TESTS -- --concurrency=$MANILA_TEMPEST_CONCURRENCY
+sudo -H -u jenkins tox -eall-plugin $MANILA_TESTS -- --concurrency=$MANILA_TEMPEST_CONCURRENCY
 RETVAL=$?
 
 
@@ -341,7 +351,7 @@ if [[ "$DRIVER" == "dummy" ]]; then
     manila type-key default set driver_handles_share_servers=False
 
     echo "Running tempest manila test suites for DHSS=False mode"
-    sudo -H -u $USER tox -eall-plugin $MANILA_TESTS -- --concurrency=$MANILA_TEMPEST_CONCURRENCY
+    sudo -H -u jenkins tox -eall-plugin $MANILA_TESTS -- --concurrency=$MANILA_TEMPEST_CONCURRENCY
     RETVAL2=$?
     save_tempest_results 2
 
