@@ -75,7 +75,7 @@ echo "MANILA_SHARE_MIGRATION_PERIOD_TASK_INTERVAL=${MANILA_SHARE_MIGRATION_PERIO
 MANILA_SERVICE_IMAGE_ENABLED=${MANILA_SERVICE_IMAGE_ENABLED:-False}
 DEFAULT_EXTRA_SPECS=${DEFAULT_EXTRA_SPECS:-"'snapshot_support=True create_share_from_snapshot_support=True'"}
 
-if [[ "$DRIVER" == "generic" ]]; then
+if [[ "$DRIVER" == "generic"* ]]; then
     MANILA_SERVICE_IMAGE_ENABLED=True
     echo "SHARE_DRIVER=manila.share.drivers.generic.GenericShareDriver" >> $localconf
 elif [[ "$DRIVER" == "windows" ]]; then
@@ -85,6 +85,12 @@ elif [[ "$DRIVER" == "dummy" ]]; then
     driver_path="manila.tests.share.drivers.dummy.DummyDriver"
     DEFAULT_EXTRA_SPECS="'snapshot_support=True create_share_from_snapshot_support=True revert_to_snapshot_support=True mount_snapshot_support=True'"
     echo "MANILA_SERVICE_IMAGE_ENABLED=False" >> $localconf
+
+    # Run dummy driver CI job using standalone approach for running
+    # manila API service just because we need to test this approach too,
+    # that is very useful for development needs.
+    echo "MANILA_USE_MOD_WSGI=False" >> $localconf
+
     echo "SHARE_DRIVER=$driver_path" >> $localconf
     echo "SUPPRESS_ERRORS_IN_CLEANUP=False" >> $localconf
     echo "MANILA_REPLICA_STATE_UPDATE_INTERVAL=10" >> $localconf
@@ -149,7 +155,7 @@ elif [[ "$DRIVER" == "zfsonlinux" ]]; then
     # Set proper host IP for user export to be able to run scenario tests correctly
     echo "MANILA_ZFSONLINUX_SHARE_EXPORT_IP=$HOST" >> $localconf
     echo "MANILA_ZFSONLINUX_SERVICE_IP=127.0.0.1" >> $localconf
-elif [[ "$DRIVER" == "container" ]]; then
+elif [[ "$DRIVER" == "container"* ]]; then
     DEFAULT_EXTRA_SPECS="'snapshot_support=false'"
     echo "SHARE_DRIVER=manila.share.drivers.container.driver.ContainerShareDriver" >> $localconf
     echo "SHARE_BACKING_FILE_SIZE=64000M" >> $localconf
@@ -168,7 +174,7 @@ echo "TEMPEST_USE_TEST_ACCOUNTS=True" >> $localconf
 echo "TEMPEST_ALLOW_TENANT_ISOLATION=False" >> $localconf
 echo "TEMPEST_CONCURRENCY=${MANILA_TEMPEST_CONCURRENCY:-8}" >> $localconf
 
-if [[ "$DRIVER" == "generic" ]]; then
+if [[ "$DRIVER" == "generic"* ]]; then
     echo -e '[[post-config|${NOVA_CONF:-/etc/nova/nova.conf}]]\n[DEFAULT]\nquota_instances=30\n' >> $localconf
     echo -e '[[post-config|${NEUTRON_CONF:-/etc/neutron/neutron.conf}]]\n[DEFAULT]\nmax_fixed_ips_per_port=100\n' >> $localconf
     echo -e '[[post-config|${NEUTRON_CONF:-/etc/neutron/neutron.conf}]]\n[QUOTAS]\nquota_subnet=-1\n' >> $localconf
@@ -179,11 +185,8 @@ if [[ -d "$BASE/old/devstack" ]]; then
     cp $localconf $BASE/old/devstack/local.conf
 fi
 
-# Go to Tempest dir and checkout stable commit to avoid possible
-# incompatibilities for plugin stored in Manila repo.
 cd $BASE/new/tempest
 source $BASE/new/manila/contrib/ci/common.sh
-git checkout $MANILA_TEMPEST_COMMIT
 
 # Print current Tempest status
 git status
