@@ -59,6 +59,22 @@ function cleanup_manila {
     _clean_zfsonlinux_data
 }
 
+# _config_manila_apache_wsgi() - Configure manila-api wsgi application.
+function _config_manila_apache_wsgi {
+    local manila_api_apache_conf
+    local venv_path=""
+    manila_api_apache_conf=$(apache_site_config_for manila-api)
+
+    sudo cp $MANILA_DIR/devstack/apache-manila.template $manila_api_apache_conf
+    sudo sed -e "
+        s|%APACHE_NAME%|$APACHE_NAME|g;
+        s|%MANILA_BIN_DIR%|$MANILA_BIN_DIR|g;
+        s|%PORT%|$MANILA_SERVICE_PORT|g;
+        s|%APIWORKERS%|$API_WORKERS|g;
+        s|%USER%|$STACK_USER|g;
+    " -i $manila_api_apache_conf
+}
+
 # configure_default_backends - configures default Manila backends with generic driver.
 function configure_default_backends {
     # Configure two default backends with generic drivers onboard
@@ -181,8 +197,7 @@ function configure_manila {
     iniset $MANILA_CONF DEFAULT osapi_share_extension manila.api.contrib.standard_extensions
     iniset $MANILA_CONF DEFAULT state_path $MANILA_STATE_PATH
     iniset $MANILA_CONF DEFAULT default_share_type $MANILA_DEFAULT_SHARE_TYPE
-    # TODO(vponomaryov): revert following back in Pike
-    # iniset $MANILA_CONF DEFAULT default_share_group_type $MANILA_DEFAULT_SHARE_GROUP_TYPE
+    iniset $MANILA_CONF DEFAULT default_share_group_type $MANILA_DEFAULT_SHARE_GROUP_TYPE
 
     if ! [[ -z $MANILA_SHARE_MIGRATION_PERIOD_TASK_INTERVAL ]]; then
         iniset $MANILA_CONF DEFAULT migration_driver_continue_update_interval $MANILA_SHARE_MIGRATION_PERIOD_TASK_INTERVAL
@@ -237,13 +252,31 @@ function configure_manila {
         iniset $MANILA_CONF DEFAULT osapi_share_listen_port $MANILA_SERVICE_PORT_INT
     fi
 
+    if [ "$SYSLOG" != "False" ]; then
+        iniset $MANILA_CONF DEFAULT use_syslog True
+    fi
+
     iniset_rpc_backend manila $MANILA_CONF DEFAULT
 
-    setup_logging $MANILA_CONF
+    if [ "$LOG_COLOR" == "True" ] && [ "$SYSLOG" == "False" ]; then
+        # Add color to logging output
+        iniset $MANILA_CONF DEFAULT logging_context_format_string \
+            "%(asctime)s.%(msecs)d %(color)s%(levelname)s %(name)s [[01;36m%(request_id)s [00;36m%(user_id)s %(project_id)s%(color)s] [01;35m%(instance)s%(color)s%(message)s[00m"
+        iniset $MANILA_CONF DEFAULT logging_default_format_string \
+            "%(asctime)s.%(msecs)d %(color)s%(levelname)s %(name)s [[00;36m-%(color)s] [01;35m%(instance)s%(color)s%(message)s[00m"
+        iniset $MANILA_CONF DEFAULT logging_debug_format_suffix \
+            "[00;33mfrom (pid=%(process)d) %(funcName)s %(pathname)s:%(lineno)d[00m"
+        iniset $MANILA_CONF DEFAULT logging_exception_prefix \
+            "%(color)s%(asctime)s.%(msecs)d TRACE %(name)s [01;35m%(instance)s[00m"
+    fi
 
     MANILA_CONFIGURE_GROUPS=${MANILA_CONFIGURE_GROUPS:-"$MANILA_ENABLED_BACKENDS"}
     set_config_opts $MANILA_CONFIGURE_GROUPS
     set_config_opts DEFAULT
+
+    if [ $(trueorfalse False MANILA_USE_MOD_WSGI) == True ]; then
+        _config_manila_apache_wsgi
+    fi
 }
 
 
@@ -639,14 +672,27 @@ function _install_nfs_and_samba {
     fi
 }
 
+# install_manilaclient - Collect source and prepare
+#   In order to install from git, add LIBS_FROM_GIT="python-manilaclient"
+#   to local.conf
+function install_manilaclient {
+    if use_library_from_git "python-manilaclient"; then
+        git_clone $MANILACLIENT_REPO $MANILACLIENT_DIR $MANILACLIENT_BRANCH
+        setup_develop $MANILACLIENT_DIR
+    else
+        pip_install python-manilaclient
+    fi
+}
+
 # install_manila - Collect source and prepare
 function install_manila {
-    git_clone $MANILACLIENT_REPO $MANILACLIENT_DIR $MANILACLIENT_BRANCH
-    setup_develop $MANILACLIENT_DIR
     setup_develop $MANILA_DIR
 
     if is_service_enabled m-shr; then
-        _install_nfs_and_samba
+
+        if [[ ! $(systemctl is-active nfs-ganesha.service) == 'active' ]]; then
+            _install_nfs_and_samba
+        fi
 
         if [ "$SHARE_DRIVER" == "manila.share.drivers.zfsonlinux.driver.ZFSonLinuxShareDriver" ]; then
             if [[ $(sudo zfs list &> /dev/null && sudo zpool list &> /dev/null || echo 'absent') == 'absent' ]]; then
@@ -692,9 +738,16 @@ function install_manila {
                 install_docker_ubuntu
                 echo "Importing docker image"
                 import_docker_service_image_ubuntu
+            elif is_fedora; then
+                echo "Installing docker...."
+                install_docker_fedora
+                echo "Importing docker image"
+                # TODO(tbarron): See if using a fedora container image
+                # is faster/smaller because of fewer extra dependencies.
+                import_docker_service_image_ubuntu
             else
-                echo "Manila Devstack plugin does not support Container Driver on  "\
-                     " distros other than Ubuntu."
+                echo "Manila Devstack plugin does not support Container Driver on"\
+                     " distros other than Ubuntu or Fedora."
                 exit 1
             fi
         fi
@@ -728,7 +781,7 @@ function configure_samba {
 
         for backend_name in ${MANILA_ENABLED_BACKENDS//,/ }; do
             iniset $MANILA_CONF $backend_name driver_handles_share_servers False
-            iniset $MANILA_CONF $backend_name lvm_share_export_ip $MANILA_LVM_SHARE_EXPORT_IP
+            iniset $MANILA_CONF $backend_name lvm_share_export_ips $MANILA_LVM_SHARE_EXPORT_IPS
         done
         iniset $MANILA_CONF DEFAULT data_node_access_ip $HOST_IP
     fi
@@ -736,7 +789,14 @@ function configure_samba {
 
 # start_manila_api - starts manila API services and checks its availability
 function start_manila_api {
-    run_process m-api "$MANILA_BIN_DIR/manila-api --config-file $MANILA_CONF"
+    if [ $(trueorfalse False MANILA_USE_MOD_WSGI) == True ]; then
+        install_apache_wsgi
+        enable_apache_site manila-api
+        restart_apache_server
+        tail_log m-api /var/log/$APACHE_NAME/manila_api.log
+    else
+        run_process m-api "$MANILA_BIN_DIR/manila-api --config-file $MANILA_CONF"
+    fi
 
     echo "Waiting for Manila API to start..."
     if ! wait_for_service $SERVICE_TIMEOUT $MANILA_SERVICE_PROTOCOL://$MANILA_SERVICE_HOST:$MANILA_SERVICE_PORT; then
@@ -765,8 +825,16 @@ function start_manila {
 
 # stop_manila - Stop running processes
 function stop_manila {
-    # Kill the manila processes
-    for serv in m-api m-sch m-shr m-dat; do
+    # Disable manila api service
+    if [ $(trueorfalse False MANILA_USE_MOD_WSGI) == True ]; then
+        disable_apache_site manila-api
+        restart_apache_server
+    else
+        stop_process m-api
+    fi
+
+    # Kill all other manila processes
+    for serv in m-sch m-shr m-dat; do
         stop_process $serv
     done
 }
@@ -804,6 +872,12 @@ function install_docker_ubuntu {
     install_package docker.io
 }
 
+function install_docker_fedora {
+    sudo yum install -y docker
+    sudo systemctl enable docker
+    sudo systemctl start docker
+}
+
 function download_image {
     local image_url=$1
 
@@ -864,6 +938,8 @@ function install_libraries {
 
 # Main dispatcher
 if [[ "$1" == "stack" && "$2" == "install" ]]; then
+    echo_summary "Installing Manila Client"
+    install_manilaclient
     echo_summary "Installing Manila"
     install_manila
     set_cinder_quotas
@@ -874,6 +950,8 @@ elif [[ "$1" == "stack" && "$2" == "post-config" ]]; then
     init_manila
     echo_summary "Installing extra libraries"
     install_libraries
+    echo_summary "Creating Manila entities for auth service"
+    create_manila_accounts
 
     # Cinder config update
     if is_service_enabled cinder && [[ -n "$CINDER_OVERSUBSCRIPTION_RATIO" ]]; then
@@ -885,9 +963,6 @@ elif [[ "$1" == "stack" && "$2" == "post-config" ]]; then
         iniset $CINDER_CONF DEFAULT max_over_subscription_ratio $CINDER_OVERSUBSCRIPTION_RATIO
     fi
 elif [[ "$1" == "stack" && "$2" == "extra" ]]; then
-    echo_summary "Creating Manila entities for auth service"
-    create_manila_accounts
-
     if is_service_enabled nova; then
         echo_summary "Creating Manila service flavor"
         create_manila_service_flavor
@@ -926,9 +1001,8 @@ elif [[ "$1" == "stack" && "$2" == "extra" ]]; then
     echo_summary "Creating Manila default share type"
     create_default_share_type
 
-    # TODO(vponomaryov): revert following back in Pike
-    # echo_summary "Creating Manila default share group type"
-    # create_default_share_group_type
+    echo_summary "Creating Manila default share group type"
+    create_default_share_group_type
 
     echo_summary "Creating Manila custom share types"
     create_custom_share_types
