@@ -98,13 +98,26 @@ REST_API_VERSION_HISTORY = """
     * 2.30 - Added cast_rules_to_readonly field to share_instances.
     * 2.31 - Convert consistency groups to share groups.
     * 2.32 - Added mountable snapshots APIs.
+    * 2.33 - Added 'created_at' and 'updated_at' to the response of
+             access_list API.
+    * 2.34 - Added 'availability_zone_id' and 'consistent_snapshot_support'
+             fields to 'share_group' object.
+    * 2.35 - Added support to retrieve shares filtered by export_location_id
+             and export_location_path.
+    * 2.36 - Added like filter support in ``shares``, ``snapshots``,
+             ``share-networks``, ``share-groups`` list APIs.
+    * 2.37 - Added /messages APIs.
+    * 2.38 - Support IPv6 validation in allow_access API to enable IPv6 in
+             manila.
+    * 2.39 - Added share-type quotas.
+    * 2.40 - Added share group and share group snapshot quotas.
 """
 
 # The minimum and maximum versions of the API supported
 # The default api version request is defined to be the
 # minimum version of the API supported.
 _MIN_API_VERSION = "2.0"
-_MAX_API_VERSION = "2.32"
+_MAX_API_VERSION = "2.40"
 DEFAULT_API_VERSION = _MIN_API_VERSION
 
 
