@@ -24,7 +24,7 @@ from manila.api.openstack import wsgi
 from manila.api.views import share_snapshots as snapshot_views
 from manila import db
 from manila import exception
-from manila.i18n import _, _LI
+from manila.i18n import _
 from manila import share
 
 LOG = log.getLogger(__name__)
@@ -61,7 +61,7 @@ class ShareSnapshotMixin(object):
         """Delete a snapshot."""
         context = req.environ['manila.context']
 
-        LOG.info(_LI("Delete snapshot with id: %s"), id, context=context)
+        LOG.info("Delete snapshot with id: %s", id, context=context)
 
         try:
             snapshot = self.share_api.get_snapshot(context, id)
@@ -72,10 +72,16 @@ class ShareSnapshotMixin(object):
 
     def index(self, req):
         """Returns a summary list of snapshots."""
+        req.GET.pop('name~', None)
+        req.GET.pop('description~', None)
+        req.GET.pop('description', None)
         return self._get_snapshots(req, is_detail=False)
 
     def detail(self, req):
         """Returns a detailed list of snapshots."""
+        req.GET.pop('name~', None)
+        req.GET.pop('description~', None)
+        req.GET.pop('description', None)
         return self._get_snapshots(req, is_detail=True)
 
     def _get_snapshots(self, req, is_detail):
@@ -96,6 +102,15 @@ class ShareSnapshotMixin(object):
         # from Cinder v1 and v2 APIs.
         if 'name' in search_opts:
             search_opts['display_name'] = search_opts.pop('name')
+        if 'description' in search_opts:
+            search_opts['display_description'] = search_opts.pop(
+                'description')
+
+        # like filter
+        for key, db_key in (('name~', 'display_name~'),
+                            ('description~', 'display_description~')):
+            if key in search_opts:
+                search_opts[db_key] = search_opts.pop(key)
 
         common.remove_invalid_options(context, search_opts,
                                       self._get_snapshots_search_options())
@@ -119,8 +134,10 @@ class ShareSnapshotMixin(object):
         return snapshots
 
     def _get_snapshots_search_options(self):
-        """Return share search options allowed by non-admin."""
-        return ('display_name', 'name', 'status', 'share_id', 'size')
+        """Return share snapshot search options allowed by non-admin."""
+        return ('display_name', 'name', 'status', 'share_id', 'size',
+                'display_name~', 'display_description~', 'description',
+                'display_description')
 
     def update(self, req, id, body):
         """Update a snapshot."""
@@ -169,7 +186,7 @@ class ShareSnapshotMixin(object):
             LOG.error(msg)
             raise exc.HTTPUnprocessableEntity(explanation=msg)
 
-        LOG.info(_LI("Create snapshot from share %s"),
+        LOG.info("Create snapshot from share %s",
                  share_id, context=context)
 
         # NOTE(rushiagr): v2 API allows name instead of display_name
