@@ -31,7 +31,7 @@ from manila.api.views import shares as share_views
 from manila.common import constants
 from manila import db
 from manila import exception
-from manila.i18n import _, _LI
+from manila.i18n import _
 from manila import share
 from manila.share import share_types
 
@@ -68,7 +68,7 @@ class ShareMixin(object):
         """Delete a share."""
         context = req.environ['manila.context']
 
-        LOG.info(_LI("Delete share with id: %s"), id, context=context)
+        LOG.info("Delete share with id: %s", id, context=context)
 
         try:
             share = self.share_api.get(context, id)
@@ -100,10 +100,20 @@ class ShareMixin(object):
 
     def index(self, req):
         """Returns a summary list of shares."""
+        req.GET.pop('export_location_id', None)
+        req.GET.pop('export_location_path', None)
+        req.GET.pop('name~', None)
+        req.GET.pop('description~', None)
+        req.GET.pop('description', None)
         return self._get_shares(req, is_detail=False)
 
     def detail(self, req):
         """Returns a detailed list of shares."""
+        req.GET.pop('export_location_id', None)
+        req.GET.pop('export_location_path', None)
+        req.GET.pop('name~', None)
+        req.GET.pop('description~', None)
+        req.GET.pop('description', None)
         return self._get_shares(req, is_detail=True)
 
     def _get_shares(self, req, is_detail):
@@ -131,6 +141,16 @@ class ShareMixin(object):
         # from Cinder v1 and v2 APIs.
         if 'name' in search_opts:
             search_opts['display_name'] = search_opts.pop('name')
+        if 'description' in search_opts:
+            search_opts['display_description'] = search_opts.pop(
+                'description')
+
+        # like filter
+        for key, db_key in (('name~', 'display_name~'),
+                            ('description~', 'display_description~')):
+            if key in search_opts:
+                search_opts[db_key] = search_opts.pop(key)
+
         if sort_key == 'name':
             sort_key = 'display_name'
 
@@ -159,7 +179,9 @@ class ShareMixin(object):
             'display_name', 'status', 'share_server_id', 'volume_type_id',
             'share_type_id', 'snapshot_id', 'host', 'share_network_id',
             'is_public', 'metadata', 'extra_specs', 'sort_key', 'sort_dir',
-            'share_group_id', 'share_group_snapshot_id'
+            'share_group_id', 'share_group_snapshot_id',
+            'export_location_id', 'export_location_path', 'display_name~',
+            'display_description~', 'description', 'display_description'
         )
 
     def update(self, req, id, body):
@@ -204,6 +226,7 @@ class ShareMixin(object):
             raise exc.HTTPUnprocessableEntity()
 
         share = body['share']
+        availability_zone_id = None
 
         # NOTE(rushiagr): Manila API allows 'name' instead of 'display_name'.
         if share.get('name'):
@@ -219,23 +242,37 @@ class ShareMixin(object):
         size = share['size']
         share_proto = share['share_proto'].upper()
 
-        msg = (_LI("Create %(share_proto)s share of %(size)s GB") %
+        msg = ("Create %(share_proto)s share of %(size)s GB" %
                {'share_proto': share_proto, 'size': size})
         LOG.info(msg, context=context)
 
         availability_zone = share.get('availability_zone')
-
         if availability_zone:
             try:
-                db.availability_zone_get(context, availability_zone)
+                availability_zone_id = db.availability_zone_get(
+                    context, availability_zone).id
             except exception.AvailabilityZoneNotFound as e:
                 raise exc.HTTPNotFound(explanation=six.text_type(e))
 
+        share_group_id = share.get('share_group_id')
+        if share_group_id:
+            try:
+                share_group = db.share_group_get(context, share_group_id)
+            except exception.ShareGroupNotFound as e:
+                raise exc.HTTPNotFound(explanation=six.text_type(e))
+            sg_az_id = share_group['availability_zone_id']
+            if availability_zone and availability_zone_id != sg_az_id:
+                msg = _("Share cannot have AZ ('%(s_az)s') different than "
+                        "share group's one (%(sg_az)s).") % {
+                            's_az': availability_zone_id, 'sg_az': sg_az_id}
+                raise exception.InvalidInput(msg)
+            availability_zone_id = sg_az_id
+
         kwargs = {
-            'availability_zone': availability_zone,
+            'availability_zone': availability_zone_id,
             'metadata': share.get('metadata'),
             'is_public': share.get('is_public', False),
-            'share_group_id': share.get('share_group_id')
+            'share_group_id': share_group_id,
         }
 
         snapshot_id = share.get('snapshot_id')
@@ -257,8 +294,8 @@ class ShareMixin(object):
             parent_share_net_id = parent_share.instance['share_network_id']
             if share_network_id:
                 if share_network_id != parent_share_net_id:
-                    msg = "Share network ID should be the same as snapshot's" \
-                          " parent share's or empty"
+                    msg = ("Share network ID should be the same as snapshot's"
+                           " parent share's or empty")
                     raise exc.HTTPBadRequest(explanation=msg)
             elif parent_share_net_id:
                 share_network_id = parent_share_net_id
@@ -311,7 +348,7 @@ class ShareMixin(object):
         # and create share with share group features not
         # need this check.
         if (not share_network_id and not snapshot
-                and not share.get('share_group_id')
+                and not share_group_id
                 and share_type and share_type.get('extra_specs')
                 and (strutils.bool_from_string(share_type.get('extra_specs').
                      get('driver_handles_share_servers')))):
@@ -340,7 +377,7 @@ class ShareMixin(object):
 
     @wsgi.Controller.authorize('allow_access')
     def _allow_access(self, req, id, body, enable_ceph=False,
-                      allow_on_error_status=False):
+                      allow_on_error_status=False, enable_ipv6=False):
         """Add share access rule."""
         context = req.environ['manila.context']
         access_data = body.get('allow_access', body.get('os-allow_access'))
@@ -362,7 +399,8 @@ class ShareMixin(object):
         access_to = access_data['access_to']
         common.validate_access(access_type=access_type,
                                access_to=access_to,
-                               enable_ceph=enable_ceph)
+                               enable_ceph=enable_ceph,
+                               enable_ipv6=enable_ipv6)
         try:
             access = self.share_api.allow_access(
                 context, share, access_type, access_to,
@@ -391,7 +429,7 @@ class ShareMixin(object):
         return webob.Response(status_int=202)
 
     def _access_list(self, req, id, body):
-        """list share access rules."""
+        """List share access rules."""
         context = req.environ['manila.context']
 
         share = self.share_api.get(context, id)
