@@ -23,11 +23,12 @@ import webob
 from webob import exc
 
 from manila.api import common
+from manila.api.openstack import api_version_request as api_version
 from manila.api.openstack import wsgi
 from manila.api.views import share_networks as share_networks_views
 from manila.db import api as db_api
 from manila import exception
-from manila.i18n import _, _LE, _LW
+from manila.i18n import _
 from manila import policy
 from manila import quota
 from manila.share import rpcapi as share_rpcapi
@@ -97,8 +98,8 @@ class ShareNetworkController(wsgi.Controller):
                 context, project_id=share_network['project_id'],
                 share_networks=-1, user_id=share_network['user_id'])
         except Exception:
-            LOG.exception(_LE("Failed to update usages deleting "
-                              "share-network."))
+            LOG.exception("Failed to update usages deleting "
+                          "share-network.")
         else:
             QUOTAS.commit(context, reservations,
                           project_id=share_network['project_id'],
@@ -111,13 +112,20 @@ class ShareNetworkController(wsgi.Controller):
         search_opts = {}
         search_opts.update(req.GET)
 
+        if ('all_tenants' in search_opts or
+            ('project_id' in search_opts and
+             search_opts['project_id'] != context.project_id)):
+                policy.check_policy(context, RESOURCE_NAME,
+                                    'get_all_share_networks')
+
         if 'security_service_id' in search_opts:
             networks = db_api.share_network_get_all_by_security_service(
                 context, search_opts['security_service_id'])
-        elif context.is_admin and 'project_id' in search_opts:
+        elif ('project_id' in search_opts and
+              search_opts['project_id'] != context.project_id):
             networks = db_api.share_network_get_all_by_project(
                 context, search_opts['project_id'])
-        elif context.is_admin and 'all_tenants' in search_opts:
+        elif 'all_tenants' in search_opts:
             networks = db_api.share_network_get_all(context)
         else:
             networks = db_api.share_network_get_all_by_project(
@@ -152,7 +160,6 @@ class ShareNetworkController(wsgi.Controller):
             'limit',
             'offset',
             'security_service_id',
-            'project_id'
         ]
         for opt in opts_to_remove:
             search_opts.pop(opt, None)
@@ -160,8 +167,16 @@ class ShareNetworkController(wsgi.Controller):
             for key, value in search_opts.items():
                 if key in ['ip_version', 'segmentation_id']:
                     value = int(value)
-                networks = [network for network in networks
-                            if network[key] == value]
+                if (req.api_version_request >=
+                        api_version.APIVersionRequest("2.36")):
+                    networks = [network for network in networks
+                                if network.get(key) == value or
+                                (value in network.get(key.rstrip('~'))
+                                 if key.endswith('~') and
+                                 network.get(key.rstrip('~')) else ())]
+                else:
+                    networks = [network for network in networks
+                                if network.get(key) == value]
 
         limited_list = common.limited(networks, req)
         return self._view_builder.build_share_networks(
@@ -201,10 +216,10 @@ class ShareNetworkController(wsgi.Controller):
         if share_network['share_servers']:
             for value in update_values:
                 if value not in ['name', 'description']:
-                    msg = _("Cannot update share network %s. It is used by "
-                            "share servers. Only 'name' and 'description' "
-                            "fields are available for update")\
-                        % share_network['id']
+                    msg = (_("Cannot update share network %s. It is used by "
+                             "share servers. Only 'name' and 'description' "
+                             "fields are available for update") %
+                           share_network['id'])
                     raise exc.HTTPForbidden(explanation=msg)
 
         try:
@@ -244,13 +259,13 @@ class ShareNetworkController(wsgi.Controller):
                 return (usages[name]['reserved'] + usages[name]['in_use'])
 
             if 'share_networks' in overs:
-                LOG.warning(_LW("Quota exceeded for %(s_pid)s, "
-                                "tried to create "
-                                "share-network (%(d_consumed)d of %(d_quota)d "
-                                "already consumed)."), {
-                                    's_pid': context.project_id,
-                                    'd_consumed': _consumed('share_networks'),
-                                    'd_quota': quotas['share_networks']})
+                LOG.warning("Quota exceeded for %(s_pid)s, "
+                            "tried to create "
+                            "share-network (%(d_consumed)d of %(d_quota)d "
+                            "already consumed).", {
+                                's_pid': context.project_id,
+                                'd_consumed': _consumed('share_networks'),
+                                'd_quota': quotas['share_networks']})
                 raise exception.ShareNetworksLimitExceeded(
                     allowed=quotas['share_networks'])
         else:
