@@ -22,12 +22,13 @@ import webob
 from webob import exc
 
 from manila.api import common
+from manila.api.openstack import api_version_request as api_version
 from manila.api.openstack import wsgi
 from manila.api.v1 import share_snapshots
 from manila.api.views import share_snapshots as snapshot_views
 from manila.common import constants
 from manila import exception
-from manila.i18n import _, _LI
+from manila.i18n import _
 from manila import share
 
 LOG = log.getLogger(__name__)
@@ -49,7 +50,7 @@ class ShareSnapshotsController(share_snapshots.ShareSnapshotMixin,
         """Unmanage a share snapshot."""
         context = req.environ['manila.context']
 
-        LOG.info(_LI("Unmanage share snapshot with id: %s."), id)
+        LOG.info("Unmanage share snapshot with id: %s.", id)
 
         try:
             snapshot = self.share_api.get_snapshot(context, id)
@@ -158,7 +159,7 @@ class ShareSnapshotsController(share_snapshots.ShareSnapshotMixin,
                 msg = _("Required parameter %s is empty.") % parameter
                 raise exc_response(explanation=msg)
 
-    def _allow(self, req, id, body):
+    def _allow(self, req, id, body, enable_ipv6=False):
         context = req.environ['manila.context']
 
         if not (body and self.is_valid_body(body, 'allow_access')):
@@ -174,7 +175,9 @@ class ShareSnapshotsController(share_snapshots.ShareSnapshotMixin,
         access_type = access_data['access_type']
         access_to = access_data['access_to']
 
-        common.validate_access(access_type=access_type, access_to=access_to)
+        common.validate_access(access_type=access_type,
+                               access_to=access_to,
+                               enable_ipv6=enable_ipv6)
 
         snapshot = self.share_api.get_snapshot(context, id)
 
@@ -269,7 +272,10 @@ class ShareSnapshotsController(share_snapshots.ShareSnapshotMixin,
     @wsgi.response(202)
     @wsgi.Controller.authorize
     def allow_access(self, req, id, body=None):
-        return self._allow(req, id, body)
+        enable_ipv6 = False
+        if req.api_version_request >= api_version.APIVersionRequest("2.38"):
+            enable_ipv6 = True
+        return self._allow(req, id, body, enable_ipv6)
 
     @wsgi.Controller.api_version('2.32')
     @wsgi.action('deny_access')
@@ -282,6 +288,24 @@ class ShareSnapshotsController(share_snapshots.ShareSnapshotMixin,
     def access_list(self, req, snapshot_id):
         return self._access_list(req, snapshot_id)
 
+    @wsgi.Controller.api_version("2.0")
+    def index(self, req):
+        """Returns a summary list of shares."""
+        if req.api_version_request < api_version.APIVersionRequest("2.36"):
+            req.GET.pop('name~', None)
+            req.GET.pop('description~', None)
+            req.GET.pop('description', None)
+        return self._get_snapshots(req, is_detail=False)
+
+    @wsgi.Controller.api_version("2.0")
+    def detail(self, req):
+        """Returns a detailed list of shares."""
+        if req.api_version_request < api_version.APIVersionRequest("2.36"):
+            req.GET.pop('name~', None)
+            req.GET.pop('description~', None)
+            req.GET.pop('description', None)
+        return self._get_snapshots(req, is_detail=True)
+
 
 def create_resource():
     return wsgi.Resource(ShareSnapshotsController())
