@@ -29,7 +29,7 @@ from manila.api.views import shares as share_views
 from manila.common import constants
 from manila import db
 from manila import exception
-from manila.i18n import _, _LI
+from manila.i18n import _
 from manila import share
 from manila import utils
 
@@ -144,7 +144,7 @@ class ShareController(shares.ShareMixin,
                     raise exc.HTTPConflict(explanation=msg % msg_args)
 
             msg_args = {'share_id': share_id, 'snap_id': snapshot_id}
-            msg = _LI('Reverting share %(share_id)s to snapshot %(snap_id)s.')
+            msg = 'Reverting share %(share_id)s to snapshot %(snap_id)s.'
             LOG.info(msg, msg_args)
 
             self.share_api.revert_to_snapshot(context, share, snapshot)
@@ -343,6 +343,8 @@ class ShareController(shares.ShareMixin,
             kwargs['enable_ceph'] = True
         if req.api_version_request >= api_version.APIVersionRequest("2.28"):
             kwargs['allow_on_error_status'] = True
+        if req.api_version_request >= api_version.APIVersionRequest("2.38"):
+            kwargs['enable_ipv6'] = True
 
         return self._allow_access(*args, **kwargs)
 
@@ -415,6 +417,34 @@ class ShareController(shares.ShareMixin,
     def revert(self, req, id, body=None):
         return self._revert(req, id, body)
 
+    @wsgi.Controller.api_version("2.0")
+    def index(self, req):
+        """Returns a summary list of shares."""
+        if req.api_version_request < api_version.APIVersionRequest("2.35"):
+            req.GET.pop('export_location_id', None)
+            req.GET.pop('export_location_path', None)
+
+        if req.api_version_request < api_version.APIVersionRequest("2.36"):
+            req.GET.pop('name~', None)
+            req.GET.pop('description~', None)
+            req.GET.pop('description', None)
+
+        return self._get_shares(req, is_detail=False)
+
+    @wsgi.Controller.api_version("2.0")
+    def detail(self, req):
+        """Returns a detailed list of shares."""
+        if req.api_version_request < api_version.APIVersionRequest("2.35"):
+            req.GET.pop('export_location_id', None)
+            req.GET.pop('export_location_path', None)
+
+        if req.api_version_request < api_version.APIVersionRequest("2.36"):
+            req.GET.pop('name~', None)
+            req.GET.pop('description~', None)
+            req.GET.pop('description', None)
+
+        return self._get_shares(req, is_detail=True)
+
 
 def create_resource():
     return wsgi.Resource(ShareController())
