@@ -41,9 +41,6 @@ log.register_options(CONF)
 
 
 core_opts = [
-    cfg.StrOpt('api_paste_config',
-               default="api-paste.ini",
-               help='File name for the paste.deploy config for manila-api.'),
     cfg.StrOpt('state_path',
                default='/var/lib/manila',
                help="Top-level directory for maintaining manila's state."),
@@ -58,10 +55,10 @@ CONF.register_cli_opts(core_opts)
 CONF.register_cli_opts(debug_opts)
 
 global_opts = [
-    cfg.StrOpt('my_ip',
-               default=netutils.get_my_ipv4(),
-               sample_default='<your_ip>',
-               help='IP address of this host.'),
+    cfg.HostAddressOpt('my_ip',
+                       default=netutils.get_my_ipv4(),
+                       sample_default='<your_ip>',
+                       help='IP address of this host.'),
     cfg.StrOpt('scheduler_topic',
                default='manila-scheduler',
                help='The topic scheduler nodes listen on.'),
@@ -107,17 +104,20 @@ global_opts = [
     cfg.StrOpt('data_manager',
                default='manila.data.manager.DataManager',
                help='Full class name for the data manager.'),
-    cfg.StrOpt('host',
-               default=socket.gethostname(),
-               sample_default='<your_hostname>',
-               help='Name of this node.  This can be an opaque identifier.  '
-                    'It is not necessarily a hostname, FQDN, or IP address.'),
+    cfg.HostAddressOpt('host',
+                       default=socket.gethostname(),
+                       sample_default='<your_hostname>',
+                       help='Name of this node.  This can be an opaque '
+                            'identifier. It is not necessarily a hostname, '
+                            'FQDN, or IP address.'),
     # NOTE(vish): default to nova for compatibility with nova installs
     cfg.StrOpt('storage_availability_zone',
                default='nova',
                help='Availability zone of this node.'),
     cfg.StrOpt('default_share_type',
                help='Default share type to use.'),
+    cfg.StrOpt('default_share_group_type',
+               help='Default share group type to use.'),
     cfg.ListOpt('memcached_servers',
                 help='Memcached servers or None for in process cache.'),
     cfg.StrOpt('share_usage_audit_period',
@@ -188,27 +188,25 @@ def verify_share_protocols():
 
 def set_middleware_defaults():
     """Update default configuration options for oslo.middleware."""
-    # CORS Defaults
-    # TODO(krotscheck): Update with https://review.openstack.org/#/c/285368/
-    cfg.set_defaults(cors.CORS_OPTS,
-                     allow_headers=['X-Auth-Token',
-                                    'X-OpenStack-Request-ID',
-                                    'X-Openstack-Manila-Api-Version',
-                                    'X-OpenStack-Manila-API-Experimental',
-                                    'X-Identity-Status',
-                                    'X-Roles',
-                                    'X-Service-Catalog',
-                                    'X-User-Id',
-                                    'X-Tenant-Id'],
-                     expose_headers=['X-Auth-Token',
-                                     'X-OpenStack-Request-ID',
-                                     'X-Openstack-Manila-Api-Version',
-                                     'X-OpenStack-Manila-API-Experimental',
-                                     'X-Subject-Token',
-                                     'X-Service-Token'],
-                     allow_methods=['GET',
-                                    'PUT',
-                                    'POST',
-                                    'DELETE',
-                                    'PATCH']
-                     )
+    cors.set_defaults(
+        allow_headers=['X-Auth-Token',
+                       'X-OpenStack-Request-ID',
+                       'X-Openstack-Manila-Api-Version',
+                       'X-OpenStack-Manila-API-Experimental',
+                       'X-Identity-Status',
+                       'X-Roles',
+                       'X-Service-Catalog',
+                       'X-User-Id',
+                       'X-Tenant-Id'],
+        expose_headers=['X-Auth-Token',
+                        'X-OpenStack-Request-ID',
+                        'X-Openstack-Manila-Api-Version',
+                        'X-OpenStack-Manila-API-Experimental',
+                        'X-Subject-Token',
+                        'X-Service-Token'],
+        allow_methods=['GET',
+                       'PUT',
+                       'POST',
+                       'DELETE',
+                       'PATCH']
+    )
