@@ -30,7 +30,6 @@ import six
 import webob.exc
 
 from manila.i18n import _
-from manila.i18n import _LE
 
 LOG = log.getLogger(__name__)
 
@@ -89,15 +88,15 @@ class ManilaException(Exception):
             try:
                 message = self.message % kwargs
 
-            except Exception as e:
+            except Exception:
                 # kwargs doesn't match a variable in the message
                 # log the issue and the kwargs
-                LOG.exception(_LE('Exception in string format operation.'))
+                LOG.exception('Exception in string format operation.')
                 for name, value in kwargs.items():
-                    LOG.error(_LE("%(name)s: %(value)s"), {
+                    LOG.error("%(name)s: %(value)s", {
                         'name': name, 'value': value})
                 if CONF.fatal_exception_format_errors:
-                    raise e
+                    raise
                 else:
                     # at least get the core message out if something happened
                     message = self.message
@@ -114,6 +113,10 @@ class NetworkException(ManilaException):
     message = _("Exception due to network failure.")
 
 
+class NetworkBindException(ManilaException):
+    message = _("Exception due to failed port status in binding.")
+
+
 class NetworkBadConfigurationException(NetworkException):
     message = _("Bad network configuration: %(reason)s.")
 
@@ -203,6 +206,10 @@ class NotFound(ManilaException):
     safe = True
 
 
+class MessageNotFound(NotFound):
+    message = _("Message %(message_id)s could not be found.")
+
+
 class Found(ManilaException):
     message = _("Resource was found.")
     code = 302
@@ -238,6 +245,10 @@ class InvalidShareServer(Invalid):
     message = _("Share server %(share_server_id)s is not valid.")
 
 
+class ShareMigrationError(ManilaException):
+    message = _("Error in share migration: %(reason)s")
+
+
 class ShareMigrationFailed(ManilaException):
     message = _("Share migration failed: %(reason)s")
 
@@ -263,6 +274,11 @@ class ShareServerNotCreated(ManilaException):
     message = _("Share server %(share_server_id)s failed on creation.")
 
 
+class ShareServerNotReady(ManilaException):
+    message = _("Share server %(share_server_id)s failed to reach '%(state)s' "
+                "within %(time)s seconds.")
+
+
 class ServiceNotFound(NotFound):
     message = _("Service %(service_id)s could not be found.")
 
@@ -314,6 +330,11 @@ class ProjectUserQuotaNotFound(QuotaNotFound):
                 "could not be found.")
 
 
+class ProjectShareTypeQuotaNotFound(QuotaNotFound):
+    message = _("Quota for share_type %(share_type)s in "
+                "project %(project_id)s could not be found.")
+
+
 class ProjectQuotaNotFound(QuotaNotFound):
     message = _("Quota for project %(project_id)s could not be found.")
 
@@ -374,24 +395,32 @@ class WillNotSchedule(ManilaException):
 class QuotaError(ManilaException):
     message = _("Quota exceeded: code=%(code)s.")
     code = 413
-    headers = {'Retry-After': 0}
+    headers = {'Retry-After': '0'}
     safe = True
 
 
 class ShareSizeExceedsAvailableQuota(QuotaError):
-    message = _("Requested share exceeds allowed gigabytes quota.")
+    message = _(
+        "Requested share exceeds allowed project/user or share type "
+        "gigabytes quota.")
 
 
 class SnapshotSizeExceedsAvailableQuota(QuotaError):
-    message = _("Requested snapshot exceeds allowed gigabytes quota.")
+    message = _(
+        "Requested snapshot exceeds allowed project/user or share type "
+        "gigabytes quota.")
 
 
 class ShareLimitExceeded(QuotaError):
-    message = _("Maximum number of shares allowed (%(allowed)d) exceeded.")
+    message = _(
+        "Maximum number of shares allowed (%(allowed)d) either per "
+        "project/user or share type quota is exceeded.")
 
 
 class SnapshotLimitExceeded(QuotaError):
-    message = _("Maximum number of snapshots allowed (%(allowed)d) exceeded.")
+    message = _(
+        "Maximum number of snapshots allowed (%(allowed)d) either per "
+        "project/user or share type quota is exceeded.")
 
 
 class ShareNetworksLimitExceeded(QuotaError):
@@ -399,6 +428,16 @@ class ShareNetworksLimitExceeded(QuotaError):
                 "allowed (%(allowed)d) exceeded.")
 
 
+class ShareGroupsLimitExceeded(QuotaError):
+    message = _(
+        "Maximum number of allowed share-groups is exceeded.")
+
+
+class ShareGroupSnapshotsLimitExceeded(QuotaError):
+    message = _(
+        "Maximum number of allowed share-group-snapshots is exceeded.")
+
+
 class GlusterfsException(ManilaException):
     message = _("Unknown Gluster exception.")
 
@@ -433,6 +472,14 @@ class ShareAccessExists(ManilaException):
     message = _("Share access %(access_type)s:%(access)s exists.")
 
 
+class ShareSnapshotAccessExists(InvalidInput):
+    message = _("Share snapshot access %(access_type)s:%(access)s exists.")
+
+
+class InvalidSnapshotAccess(Invalid):
+    message = _("Invalid access rule: %(reason)s")
+
+
 class InvalidShareAccess(Invalid):
     message = _("Invalid access rule: %(reason)s")
 
@@ -465,6 +512,10 @@ class ShareSnapshotNotSupported(ManilaException):
     message = _("Share %(share_name)s does not support snapshots.")
 
 
+class ShareGroupSnapshotNotSupported(ManilaException):
+    message = _("Share group %(share_group)s does not support snapshots.")
+
+
 class ShareSnapshotIsBusy(ManilaException):
     message = _("Deleting snapshot %(snapshot_name)s that has "
                 "dependent shares.")
@@ -474,6 +525,10 @@ class InvalidShareSnapshot(Invalid):
     message = _("Invalid share snapshot: %(reason)s.")
 
 
+class InvalidShareSnapshotInstance(Invalid):
+    message = _("Invalid share snapshot instance: %(reason)s.")
+
+
 class ManageInvalidShareSnapshot(InvalidShareSnapshot):
     message = _("Manage existing share snapshot failed due to "
                 "invalid share snapshot: %(reason)s.")
@@ -518,6 +573,10 @@ class InvalidShareType(Invalid):
     message = _("Invalid share type: %(reason)s.")
 
 
+class InvalidShareGroupType(Invalid):
+    message = _("Invalid share group type: %(reason)s.")
+
+
 class InvalidExtraSpec(Invalid):
     message = _("Invalid extra_spec: %(reason)s.")
 
@@ -534,40 +593,91 @@ class ShareTypeNotFound(NotFound):
     message = _("Share type %(share_type_id)s could not be found.")
 
 
+class ShareGroupTypeNotFound(NotFound):
+    message = _("Share group type %(type_id)s could not be found.")
+
+
 class ShareTypeAccessNotFound(NotFound):
     message = _("Share type access not found for %(share_type_id)s / "
                 "%(project_id)s combination.")
 
 
+class ShareGroupTypeAccessNotFound(NotFound):
+    message = _("Share group type access not found for %(type_id)s / "
+                "%(project_id)s combination.")
+
+
 class ShareTypeNotFoundByName(ShareTypeNotFound):
     message = _("Share type with name %(share_type_name)s "
                 "could not be found.")
 
 
+class ShareGroupTypeNotFoundByName(ShareTypeNotFound):
+    message = _("Share group type with name %(type_name)s "
+                "could not be found.")
+
+
 class ShareTypeExtraSpecsNotFound(NotFound):
     message = _("Share Type %(share_type_id)s has no extra specs with "
                 "key %(extra_specs_key)s.")
 
 
+class ShareGroupTypeSpecsNotFound(NotFound):
+    message = _("Share group type %(type_id)s has no group specs with "
+                "key %(specs_key)s.")
+
+
 class ShareTypeInUse(ManilaException):
     message = _("Share Type %(share_type_id)s deletion is not allowed with "
                 "shares present with the type.")
 
 
+class IPAddressInUse(InUse):
+    message = _("IP address %(ip)s is already used.")
+
+
+class ShareGroupTypeInUse(ManilaException):
+    message = _("Share group Type %(type_id)s deletion is not allowed "
+                "with groups present with the type.")
+
+
 class ShareTypeExists(ManilaException):
     message = _("Share Type %(id)s already exists.")
 
 
+class ShareTypeDoesNotExist(NotFound):
+    message = _("Share Type %(share_type)s does not exist.")
+
+
+class DefaultShareTypeNotConfigured(NotFound):
+    message = _("No default share type is configured. Either configure a "
+                "default share type or explicitly specify a share type.")
+
+
+class ShareGroupTypeExists(ManilaException):
+    message = _("Share group type %(type_id)s already exists.")
+
+
 class ShareTypeAccessExists(ManilaException):
     message = _("Share type access for %(share_type_id)s / "
                 "%(project_id)s combination already exists.")
 
 
+class ShareGroupTypeAccessExists(ManilaException):
+    message = _("Share group type access for %(type_id)s / "
+                "%(project_id)s combination already exists.")
+
+
 class ShareTypeCreateFailed(ManilaException):
     message = _("Cannot create share_type with "
                 "name %(name)s and specs %(extra_specs)s.")
 
 
+class ShareGroupTypeCreateFailed(ManilaException):
+    message = _("Cannot create share group type with "
+                "name %(name)s and specs %(group_specs)s.")
+
+
 class ManageExistingShareTypeMismatch(ManilaException):
     message = _("Manage existing share failed due to share type mismatch: "
                 "%(reason)s")
@@ -633,6 +743,18 @@ class VserverNotSpecified(NetAppException):
     message = _("Vserver not specified.")
 
 
+class EMCVmaxXMLAPIError(Invalid):
+    message = _("%(err)s")
+
+
+class EMCVmaxLockRequiredException(ManilaException):
+    message = _("Unable to acquire lock(s).")
+
+
+class EMCVmaxInvalidMoverID(ManilaException):
+    message = _("Invalid mover or vdm %(id)s.")
+
+
 class EMCVnxXMLAPIError(Invalid):
     message = _("%(err)s")
 
@@ -645,6 +767,10 @@ class EMCVnxInvalidMoverID(ManilaException):
     message = _("Invalid mover or vdm %(id)s.")
 
 
+class EMCUnityError(ShareBackendException):
+    message = _("%(err)s")
+
+
 class HPE3ParInvalidClient(Invalid):
     message = _("%(err)s")
 
@@ -686,6 +812,10 @@ class HDFSException(ManilaException):
     message = _("HDFS exception occurred!")
 
 
+class MapRFSException(ManilaException):
+    message = _("MapRFS exception occurred: %(msg)s")
+
+
 class ZFSonLinuxException(ManilaException):
     message = _("ZFSonLinux exception occurred: %(msg)s")
 
@@ -713,6 +843,18 @@ class HNASConnException(ManilaException):
     message = _("HNAS Connection Exception: %(msg)s")
 
 
+class HNASSSCIsBusy(ManilaException):
+    message = _("HNAS SSC is busy and cannot execute the command: %(msg)s")
+
+
+class HNASSSCContextChange(ManilaException):
+    message = _("HNAS SSC Context has been changed unexpectedly: %(msg)s")
+
+
+class HNASDirectoryNotEmpty(ManilaException):
+    message = _("HNAS Directory is not empty: %(msg)s")
+
+
 class HNASItemNotFoundException(StorageResourceNotFound):
     message = _("HNAS Item Not Found Exception: %(msg)s")
 
@@ -721,27 +863,27 @@ class HNASNothingToCloneException(ManilaException):
     message = _("HNAS Nothing To Clone Exception: %(msg)s")
 
 
-# ConsistencyGroup
-class ConsistencyGroupNotFound(NotFound):
-    message = _("ConsistencyGroup %(consistency_group_id)s could not be "
+# ShareGroup
+class ShareGroupNotFound(NotFound):
+    message = _("Share group %(share_group_id)s could not be found.")
+
+
+class ShareGroupSnapshotNotFound(NotFound):
+    message = _(
+        "Share group snapshot %(share_group_snapshot_id)s could not be found.")
+
+
+class ShareGroupSnapshotMemberNotFound(NotFound):
+    message = _("Share group snapshot member %(member_id)s could not be "
                 "found.")
 
 
-class CGSnapshotNotFound(NotFound):
-    message = _("Consistency group snapshot %(cgsnapshot_id)s could not be "
-                "found.")
+class InvalidShareGroup(Invalid):
+    message = _("Invalid share group: %(reason)s")
 
 
-class CGSnapshotMemberNotFound(NotFound):
-    message = _("CG snapshot %(member_id)s could not be found.")
-
-
-class InvalidConsistencyGroup(Invalid):
-    message = _("Invalid ConsistencyGroup: %(reason)s")
-
-
-class InvalidCGSnapshot(Invalid):
-    message = _("Invalid CGSnapshot: %(reason)s")
+class InvalidShareGroupSnapshot(Invalid):
+    message = _("Invalid share group snapshot: %(reason)s")
 
 
 class DriverNotInitialized(ManilaException):
@@ -782,3 +924,33 @@ class TegileAPIException(ShareBackendException):
 
 class StorageCommunicationException(ShareBackendException):
     message = _("Could not communicate with storage array.")
+
+
+class EvaluatorParseException(ManilaException):
+    message = _("Error during evaluator parsing: %(reason)s")
+
+
+# Hitachi Scaleout Platform driver
+class HSPBackendException(ShareBackendException):
+    message = _("HSP Backend Exception: %(msg)s")
+
+
+class HSPTimeoutException(ShareBackendException):
+    message = _("HSP Timeout Exception: %(msg)s")
+
+
+class HSPItemNotFoundException(ShareBackendException):
+    message = _("HSP Item Not Found Exception: %(msg)s")
+
+
+class NexentaException(ShareBackendException):
+    message = _("Exception due to Nexenta failure. %(reason)s")
+
+
+# Tooz locking
+class LockCreationFailed(ManilaException):
+    message = _('Unable to create lock. Coordination backend not started.')
+
+
+class LockingFailed(ManilaException):
+    message = _('Lock acquisition failed.')
