@@ -36,19 +36,12 @@ Guidelines for writing new hacking checks
 
 UNDERSCORE_IMPORT_FILES = []
 
-log_translation = re.compile(
-    r"(.)*LOG\.(audit|error|info|critical|exception)\(\s*('|\")")
-log_translation_LC = re.compile(
-    r"(.)*LOG\.(critical)\(\s*(_\(|'|\")")
-log_translation_LE = re.compile(
-    r"(.)*LOG\.(error|exception)\(\s*(_\(|'|\")")
-log_translation_LI = re.compile(
-    r"(.)*LOG\.(info)\(\s*(_\(|'|\")")
-log_translation_LW = re.compile(
-    r"(.)*LOG\.(warning|warn)\(\s*(_\(|'|\")")
 translated_log = re.compile(
-    r"(.)*LOG\.(audit|error|info|warn|warning|critical|exception)"
-    "\(\s*_\(\s*('|\")")
+    r"(.)*LOG\."
+    r"(audit|debug|error|info|warn|warning|critical|exception)"
+    r"\("
+    r"(_|_LE|_LI|_LW)"
+    r"\(")
 string_translation = re.compile(r"[^_]*_\(\s*('|\")")
 underscore_import_check = re.compile(r"(.)*import _$")
 underscore_import_check_multi = re.compile(r"(.)*import (.)*_, (.)*")
@@ -107,21 +100,9 @@ class BaseASTChecker(ast.NodeVisitor):
         return False
 
 
-def no_translate_debug_logs(logical_line, filename):
-    """Check for 'LOG.debug(_('
-
-    As per our translation policy,
-    https://wiki.openstack.org/wiki/LoggingStandards#Log_Translation
-    we shouldn't translate debug level logs.
-
-    * This check assumes that 'LOG' is a logger.
-    * Use filename so we can start enforcing this in specific folders instead
-      of needing to do so all at once.
-
-    M319
-    """
-    if logical_line.startswith("LOG.debug(_("):
-        yield(0, "M319 Don't translate debug level logs")
+def no_translate_logs(logical_line):
+    if translated_log.match(logical_line):
+        yield(0, "M359 Don't translate log messages!")
 
 
 class CheckLoggingFormatArgs(BaseASTChecker):
@@ -189,32 +170,6 @@ class CheckLoggingFormatArgs(BaseASTChecker):
         return super(CheckLoggingFormatArgs, self).generic_visit(node)
 
 
-def validate_log_translations(logical_line, physical_line, filename):
-    # Translations are not required in the test and tempest
-    # directories.
-    if ("manila/tests" in filename or "manila_tempest_tests" in filename or
-            "contrib/tempest" in filename):
-        return
-    if pep8.noqa(physical_line):
-        return
-    msg = "M327: LOG.critical messages require translations `_LC()`!"
-    if log_translation_LC.match(logical_line):
-        yield (0, msg)
-    msg = ("M328: LOG.error and LOG.exception messages require translations "
-           "`_LE()`!")
-    if log_translation_LE.match(logical_line):
-        yield (0, msg)
-    msg = "M329: LOG.info messages require translations `_LI()`!"
-    if log_translation_LI.match(logical_line):
-        yield (0, msg)
-    msg = "M330: LOG.warning messages require translations `_LW()`!"
-    if log_translation_LW.match(logical_line):
-        yield (0, msg)
-    msg = "M331: Log messages require translations!"
-    if log_translation.match(logical_line):
-        yield (0, msg)
-
-
 def check_explicit_underscore_import(logical_line, filename):
     """Check for explicit import of the _ function
 
@@ -232,8 +187,7 @@ def check_explicit_underscore_import(logical_line, filename):
           underscore_import_check_multi.match(logical_line) or
           custom_underscore_check.match(logical_line)):
         UNDERSCORE_IMPORT_FILES.append(filename)
-    elif (translated_log.match(logical_line) or
-          string_translation.match(logical_line)):
+    elif string_translation.match(logical_line):
         yield(0, "M323: Found use of _() without explicit import of _ !")
 
 
@@ -375,9 +329,8 @@ def no_log_warn_check(logical_line):
 
 
 def factory(register):
-    register(validate_log_translations)
     register(check_explicit_underscore_import)
-    register(no_translate_debug_logs)
+    register(no_translate_logs)
     register(CheckForStrUnicodeExc)
     register(CheckLoggingFormatArgs)
     register(CheckForTransAdd)
