@@ -23,7 +23,6 @@ from oslo_log import log
 from manila.common import client_auth
 from manila import context
 from manila import exception
-from manila.i18n import _LE
 from manila.network.neutron import constants as neutron_constants
 
 NEUTRON_GROUP = 'neutron'
@@ -173,17 +172,14 @@ class API(object):
 
     def create_port(self, tenant_id, network_id, host_id=None, subnet_id=None,
                     fixed_ip=None, device_owner=None, device_id=None,
-                    mac_address=None, port_security_enabled=True,
-                    security_group_ids=None, dhcp_opts=None, **kwargs):
+                    mac_address=None, security_group_ids=None, dhcp_opts=None,
+                    **kwargs):
         try:
             port_req_body = {'port': {}}
             port_req_body['port']['network_id'] = network_id
             port_req_body['port']['admin_state_up'] = True
             port_req_body['port']['tenant_id'] = tenant_id
-            if not port_security_enabled:
-                port_req_body['port']['port_security_enabled'] = (
-                    port_security_enabled)
-            elif security_group_ids:
+            if security_group_ids:
                 port_req_body['port']['security_groups'] = security_group_ids
             if mac_address:
                 port_req_body['port']['mac_address'] = mac_address
@@ -210,7 +206,7 @@ class API(object):
             port = self.client.create_port(port_req_body).get('port', {})
             return port
         except neutron_client_exc.NeutronClientException as e:
-            LOG.exception(_LE('Neutron error creating port on network %s'),
+            LOG.exception('Neutron error creating port on network %s',
                           network_id)
             if e.status_code == 409:
                 raise exception.PortLimitExceeded()
@@ -386,25 +382,23 @@ class API(object):
     def security_group_create(self, name, description=""):
         try:
             return self.client.create_security_group(
-                {'security_group': {"name": name, "description": description}})
+                {"name": name, "description": description})
         except neutron_client_exc.NeutronClientException as e:
             raise exception.NetworkException(
                 code=e.status_code, message=e.message)
 
     def security_group_rule_create(self, parent_group_id,
                                    ip_protocol=None, from_port=None,
-                                   to_port=None, cidr=None, group_id=None,
-                                   direction="ingress"):
-        request = {"security_group_id": parent_group_id,
-                   "protocol": ip_protocol, "remote_ip_prefix": cidr,
-                   "remote_group_id": group_id, "direction": direction}
-        if ip_protocol != "icmp":
-            request["port_range_min"] = from_port
-            request["port_range_max"] = to_port
-
+                                   to_port=None, cidr=None, group_id=None):
         try:
-            return self.client.create_security_group_rule(
-                {"security_group_rule": request})
+            return self.client.create_security_group_rule({
+                "parent_group_id": parent_group_id,
+                "ip_protocol": ip_protocol,
+                "from_port": from_port,
+                "to_port": to_port,
+                "cidr": cidr,
+                "group_id": group_id,
+            })
         except neutron_client_exc.NeutronClientException as e:
             raise exception.NetworkException(
                 code=e.status_code, message=e.message)
