@@ -33,7 +33,6 @@ import six
 
 from manila import db
 from manila import exception
-from manila.i18n import _LI, _LW
 from manila.scheduler.filters import base_host as base_host_filter
 from manila.scheduler import utils as scheduler_utils
 from manila.scheduler.weighers import base_host as base_host_weigher
@@ -57,7 +56,15 @@ host_manager_opts = [
                     'CapacityWeigher',
                     'GoodnessWeigher',
                 ],
-                help='Which weigher class names to use for weighing hosts.')
+                help='Which weigher class names to use for weighing hosts.'),
+    cfg.ListOpt(
+        'scheduler_default_share_group_filters',
+        default=[
+            'AvailabilityZoneFilter',
+            'ConsistentSnapshotFilter',
+        ],
+        help='Which filter class names to use for filtering hosts '
+             'creating share group when not specified in the request.'),
 ]
 
 CONF = cfg.CONF
@@ -136,11 +143,16 @@ class HostState(object):
         self.compression = False
         self.replication_type = None
         self.replication_domain = None
+        self.ipv4_support = None
+        self.ipv6_support = None
 
         # PoolState for all pools
         self.pools = {}
         self.updated = None
 
+        # Share Group capabilities
+        self.sg_consistent_snapshot_support = None
+
     def update_capabilities(self, capabilities=None, service=None):
         # Read-only capability dicts
 
@@ -318,6 +330,16 @@ class HostState(object):
         if not pool_cap.get('replication_domain'):
             pool_cap['replication_domain'] = self.replication_domain
 
+        if 'sg_consistent_snapshot_support' not in pool_cap:
+            pool_cap['sg_consistent_snapshot_support'] = (
+                self.sg_consistent_snapshot_support)
+
+        if self.ipv4_support is not None:
+            pool_cap['ipv4_support'] = self.ipv4_support
+
+        if self.ipv6_support is not None:
+            pool_cap['ipv6_support'] = self.ipv6_support
+
     def update_backend(self, capability):
         self.share_backend_name = capability.get('share_backend_name')
         self.vendor_name = capability.get('vendor_name')
@@ -335,6 +357,12 @@ class HostState(object):
         self.updated = capability['timestamp']
         self.replication_type = capability.get('replication_type')
         self.replication_domain = capability.get('replication_domain')
+        self.sg_consistent_snapshot_support = capability.get(
+            'share_group_stats', {}).get('consistent_snapshot_support')
+        if capability.get('ipv4_support') is not None:
+            self.ipv4_support = capability['ipv4_support']
+        if capability.get('ipv6_support') is not None:
+            self.ipv6_support = capability['ipv6_support']
 
     def consume_from_share(self, share):
         """Incrementally update host state from an share."""
@@ -420,6 +448,8 @@ class PoolState(HostState):
                 'replication_type', self.replication_type)
             self.replication_domain = capability.get(
                 'replication_domain')
+            self.sg_consistent_snapshot_support = capability.get(
+                'sg_consistent_snapshot_support')
 
     def update_pools(self, capability):
         # Do nothing, since we don't have pools within pool, yet
@@ -532,7 +562,7 @@ class HostManager(object):
         self.service_states[host] = capability_copy
 
         LOG.debug("Received %(service_name)s service update from "
-                  "%(host)s: %(cap)s" %
+                  "%(host)s: %(cap)s",
                   {'service_name': service_name, 'host': host,
                    'cap': capabilities})
 
@@ -548,7 +578,7 @@ class HostManager(object):
 
             # Warn about down services and remove them from host_state_map
             if not utils.service_is_up(service) or service['disabled']:
-                LOG.warning(_LW("Share service is down. (host: %s).") % host)
+                LOG.warning("Share service is down. (host: %s).", host)
                 continue
 
             # Create and register host_state if not in host_state_map
@@ -569,8 +599,8 @@ class HostManager(object):
         # remove non-active hosts from host_state_map
         nonactive_hosts = set(self.host_state_map.keys()) - active_hosts
         for host in nonactive_hosts:
-            LOG.info(_LI("Removing non-active host: %(host)s from"
-                         "scheduler cache."), {'host': host})
+            LOG.info("Removing non-active host: %(host)s from "
+                     "scheduler cache.", {'host': host})
             self.host_state_map.pop(host, None)
 
     def get_all_host_states_share(self, context):
@@ -594,7 +624,7 @@ class HostManager(object):
                 pool_key = '.'.join([host, pool.pool_name])
                 all_pools[pool_key] = pool
 
-        return six.itervalues(all_pools)
+        return all_pools.values()
 
     def get_pools(self, context, filters=None):
         """Returns a dict of all pools on all hosts HostManager knows about."""
@@ -608,9 +638,9 @@ class HostManager(object):
                     host, pool.pool_name)
                 host_name = share_utils.extract_host(
                     fully_qualified_pool_name, level='host')
-                backend_name = share_utils.extract_host(
-                    fully_qualified_pool_name, level='backend').split('@')[1] \
-                    if '@' in fully_qualified_pool_name else None
+                backend_name = (share_utils.extract_host(
+                    fully_qualified_pool_name, level='backend').split('@')[1]
+                    if '@' in fully_qualified_pool_name else None)
                 pool_name = share_utils.extract_host(
                     fully_qualified_pool_name, level='pool')
 
