@@ -21,15 +21,19 @@ Scheduler Service
 
 from oslo_config import cfg
 from oslo_log import log
+from oslo_service import periodic_task
 from oslo_utils import excutils
 from oslo_utils import importutils
 
 from manila.common import constants
 from manila import context
+from manila import coordination
 from manila import db
 from manila import exception
-from manila.i18n import _LE, _LW
 from manila import manager
+from manila.message import api as message_api
+from manila.message import message_field
+from manila import quota
 from manila import rpc
 from manila.share import rpcapi as share_rpcapi
 
@@ -70,13 +74,14 @@ class SchedulerManager(manager.Manager):
                 'old': scheduler_driver,
                 'new': MAPPING[scheduler_driver],
             }
-            LOG.warning(_LW("Scheduler driver path %(old)s is deprecated, "
-                            "update your configuration to the new path "
-                            "%(new)s"), msg_args)
+            LOG.warning("Scheduler driver path %(old)s is deprecated, "
+                        "update your configuration to the new path "
+                        "%(new)s", msg_args)
             scheduler_driver = MAPPING[scheduler_driver]
 
         self.driver = importutils.import_object(scheduler_driver)
-        super(SchedulerManager, self).__init__(*args, **kwargs)
+        self.message_api = message_api.API()
+        super(self.__class__, self).__init__(*args, **kwargs)
 
     def init_host(self):
         ctxt = context.get_admin_context()
@@ -105,16 +110,15 @@ class SchedulerManager(manager.Manager):
             self.driver.schedule_create_share(context, request_spec,
                                               filter_properties)
         except exception.NoValidHost as ex:
-            self._set_share_state_and_notify('create_share',
-                                             {'status':
-                                              constants.STATUS_ERROR},
-                                             context, ex, request_spec)
+            self._set_share_state_and_notify(
+                'create_share', {'status': constants.STATUS_ERROR},
+                context, ex, request_spec,
+                message_field.Action.ALLOCATE_HOST)
         except Exception as ex:
             with excutils.save_and_reraise_exception():
-                self._set_share_state_and_notify('create_share',
-                                                 {'status':
-                                                  constants.STATUS_ERROR},
-                                                 context, ex, request_spec)
+                self._set_share_state_and_notify(
+                    'create_share', {'status': constants.STATUS_ERROR},
+                    context, ex, request_spec)
 
     def get_pools(self, context, filters=None):
         """Get active pools from the scheduler's cache."""
@@ -187,9 +191,9 @@ class SchedulerManager(manager.Manager):
                     _migrate_share_set_error(self, context, ex, request_spec)
 
     def _set_share_state_and_notify(self, method, state, context, ex,
-                                    request_spec):
+                                    request_spec, action=None):
 
-        LOG.error(_LE("Failed to schedule %(method)s: %(ex)s"),
+        LOG.error("Failed to schedule %(method)s: %(ex)s",
                   {"method": method, "ex": ex})
 
         properties = request_spec.get('share_properties', {})
@@ -199,6 +203,12 @@ class SchedulerManager(manager.Manager):
         if share_id:
             db.share_update(context, share_id, state)
 
+        if action:
+            self.message_api.create(
+                context, action, context.project_id,
+                resource_type=message_field.Resource.SHARE,
+                resource_id=share_id, exception=ex)
+
         payload = dict(request_spec=request_spec,
                        share_properties=properties,
                        share_id=share_id,
@@ -212,8 +222,9 @@ class SchedulerManager(manager.Manager):
     def request_service_capabilities(self, context):
         share_rpcapi.ShareAPI().publish_service_capabilities(context)
 
-    def _set_share_group_error_state(self, method, context, ex, request_spec):
-        LOG.warning(_LW("Failed to schedule_%(method)s: %(ex)s"),
+    def _set_share_group_error_state(self, method, context, ex,
+                                     request_spec, action=None):
+        LOG.warning("Failed to schedule_%(method)s: %(ex)s",
                     {"method": method, "ex": ex})
 
         share_group_state = {'status': constants.STATUS_ERROR}
@@ -223,6 +234,16 @@ class SchedulerManager(manager.Manager):
         if share_group_id:
             db.share_group_update(context, share_group_id, share_group_state)
 
+        if action:
+            self.message_api.create(
+                context, action, context.project_id,
+                resource_type=message_field.Resource.SHARE_GROUP,
+                resource_id=share_group_id, exception=ex)
+
+    @periodic_task.periodic_task(spacing=600, run_immediately=True)
+    def _expire_reservations(self, context):
+        quota.QUOTAS.expire(context)
+
     def create_share_group(self, context, share_group_id, request_spec=None,
                            filter_properties=None):
         try:
@@ -230,16 +251,17 @@ class SchedulerManager(manager.Manager):
                 context, share_group_id, request_spec, filter_properties)
         except exception.NoValidHost as ex:
             self._set_share_group_error_state(
-                'create_share_group', context, ex, request_spec)
+                'create_share_group', context, ex, request_spec,
+                message_field.Action.ALLOCATE_HOST)
         except Exception as ex:
             with excutils.save_and_reraise_exception():
                 self._set_share_group_error_state(
                     'create_share_group', context, ex, request_spec)
 
     def _set_share_replica_error_state(self, context, method, exc,
-                                       request_spec):
+                                       request_spec, action=None):
 
-        LOG.warning(_LW("Failed to schedule_%(method)s: %(exc)s"),
+        LOG.warning("Failed to schedule_%(method)s: %(exc)s",
                     {'method': method, 'exc': exc})
         status_updates = {
             'status': constants.STATUS_ERROR,
@@ -258,6 +280,12 @@ class SchedulerManager(manager.Manager):
 
         db.share_replica_update(context, share_replica_id, status_updates)
 
+        if action:
+            self.message_api.create(
+                context, action, context.project_id,
+                resource_type=message_field.Resource.SHARE_REPLICA,
+                resource_id=share_replica_id, exception=exc)
+
     def create_share_replica(self, context, request_spec=None,
                              filter_properties=None):
         try:
@@ -266,9 +294,16 @@ class SchedulerManager(manager.Manager):
 
         except exception.NoValidHost as exc:
             self._set_share_replica_error_state(
-                context, 'create_share_replica', exc, request_spec)
+                context, 'create_share_replica', exc, request_spec,
+                message_field.Action.ALLOCATE_HOST)
 
         except Exception as exc:
             with excutils.save_and_reraise_exception():
                 self._set_share_replica_error_state(
                     context, 'create_share_replica', exc, request_spec)
+
+    @periodic_task.periodic_task(spacing=CONF.message_reap_interval,
+                                 run_immediately=True)
+    @coordination.synchronized('locked-clean-expired-messages')
+    def _clean_expired_messages(self, context):
+        self.message_api.cleanup_expired_messages(context)
