@@ -26,16 +26,15 @@ from oslo_log import log
 import oslo_messaging as messaging
 from oslo_service import loopingcall
 from oslo_service import service
+from oslo_service import wsgi
 from oslo_utils import importutils
 
 from manila import context
 from manila import coordination
 from manila import db
 from manila import exception
-from manila.i18n import _, _LE, _LI, _LW
 from manila import rpc
 from manila import version
-from manila import wsgi
 
 LOG = log.getLogger(__name__)
 
@@ -51,9 +50,10 @@ service_opts = [
                help='Range of seconds to randomly delay when starting the '
                     'periodic task scheduler to reduce stampeding. '
                     '(Disable by setting to 0)'),
-    cfg.StrOpt('osapi_share_listen',
-               default="::",
-               help='IP address for OpenStack Share API to listen on.'),
+    cfg.HostAddressOpt('osapi_share_listen',
+                       default="::",
+                       help='IP address for OpenStack Share API to listen '
+                            'on.'),
     cfg.PortOpt('osapi_share_listen_port',
                 default=8786,
                 help='Port for OpenStack Share API to listen on.'),
@@ -97,7 +97,7 @@ class Service(service.Service):
 
     def start(self):
         version_string = version.version_string()
-        LOG.info(_LI('Starting %(topic)s node (version %(version_string)s)'),
+        LOG.info('Starting %(topic)s node (version %(version_string)s)',
                  {'topic': self.topic, 'version_string': version_string})
         self.model_disconnected = False
         ctxt = context.get_admin_context()
@@ -200,7 +200,7 @@ class Service(service.Service):
         try:
             db.service_destroy(context.get_admin_context(), self.service_id)
         except exception.NotFound:
-            LOG.warning(_LW('Service killed that has no database entry.'))
+            LOG.warning('Service killed that has no database entry.')
 
     def stop(self):
         # Try to shut the connection down, but if we get any sort of
@@ -218,8 +218,8 @@ class Service(service.Service):
             try:
                 coordination.LOCK_COORDINATOR.stop()
             except Exception:
-                LOG.exception(_LE("Unable to stop the Tooz Locking "
-                                  "Coordinator."))
+                LOG.exception("Unable to stop the Tooz Locking "
+                              "Coordinator.")
 
         self.timers = []
 
@@ -261,13 +261,13 @@ class Service(service.Service):
             # TODO(termie): make this pattern be more elegant.
             if getattr(self, 'model_disconnected', False):
                 self.model_disconnected = False
-                LOG.error(_LE('Recovered model server connection!'))
+                LOG.error('Recovered model server connection!')
 
         # TODO(vish): this should probably only catch connection errors
         except Exception:  # pylint: disable=W0702
             if not getattr(self, 'model_disconnected', False):
                 self.model_disconnected = True
-                LOG.exception(_LE('model server went away'))
+                LOG.exception('model server went away')
 
 
 class WSGIService(service.ServiceBase):
@@ -283,7 +283,7 @@ class WSGIService(service.ServiceBase):
         """
         self.name = name
         self.manager = self._get_manager()
-        self.loader = loader or wsgi.Loader()
+        self.loader = loader or wsgi.Loader(CONF)
         if not rpc.initialized():
             rpc.init(CONF)
         self.app = self.loader.load_app(name)
@@ -292,14 +292,17 @@ class WSGIService(service.ServiceBase):
         self.workers = getattr(CONF, '%s_workers' % name, None)
         if self.workers is not None and self.workers < 1:
             LOG.warning(
-                _LW("Value of config option %(name)s_workers must be integer "
-                    "greater than 1.  Input value ignored.") % {'name': name})
+                "Value of config option %(name)s_workers must be integer "
+                "greater than 1.  Input value ignored.", {'name': name})
             # Reset workers to default
             self.workers = None
-        self.server = wsgi.Server(name,
-                                  self.app,
-                                  host=self.host,
-                                  port=self.port)
+        self.server = wsgi.Server(
+            CONF,
+            name,
+            self.app,
+            host=self.host,
+            port=self.port,
+        )
 
     def _get_manager(self):
         """Initialize a Manager object appropriate for this service.
@@ -373,12 +376,22 @@ _launcher = None
 def serve(server, workers=None):
     global _launcher
     if _launcher:
-        raise RuntimeError(_('serve() can only be called once'))
+        raise RuntimeError('serve() can only be called once')
     _launcher = service.launch(CONF, server, workers=workers)
 
 
 def wait():
-    CONF.log_opt_values(LOG, log.DEBUG)
+    LOG.debug('Full set of CONF:')
+    for flag in CONF:
+        flag_get = CONF.get(flag, None)
+        # hide flag contents from log if contains a password
+        # should use secret flag when switch over to openstack-common
+        if ("_password" in flag or "_key" in flag or
+                (flag == "sql_connection" and "mysql:" in flag_get)):
+            LOG.debug('%(flag)s : FLAG SET ', {"flag": flag})
+        else:
+            LOG.debug('%(flag)s : %(flag_get)s',
+                      {"flag": flag, "flag_get": flag_get})
     try:
         _launcher.wait()
     except KeyboardInterrupt:
