@@ -27,15 +27,15 @@ if storops:
 
 from manila.common import constants as const
 from manila import exception
-from manila.i18n import _, _LE, _LW, _LI
+from manila.i18n import _
+from manila.share.drivers.dell_emc.common.enas import utils as enas_utils
 from manila.share.drivers.dell_emc.plugins import base as driver
 from manila.share.drivers.dell_emc.plugins.unity import client
 from manila.share.drivers.dell_emc.plugins.unity import utils as unity_utils
-from manila.share.drivers.dell_emc.plugins.vnx import utils as emc_utils
 from manila.share import utils as share_utils
 from manila import utils
 
-VERSION = "2.0.0"
+VERSION = "3.0.0"
 
 LOG = log.getLogger(__name__)
 SUPPORTED_NETWORK_TYPES = (None, 'flat', 'vlan')
@@ -64,14 +64,14 @@ CONF = cfg.CONF
 CONF.register_opts(UNITY_OPTS)
 
 
-@emc_utils.decorate_all_methods(emc_utils.log_enter_exit,
-                                debug_only=True)
+@enas_utils.decorate_all_methods(enas_utils.log_enter_exit,
+                                 debug_only=True)
 class UnityStorageConnection(driver.StorageConnection):
     """Implements Unity specific functionality for EMC Manila driver."""
 
     IP_ALLOCATIONS = 1
 
-    @emc_utils.log_enter_exit
+    @enas_utils.log_enter_exit
     def __init__(self, *args, **kwargs):
         super(UnityStorageConnection, self).__init__(*args, **kwargs)
         if 'configuration' in kwargs:
@@ -127,9 +127,9 @@ class UnityStorageConnection(driver.StorageConnection):
             raise exception.BadConfigurationException(reason=msg)
 
         if unmanaged_port_ids:
-            LOG.info(_LI("The following specified ports are not managed by "
-                         "the backend: %(unmanaged)s. This host will only "
-                         "manage the storage ports: %(exist)s"),
+            LOG.info("The following specified ports are not managed by "
+                     "the backend: %(unmanaged)s. This host will only "
+                     "manage the storage ports: %(exist)s",
                      {'unmanaged': ",".join(unmanaged_port_ids),
                       'exist': ",".join(map(",".join,
                                             sp_ports_map.values()))})
@@ -138,8 +138,8 @@ class UnityStorageConnection(driver.StorageConnection):
                       ",".join(map(",".join, sp_ports_map.values())))
 
         if len(sp_ports_map) == 1:
-            LOG.info(_LI("Only ports of %s are configured. Configure ports "
-                         "of both SPA and SPB to use both of the SPs."),
+            LOG.info("Only ports of %s are configured. Configure ports "
+                     "of both SPA and SPB to use both of the SPs.",
                      list(sp_ports_map)[0])
 
         return sp_ports_map
@@ -213,8 +213,7 @@ class UnityStorageConnection(driver.StorageConnection):
             raise exception.EMCUnityError(err=message)
 
         backend_snap = self.client.create_snap_of_snap(snapshot['id'],
-                                                       share_name,
-                                                       snap_type='snapshot')
+                                                       share_name)
 
         locations = None
         if share_proto == 'CIFS':
@@ -237,7 +236,7 @@ class UnityStorageConnection(driver.StorageConnection):
             backend_share = self.client.get_share(share_name,
                                                   share['share_proto'])
         except storops_ex.UnityResourceNotFoundError:
-            LOG.warning(_LW("Share %s is not found when deleting the share"),
+            LOG.warning("Share %s is not found when deleting the share",
                         share_name)
             return
 
@@ -261,8 +260,8 @@ class UnityStorageConnection(driver.StorageConnection):
                                           new_size)
         else:
             share_id = share['id']
-            reason = _LE("Driver does not support extending a "
-                         "snapshot based share.")
+            reason = ("Driver does not support extending a "
+                      "snapshot based share.")
             raise exception.ShareExtendingError(share_id=share_id,
                                                 reason=reason)
 
@@ -274,9 +273,7 @@ class UnityStorageConnection(driver.StorageConnection):
 
         snapshot_name = snapshot['id']
         if self._is_share_from_snapshot(backend_share):
-            self.client.create_snap_of_snap(backend_share.snap,
-                                            snapshot_name,
-                                            snap_type='checkpoint')
+            self.client.create_snap_of_snap(backend_share.snap, snapshot_name)
         else:
             self.client.create_snapshot(backend_share.filesystem,
                                         snapshot_name)
@@ -422,7 +419,7 @@ class UnityStorageConnection(driver.StorageConnection):
 
         except Exception:
             with excutils.save_and_reraise_exception():
-                LOG.exception(_LE('Could not setup server.'))
+                LOG.exception('Could not setup server.')
                 server_details = {'share_server_name': server_name}
                 self.teardown_server(
                     server_details, network_info['security_services'])
@@ -538,10 +535,10 @@ class UnityStorageConnection(driver.StorageConnection):
             raise exception.BadConfigurationException(reason=msg)
 
         if unmanaged_pools:
-            LOG.info(_LI("The following specified storage pools "
-                         "are not managed by the backend: "
-                         "%(un_managed)s. This host will only manage "
-                         "the storage pools: %(exist)s"),
+            LOG.info("The following specified storage pools "
+                     "are not managed by the backend: "
+                     "%(un_managed)s. This host will only manage "
+                     "the storage pools: %(exist)s",
                      {'un_managed': ",".join(unmanaged_pools),
                       'exist': ",".join(matched_pools)})
         else:
@@ -621,13 +618,13 @@ class UnityStorageConnection(driver.StorageConnection):
                 # Enable NFS service with kerberos
                 kerberos_enabled = True
                 # TODO(jay.xu): enable nfs service with kerberos
-                LOG.warning(_LW('Kerberos is not supported by '
-                                'EMC Unity manila driver plugin.'))
+                LOG.warning('Kerberos is not supported by '
+                            'EMC Unity manila driver plugin.')
             elif service_type == 'ldap':
-                LOG.warning(_LW('LDAP is not supported by '
-                                'EMC Unity manila driver plugin.'))
+                LOG.warning('LDAP is not supported by '
+                            'EMC Unity manila driver plugin.')
             else:
-                LOG.warning(_LW('Unknown security service type: %s.'),
+                LOG.warning('Unknown security service type: %s.',
                             service_type)
 
         if not kerberos_enabled:
