@@ -24,15 +24,21 @@ from oslo_utils import units
 
 from manila.common import constants as const
 from manila import exception
-from manila.i18n import _, _LE, _LI, _LW
+from manila.i18n import _
+from manila.share.drivers.dell_emc.common.enas import constants
+from manila.share.drivers.dell_emc.common.enas import utils as enas_utils
 from manila.share.drivers.dell_emc.plugins import base as driver
-from manila.share.drivers.dell_emc.plugins.vnx import constants
 from manila.share.drivers.dell_emc.plugins.vnx import object_manager as manager
-from manila.share.drivers.dell_emc.plugins.vnx import utils as vnx_utils
 from manila.share import utils as share_utils
 from manila import utils
 
-VERSION = "2.0.0"
+"""Version history:
+    1.0.0 - Initial version (Liberty)
+    2.0.0 - Bumped the version for Mitaka
+    3.0.0 - Bumped the version for Ocata
+    4.0.0 - Bumped the version for Pike
+"""
+VERSION = "4.0.0"
 
 LOG = log.getLogger(__name__)
 
@@ -55,12 +61,12 @@ CONF = cfg.CONF
 CONF.register_opts(VNX_OPTS)
 
 
-@vnx_utils.decorate_all_methods(vnx_utils.log_enter_exit,
-                                debug_only=True)
+@enas_utils.decorate_all_methods(enas_utils.log_enter_exit,
+                                 debug_only=True)
 class VNXStorageConnection(driver.StorageConnection):
     """Implements VNX specific functionality for EMC Manila driver."""
 
-    @vnx_utils.log_enter_exit
+    @enas_utils.log_enter_exit
     def __init__(self, *args, **kwargs):
         super(VNXStorageConnection, self).__init__(*args, **kwargs)
         if 'configuration' in kwargs:
@@ -156,7 +162,7 @@ class VNXStorageConnection(driver.StorageConnection):
         self._get_context('FileSystem').extend(share['id'], pool_name,
                                                nwe_size)
 
-    @vnx_utils.log_enter_exit
+    @enas_utils.log_enter_exit
     def _create_cifs_share(self, share_name, share_server):
         """Create CIFS share."""
         vdm_name = self._get_share_server_name(share_server)
@@ -186,7 +192,7 @@ class VNXStorageConnection(driver.StorageConnection):
 
         return location
 
-    @vnx_utils.log_enter_exit
+    @enas_utils.log_enter_exit
     def _create_nfs_share(self, share_name, share_server):
         """Create NFS share."""
         vdm_name = self._get_share_server_name(share_server)
@@ -250,9 +256,9 @@ class VNXStorageConnection(driver.StorageConnection):
     def delete_share(self, context, share, share_server=None):
         """Delete a share."""
         if share_server is None:
-            LOG.warning(_LW("Driver does not support share deletion without "
-                            "share network specified. Return directly because "
-                            "there is nothing to clean."))
+            LOG.warning("Driver does not support share deletion without "
+                        "share network specified. Return directly because "
+                        "there is nothing to clean.")
             return
 
         share_proto = share['share_proto']
@@ -265,7 +271,7 @@ class VNXStorageConnection(driver.StorageConnection):
             raise exception.InvalidShare(
                 reason='Unsupported share type')
 
-    @vnx_utils.log_enter_exit
+    @enas_utils.log_enter_exit
     def _delete_cifs_share(self, share, share_server):
         """Delete CIFS share."""
         vdm_name = self._get_share_server_name(share_server)
@@ -276,7 +282,7 @@ class VNXStorageConnection(driver.StorageConnection):
 
         self._deallocate_container(name, vdm_name)
 
-    @vnx_utils.log_enter_exit
+    @enas_utils.log_enter_exit
     def _delete_nfs_share(self, share, share_server):
         """Delete NFS share."""
         vdm_name = self._get_share_server_name(share_server)
@@ -287,7 +293,7 @@ class VNXStorageConnection(driver.StorageConnection):
 
         self._deallocate_container(name, vdm_name)
 
-    @vnx_utils.log_enter_exit
+    @enas_utils.log_enter_exit
     def _deallocate_container(self, share_name, vdm_name):
         """Delete underneath objects of the share."""
         path = '/' + share_name
@@ -342,7 +348,7 @@ class VNXStorageConnection(driver.StorageConnection):
                 reason=(_('Invalid NAS protocol supplied: %s.')
                         % share_proto))
 
-    @vnx_utils.log_enter_exit
+    @enas_utils.log_enter_exit
     def _cifs_allow_access(self, context, share, access, share_server):
         """Allow access to CIFS share."""
         vdm_name = self._get_share_server_name(share_server)
@@ -376,7 +382,7 @@ class VNXStorageConnection(driver.StorageConnection):
             server['domain'],
             access=cifs_access)
 
-    @vnx_utils.log_enter_exit
+    @enas_utils.log_enter_exit
     def _nfs_allow_access(self, context, share, access, share_server):
         """Allow access to NFS share."""
         vdm_name = self._get_share_server_name(share_server)
@@ -418,7 +424,7 @@ class VNXStorageConnection(driver.StorageConnection):
         elif share_proto == 'NFS':
             self._nfs_clear_access(share_name, share_server, white_list)
 
-    @vnx_utils.log_enter_exit
+    @enas_utils.log_enter_exit
     def _cifs_clear_access(self, share_name, share_server, white_list):
         """Clear access for CIFS share except hosts in the white list."""
         vdm_name = self._get_share_server_name(share_server)
@@ -439,7 +445,7 @@ class VNXStorageConnection(driver.StorageConnection):
             domain=server['domain'],
             white_list_users=white_list)
 
-    @vnx_utils.log_enter_exit
+    @enas_utils.log_enter_exit
     def _nfs_clear_access(self, share_name, share_server, white_list):
         """Clear access for NFS share except hosts in the white list."""
         self._get_context('NFSShare').clear_share_access(
@@ -459,7 +465,7 @@ class VNXStorageConnection(driver.StorageConnection):
             raise exception.InvalidShare(
                 reason=_('Unsupported share type'))
 
-    @vnx_utils.log_enter_exit
+    @enas_utils.log_enter_exit
     def _cifs_deny_access(self, share, access, share_server):
         """Deny access to CIFS share."""
         vdm_name = self._get_share_server_name(share_server)
@@ -493,7 +499,7 @@ class VNXStorageConnection(driver.StorageConnection):
             server['domain'],
             access=cifs_access)
 
-    @vnx_utils.log_enter_exit
+    @enas_utils.log_enter_exit
     def _nfs_deny_access(self, share, access, share_server):
         """Deny access to NFS share."""
         vdm_name = self._get_share_server_name(share_server)
@@ -534,7 +540,7 @@ class VNXStorageConnection(driver.StorageConnection):
 
             real_pools = set([item for item in backend_pools])
             conf_pools = set([item.strip() for item in pools])
-            matched_pools, unmatched_pools = vnx_utils.do_match_any(
+            matched_pools, unmatched_pools = enas_utils.do_match_any(
                 real_pools, conf_pools)
 
             if not matched_pools:
@@ -545,7 +551,7 @@ class VNXStorageConnection(driver.StorageConnection):
                        ",".join(real_pools))
                 raise exception.InvalidParameterValue(err=msg)
 
-            LOG.info(_LI("Storage pools: %s will be managed."),
+            LOG.info("Storage pools: %s will be managed.",
                      ",".join(matched_pools))
         else:
             LOG.debug("No storage pool is specified, so all pools "
@@ -576,7 +582,7 @@ class VNXStorageConnection(driver.StorageConnection):
                       "Data Mover can be used.")
             return real_ports
 
-        matched_ports, unmanaged_ports = vnx_utils.do_match_any(
+        matched_ports, unmanaged_ports = enas_utils.do_match_any(
             real_ports, self.port_conf)
 
         if not matched_ports:
@@ -711,7 +717,7 @@ class VNXStorageConnection(driver.StorageConnection):
 
         except Exception:
             with excutils.save_and_reraise_exception():
-                LOG.exception(_LE('Could not setup server.'))
+                LOG.exception('Could not setup server.')
                 server_details = self._construct_backend_details(
                     vdm_name, allocated_interfaces)
                 self.teardown_server(
@@ -728,7 +734,7 @@ class VNXStorageConnection(driver.StorageConnection):
             'nfs_if': nfs_if,
         }
 
-    @vnx_utils.log_enter_exit
+    @enas_utils.log_enter_exit
     def _vdm_exist(self, name):
         status, out = self._get_context('VDM').get(name)
         if constants.STATUS_OK != status:
@@ -799,7 +805,7 @@ class VNXStorageConnection(driver.StorageConnection):
                 status, servers = self._get_context('CIFSServer').get_all(
                     vdm_name)
                 if constants.STATUS_OK != status:
-                    LOG.error(_LE('Could not find CIFS server by name: %s.'),
+                    LOG.error('Could not find CIFS server by name: %s.',
                               vdm_name)
                 else:
                     cifs_servers = copy.deepcopy(servers)
