@@ -24,7 +24,6 @@ import six
 
 from manila import exception
 from manila.i18n import _
-from manila.i18n import _LE
 from manila.share.drivers.ganesha import utils as ganesha_utils
 from manila import utils
 
@@ -131,36 +130,70 @@ def _dump_to_conf(confdict, out=sys.stdout, indent=0):
         for k, v in confdict.items():
             if v is None:
                 continue
-            out.write(' ' * (indent * IWIDTH) + k + ' ')
             if isinstance(v, dict):
+                out.write(' ' * (indent * IWIDTH) + k + ' ')
                 out.write("{\n")
                 _dump_to_conf(v, out, indent + 1)
                 out.write(' ' * (indent * IWIDTH) + '}')
+            elif isinstance(v, list):
+                for item in v:
+                    out.write(' ' * (indent * IWIDTH) + k + ' ')
+                    out.write("{\n")
+                    _dump_to_conf(item, out, indent + 1)
+                    out.write(' ' * (indent * IWIDTH) + '}\n')
+            # The 'CLIENTS' Ganesha string option is an exception in that it's
+            # string value can't be enclosed within quotes as can be done for
+            # other string options in a valid Ganesha conf file.
+            elif k.upper() == 'CLIENTS':
+                out.write(' ' * (indent * IWIDTH) + k + ' = ' + v + ';')
             else:
+                out.write(' ' * (indent * IWIDTH) + k + ' ')
                 out.write('= ')
                 _dump_to_conf(v, out, indent)
                 out.write(';')
             out.write('\n')
     else:
         dj = jsonutils.dumps(confdict)
-        if confdict == dj[1:-1]:
-            out.write(confdict)
-        else:
-            out.write(dj)
+        out.write(dj)
 
 
 def parseconf(conf):
     """Parse Ganesha config.
 
     Both native format and JSON are supported.
+
+    Convert config to a (nested) dictionary.
     """
+    def list_to_dict(l):
+        # Convert a list of key-value pairs stored as tuples to a dict.
+        # For tuples with identical keys, preserve all the values in a
+        # list. e.g., argument [('k', 'v1'), ('k', 'v2')] to function
+        # returns {'k': ['v1', 'v2']}.
+        d = {}
+        for i in l:
+            if isinstance(i, tuple):
+                k, v = i
+                if isinstance(v, list):
+                    v = list_to_dict(v)
+                if k in d:
+                    d[k] = [d[k]]
+                    d[k].append(v)
+                else:
+                    d[k] = v
+        return d
 
     try:
         # allow config to be specified in JSON --
         # for sake of people who might feel Ganesha config foreign.
         d = jsonutils.loads(conf)
     except ValueError:
-        d = jsonutils.loads(_conf2json(conf))
+        # Customize JSON decoder to convert Ganesha config to a list
+        # of key-value pairs stored as tuples. This allows multiple
+        # occurrences of a config block to be later converted to a
+        # dict key-value pair, with block name being the key and a
+        # list of block contents being the value.
+        l = jsonutils.loads(_conf2json(conf), object_pairs_hook=lambda x: x)
+        d = list_to_dict(l)
     return d
 
 
@@ -187,8 +220,8 @@ class GaneshaManager(object):
             except exception.ProcessExecutionError as e:
                 if makelog:
                     LOG.error(
-                        _LE("Error while executing management command on "
-                            "Ganesha node %(tag)s: %(msg)s."),
+                        ("Error while executing management command on "
+                         "Ganesha node %(tag)s: %(msg)s."),
                         {'tag': tag, 'msg': msg})
                 raise exception.GaneshaCommandFailure(
                     stdout=e.stdout, stderr=e.stderr, exit_code=e.exit_code,
@@ -252,6 +285,18 @@ class GaneshaManager(object):
         return parseconf(self.execute("cat", self._getpath(name),
                                       message='reading export ' + name)[0])
 
+    def _check_export_file_exists(self, name):
+        """Check whether export exists."""
+        try:
+            self.execute('test', '-f', self._getpath(name), makelog=False,
+                         run_as_root=False)
+            return True
+        except exception.GaneshaCommandFailure as e:
+            if e.exit_code == 1:
+                return False
+            else:
+                raise
+
     def _write_export_file(self, name, confdict):
         """Write confdict to the export file of name."""
         for k, v in ganesha_utils.walk(confdict):
@@ -301,6 +346,20 @@ class GaneshaManager(object):
                 self._mkindex()
             raise
 
+    def update_export(self, name, confdict):
+        """Update an export to Ganesha specified by confdict."""
+        xid = confdict["EXPORT"]["Export_Id"]
+        old_confdict = self._read_export_file(name)
+
+        path = self._write_export_file(name, confdict)
+        try:
+            self._dbus_send_ganesha("UpdateExport", "string:" + path,
+                                    "string:EXPORT(Export_Id=%d)" % xid)
+        except Exception:
+            # Revert the export file update.
+            self._write_export_file(name, old_confdict)
+            raise
+
     def remove_export(self, name):
         """Remove an export from Ganesha."""
         try:
@@ -324,8 +383,8 @@ class GaneshaManager(object):
             run_as_root=False)[0]
         match = re.search('\Aexportid\|(\d+)$', out)
         if not match:
-            LOG.error(_LE("Invalid export database on "
-                      "Ganesha node %(tag)s: %(db)s."),
+            LOG.error("Invalid export database on "
+                      "Ganesha node %(tag)s: %(db)s.",
                       {'tag': self.tag, 'db': self.ganesha_db_path})
             raise exception.InvalidSqliteDB()
         return int(match.groups()[0])
