@@ -30,7 +30,7 @@ from manila.common import constants as const
 from manila import compute
 from manila import context
 from manila import exception
-from manila.i18n import _, _LE, _LI, _LW
+from manila.i18n import _
 from manila.share import driver
 from manila.share.drivers import service_instance
 from manila import utils
@@ -193,11 +193,11 @@ class GenericShareDriver(driver.ExecuteMixin, driver.ShareDriver):
 
             if not common_sv_available:
                 time.sleep(sv_fetch_retry_interval)
-                LOG.warning(_LW("Waiting for the common service VM to become "
-                                "available. "
-                                "Driver is currently uninitialized. "
-                                "Share server: %(share_server)s "
-                                "Retry interval: %(retry_interval)s"),
+                LOG.warning("Waiting for the common service VM to become "
+                            "available. "
+                            "Driver is currently uninitialized. "
+                            "Share server: %(share_server)s "
+                            "Retry interval: %(retry_interval)s",
                             dict(share_server=share_server,
                                  retry_interval=sv_fetch_retry_interval))
 
@@ -285,40 +285,23 @@ class GenericShareDriver(driver.ExecuteMixin, driver.ShareDriver):
                     return True
         return False
 
-    def _add_mount_permanently(self, share_id, server_details):
-        """Add mount permanently for mounted filesystems."""
+    def _sync_mount_temp_and_perm_files(self, server_details):
+        """Sync temporary and permanent files for mounted filesystems."""
         try:
             self._ssh_exec(
                 server_details,
-                ['grep', share_id, const.MOUNT_FILE_TEMP,
-                 '|', 'sudo', 'tee', '-a', const.MOUNT_FILE],
+                ['sudo', 'cp', const.MOUNT_FILE_TEMP, const.MOUNT_FILE],
             )
         except exception.ProcessExecutionError as e:
-            LOG.error(_LE("Failed to add 'Share-%(share_id)s' mount "
-                      "permanently on server '%(instance_id)s'."),
-                      {"share_id": share_id,
-                       "instance_id": server_details['instance_id']})
+            LOG.error("Failed to sync mount files on server '%s'.",
+                      server_details['instance_id'])
             raise exception.ShareBackendException(msg=six.text_type(e))
         try:
             # Remount it to avoid postponed point of failure
             self._ssh_exec(server_details, ['sudo', 'mount', '-a'])
         except exception.ProcessExecutionError as e:
-            LOG.error(_LE("Failed to mount all shares on server '%s'."),
+            LOG.error("Failed to mount all shares on server '%s'.",
                       server_details['instance_id'])
-
-    def _remove_mount_permanently(self, share_id, server_details):
-        """Remove mount permanently from mounted filesystems."""
-        try:
-            self._ssh_exec(
-                server_details,
-                ['sudo', 'sed', '-i', '\'/%s/d\'' % share_id,
-                 const.MOUNT_FILE],
-            )
-        except exception.ProcessExecutionError as e:
-            LOG.error(_LE("Failed to remove 'Share-%(share_id)s' mount "
-                      "permanently on server '%(instance_id)s'."),
-                      {"share_id": share_id,
-                       "instance_id": server_details['instance_id']})
             raise exception.ShareBackendException(msg=six.text_type(e))
 
     def _mount_device(self, share, server_details, volume):
@@ -359,10 +342,12 @@ class GenericShareDriver(driver.ExecuteMixin, driver.ShareDriver):
                         '&&', 'sudo', 'mount', device_path, mount_path,
                     )
                     self._ssh_exec(server_details, mount_cmd)
-                    self._add_mount_permanently(share.id, server_details)
+
+                    # Add mount permanently
+                    self._sync_mount_temp_and_perm_files(server_details)
                 else:
-                    LOG.warning(_LW("Mount point '%(path)s' already exists on "
-                                    "server '%(server)s'."), log_data)
+                    LOG.warning("Mount point '%(path)s' already exists on "
+                                "server '%(server)s'.", log_data)
             except exception.ProcessExecutionError as e:
                 raise exception.ShareBackendException(msg=six.text_type(e))
         return _mount_device_with_lock()
@@ -385,10 +370,11 @@ class GenericShareDriver(driver.ExecuteMixin, driver.ShareDriver):
                 unmount_cmd = ['sudo', 'umount', mount_path, '&&', 'sudo',
                                'rmdir', mount_path]
                 self._ssh_exec(server_details, unmount_cmd)
-                self._remove_mount_permanently(share.id, server_details)
+                # Remove mount permanently
+                self._sync_mount_temp_and_perm_files(server_details)
             else:
-                LOG.warning(_LW("Mount point '%(path)s' does not exist on "
-                                "server '%(server)s'."), log_data)
+                LOG.warning("Mount point '%(path)s' does not exist on "
+                            "server '%(server)s'.", log_data)
         return _unmount_device_with_lock()
 
     def _get_mount_path(self, share):
@@ -463,10 +449,10 @@ class GenericShareDriver(driver.ExecuteMixin, driver.ShareDriver):
             return volumes_list[0]
         elif len(volumes_list) > 1:
             LOG.error(
-                _LE("Expected only one volume in volume list with name "
-                    "'%(name)s', but got more than one in a result - "
-                    "'%(result)s'."), {
-                        'name': volume_name, 'result': volumes_list})
+                "Expected only one volume in volume list with name "
+                "'%(name)s', but got more than one in a result - "
+                "'%(result)s'.", {
+                    'name': volume_name, 'result': volumes_list})
             raise exception.ManilaException(
                 _("Error. Ambiguous volumes for name '%s'") % volume_name)
         return None
@@ -493,11 +479,11 @@ class GenericShareDriver(driver.ExecuteMixin, driver.ShareDriver):
             volume_snapshot = volume_snapshot_list[0]
         elif len(volume_snapshot_list) > 1:
             LOG.error(
-                _LE("Expected only one volume snapshot in list with name "
-                    "'%(name)s', but got more than one in a result - "
-                    "'%(result)s'."), {
-                        'name': volume_snapshot_name,
-                        'result': volume_snapshot_list})
+                "Expected only one volume snapshot in list with name"
+                "'%(name)s', but got more than one in a result - "
+                "'%(result)s'.", {
+                    'name': volume_snapshot_name,
+                    'result': volume_snapshot_list})
             raise exception.ManilaException(
                 _('Error. Ambiguous volume snaphots'))
         return volume_snapshot
@@ -515,8 +501,8 @@ class GenericShareDriver(driver.ExecuteMixin, driver.ShareDriver):
             try:
                 volume = self._get_volume(context, share['id'])
             except exception.VolumeNotFound:
-                LOG.warning(_LW("Volume not found for share %s. "
-                                "Possibly already deleted."), share['id'])
+                LOG.warning("Volume not found for share %s. "
+                            "Possibly already deleted.", share['id'])
                 volume = None
             if volume and volume['id'] in attached_volumes:
                 self.compute_api.instance_volume_detach(
@@ -601,7 +587,7 @@ class GenericShareDriver(driver.ExecuteMixin, driver.ShareDriver):
         try:
             volume = self._get_volume(context, share['id'])
         except exception.VolumeNotFound:
-            LOG.info(_LI("Volume not found. Already deleted?"))
+            LOG.info("Volume not found. Already deleted?")
             volume = None
         if volume:
             if volume['status'] == 'in-use':
@@ -765,7 +751,8 @@ class GenericShareDriver(driver.ExecuteMixin, driver.ShareDriver):
     def create_snapshot(self, context, snapshot, share_server=None):
         """Creates a snapshot."""
         model_update = {}
-        volume = self._get_volume(self.admin_context, snapshot['share_id'])
+        volume = self._get_volume(
+            self.admin_context, snapshot['share_instance_id'])
         volume_snapshot_name = (self.configuration.
                                 volume_snapshot_name_template % snapshot['id'])
         volume_snapshot = self.volume_api.create_snapshot_force(
@@ -886,7 +873,7 @@ class GenericShareDriver(driver.ExecuteMixin, driver.ShareDriver):
 
     def _setup_server(self, network_info, metadata=None):
         msg = "Creating share server '%s'."
-        LOG.debug(msg % network_info['server_id'])
+        LOG.debug(msg, network_info['server_id'])
         server = self.service_instance_manager.set_up_service_instance(
             self.admin_context, network_info)
         for helper in self._helpers.values():
@@ -958,7 +945,7 @@ class GenericShareDriver(driver.ExecuteMixin, driver.ShareDriver):
 
             linked_volume_name = self._get_volume_name(share['id'])
             if share_volume['name'] != linked_volume_name:
-                LOG.debug('Manage: volume_id = %s' % share_volume['id'])
+                LOG.debug('Manage: volume_id = %s', share_volume['id'])
                 self.volume_api.update(self.admin_context, share_volume['id'],
                                        {'name': linked_volume_name})
 
