@@ -13,14 +13,17 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import copy
+import ipaddress
 import os
 import re
+import six
 
 from oslo_log import log
 
 from manila.common import constants as const
 from manila import exception
-from manila.i18n import _, _LW
+from manila.i18n import _
 from manila import utils
 
 LOG = log.getLogger(__name__)
@@ -37,12 +40,12 @@ class NASHelperBase(object):
     def init_helper(self, server):
         pass
 
-    def create_export(self, server, share_name, recreate=False):
-        """Create new export, delete old one if exists."""
+    def create_exports(self, server, share_name, recreate=False):
+        """Create new exports, delete old ones if exist."""
         raise NotImplementedError()
 
-    def remove_export(self, server, share_name):
-        """Remove export."""
+    def remove_exports(self, server, share_name):
+        """Remove exports."""
         raise NotImplementedError()
 
     def configure_access(self, server, share_name):
@@ -76,14 +79,58 @@ class NASHelperBase(object):
 
     @staticmethod
     def _verify_server_has_public_address(server):
-        if 'public_address' not in server:
+        if 'public_address' in server:
+            pass
+        elif 'public_addresses' in server:
+            if not isinstance(server['public_addresses'], list):
+                raise exception.ManilaException(_("public_addresses must be "
+                                                  "a list"))
+        else:
             raise exception.ManilaException(
-                _("Can not get 'public_address' for generation of export."))
+                _("Can not get public_address(es) for generation of export."))
 
-    def get_exports_for_share(self, server, old_export_location):
-        """Returns list of exports based on server info."""
+    def _get_export_location_template(self, export_location_or_path):
+        """Returns template of export location.
+
+        Example for NFS:
+            %s:/path/to/share
+        Example for CIFS:
+            \\\\%s\\cifs_share_name
+        """
         raise NotImplementedError()
 
+    def get_exports_for_share(self, server, export_location_or_path):
+        """Returns list of exports based on server info."""
+        self._verify_server_has_public_address(server)
+        export_location_template = self._get_export_location_template(
+            export_location_or_path)
+        export_locations = []
+
+        if 'public_addresses' in server:
+            pairs = list(map(lambda addr: (addr, False),
+                             server['public_addresses']))
+        else:
+            pairs = [(server['public_address'], False)]
+
+        # NOTE(vponomaryov):
+        # Generic driver case: 'admin_ip' exists only in case of DHSS=True
+        # mode and 'ip' exists in case of DHSS=False mode.
+        # Use one of these for creation of export location for service needs.
+        service_address = server.get("admin_ip", server.get("ip"))
+        if service_address:
+            pairs.append((service_address, True))
+        for ip, is_admin in pairs:
+            export_locations.append({
+                "path": export_location_template % ip,
+                "is_admin_only": is_admin,
+                "metadata": {
+                    # TODO(vponomaryov): remove this fake metadata when
+                    # proper appears.
+                    "export_location_metadata_example": "example",
+                },
+            })
+        return export_locations
+
     def get_share_path_by_export_location(self, server, export_location):
         """Returns share path by its export location."""
         raise NotImplementedError()
@@ -137,11 +184,30 @@ def nfs_synchronized(f):
 class NFSHelper(NASHelperBase):
     """Interface to work with share."""
 
-    def create_export(self, server, share_name, recreate=False):
-        """Create new export, delete old one if exists."""
-        return ':'.join((server['public_address'],
-                         os.path.join(
-                             self.configuration.share_mount_path, share_name)))
+    def create_exports(self, server, share_name, recreate=False):
+        path = os.path.join(self.configuration.share_mount_path, share_name)
+        server_copy = copy.copy(server)
+        public_addresses = []
+        if 'public_addresses' in server_copy:
+            for address in server_copy['public_addresses']:
+                public_addresses.append(
+                    self._escaped_address(address))
+            server_copy['public_addresses'] = public_addresses
+
+        for t in ['public_address', 'admin_ip', 'ip']:
+            address = server_copy.get(t)
+            if address is not None:
+                server_copy[t] = self._escaped_address(address)
+
+        return self.get_exports_for_share(server_copy, path)
+
+    @staticmethod
+    def _escaped_address(address):
+        addr = ipaddress.ip_address(six.text_type(address))
+        if addr.version == 4:
+            return six.text_type(addr)
+        else:
+            return '[%s]' % six.text_type(addr)
 
     def init_helper(self, server):
         try:
@@ -153,14 +219,8 @@ class NFSHelper(NASHelperBase):
                     % server['instance_id'])
             LOG.error(e.stderr)
 
-    def remove_export(self, server, share_name):
-        """Remove export."""
-
-    def _get_parsed_access_to(self, access_to):
-        netmask = utils.cidr_to_netmask(access_to)
-        if netmask == '255.255.255.255':
-            return access_to.split('/')[0]
-        return access_to.split('/')[0] + '/' + netmask
+    def remove_exports(self, server, share_name):
+        """Remove exports."""
 
     @nfs_synchronized
     def update_access(self, server, share_name, access_rules, add_rules,
@@ -179,7 +239,7 @@ class NFSHelper(NASHelperBase):
                 access_rules, ('ip',),
                 (const.ACCESS_LEVEL_RO, const.ACCESS_LEVEL_RW))
 
-            hosts = self._get_host_list(out, local_path)
+            hosts = self.get_host_list(out, local_path)
             for host in hosts:
                 self._ssh_exec(server, ['sudo', 'exportfs', '-u',
                                         ':'.join((host, local_path))])
@@ -188,12 +248,13 @@ class NFSHelper(NASHelperBase):
                 rules_options = '%s,no_subtree_check'
                 if access['access_level'] == const.ACCESS_LEVEL_RW:
                     rules_options = ','.join((rules_options, 'no_root_squash'))
+                access_to = self._get_parsed_address_or_cidr(
+                    access['access_to'])
                 self._ssh_exec(
                     server,
                     ['sudo', 'exportfs', '-o',
                      rules_options % access['access_level'],
-                     ':'.join((self._get_parsed_access_to(access['access_to']),
-                               local_path))])
+                     ':'.join((access_to, local_path))])
             self._sync_nfs_temp_and_perm_files(server)
         # Adding/Deleting specific rules
         else:
@@ -203,7 +264,7 @@ class NFSHelper(NASHelperBase):
                 (const.ACCESS_LEVEL_RO, const.ACCESS_LEVEL_RW))
 
             for access in delete_rules:
-                access['access_to'] = self._get_parsed_access_to(
+                access_to = self._get_parsed_address_or_cidr(
                     access['access_to'])
                 try:
                     self.validate_access_rules(
@@ -211,30 +272,30 @@ class NFSHelper(NASHelperBase):
                         (const.ACCESS_LEVEL_RO, const.ACCESS_LEVEL_RW))
                 except (exception.InvalidShareAccess,
                         exception.InvalidShareAccessLevel):
-                    LOG.warning(_LW(
+                    LOG.warning(
                         "Unsupported access level %(level)s or access type "
                         "%(type)s, skipping removal of access rule to "
-                        "%(to)s.") % {'level': access['access_level'],
-                                      'type': access['access_type'],
-                                      'to': access['access_to']})
+                        "%(to)s.", {'level': access['access_level'],
+                                    'type': access['access_type'],
+                                    'to': access['access_to']})
                     continue
                 self._ssh_exec(server, ['sudo', 'exportfs', '-u',
-                               ':'.join((access['access_to'], local_path))])
+                               ':'.join((access_to, local_path))])
             if delete_rules:
                 self._sync_nfs_temp_and_perm_files(server)
             for access in add_rules:
-                access['access_to'] = self._get_parsed_access_to(
+                access_to = self._get_parsed_address_or_cidr(
                     access['access_to'])
                 found_item = re.search(
-                    re.escape(local_path) + '[\s\n]*' + re.escape(
-                        access['access_to']), out)
+                    re.escape(local_path) + '[\s\n]*' + re.escape(access_to),
+                    out)
                 if found_item is not None:
-                    LOG.warning(_LW("Access rule %(type)s:%(to)s already "
-                                    "exists for share %(name)s") % {
-                        'to': access['access_to'],
-                        'type': access['access_type'],
-                        'name': share_name
-                    })
+                    LOG.warning("Access rule %(type)s:%(to)s already "
+                                "exists for share %(name)s", {
+                                    'to': access['access_to'],
+                                    'type': access['access_type'],
+                                    'name': share_name
+                                })
                 else:
                     rules_options = '%s,no_subtree_check'
                     if access['access_level'] == const.ACCESS_LEVEL_RW:
@@ -244,11 +305,28 @@ class NFSHelper(NASHelperBase):
                         server,
                         ['sudo', 'exportfs', '-o',
                          rules_options % access['access_level'],
-                         ':'.join((access['access_to'], local_path))])
+                         ':'.join((access_to, local_path))])
             if add_rules:
                 self._sync_nfs_temp_and_perm_files(server)
 
-    def _get_host_list(self, output, local_path):
+    @staticmethod
+    def _get_parsed_address_or_cidr(access_to):
+        network = ipaddress.ip_network(six.text_type(access_to))
+        mask_length = network.prefixlen
+        address = six.text_type(network.network_address)
+        if mask_length == 0:
+            # Special case because Linux exports don't support /0 netmasks
+            return '*'
+        if network.version == 4:
+            if mask_length == 32:
+                return address
+            return '%s/%s' % (address, mask_length)
+        if mask_length == 128:
+            return "[%s]" % address
+        return "[%s]/%s" % (address, mask_length)
+
+    @staticmethod
+    def get_host_list(output, local_path):
         entries = []
         output = output.replace('\n\t\t', ' ')
         lines = output.split('\n')
@@ -276,10 +354,9 @@ class NFSHelper(NASHelperBase):
             self._ssh_exec(
                 server, ['sudo', 'service', 'nfs-kernel-server', 'restart'])
 
-    def get_exports_for_share(self, server, old_export_location):
-        self._verify_server_has_public_address(server)
-        path = old_export_location.split(':')[-1]
-        return [':'.join((server['public_address'], path))]
+    def _get_export_location_template(self, export_location_or_path):
+        path = export_location_or_path.split(':')[-1]
+        return '%s:' + path
 
     def get_share_path_by_export_location(self, server, export_location):
         return export_location.split(':')[-1]
@@ -289,14 +366,18 @@ class NFSHelper(NASHelperBase):
         maintenance_file = self._get_maintenance_file_path(share_name)
         backup_exports = [
             'cat', const.NFS_EXPORTS_FILE,
-            '| grep', share_name,
-            '| sudo tee', maintenance_file
+            '|', 'grep', share_name,
+            '|', 'sudo', 'tee', maintenance_file
         ]
         self._ssh_exec(server, backup_exports)
 
         local_path = os.path.join(self.configuration.share_mount_path,
                                   share_name)
-        self._ssh_exec(server, ['sudo', 'exportfs', '-u', local_path])
+        out, err = self._ssh_exec(server, ['sudo', 'exportfs'])
+        hosts = self.get_host_list(out, local_path)
+        for host in hosts:
+            self._ssh_exec(server, ['sudo', 'exportfs', '-u',
+                                    ':'.join((host, local_path))])
         self._sync_nfs_temp_and_perm_files(server)
 
     @nfs_synchronized
@@ -304,14 +385,33 @@ class NFSHelper(NASHelperBase):
         maintenance_file = self._get_maintenance_file_path(share_name)
         restore_exports = [
             'cat', maintenance_file,
-            '| sudo tee -a', const.NFS_EXPORTS_FILE,
-            '&& sudo exportfs -r',
-            '&& sudo rm -f', maintenance_file
+            '|', 'sudo', 'tee', '-a', const.NFS_EXPORTS_FILE,
+            '&&', 'sudo', 'exportfs', '-r',
+            '&&', 'sudo', 'rm', '-f', maintenance_file
         ]
         self._ssh_exec(server, restore_exports)
 
 
-class CIFSHelperIPAccess(NASHelperBase):
+class CIFSHelperBase(NASHelperBase):
+    @staticmethod
+    def _get_share_group_name_from_export_location(export_location):
+        if '/' in export_location and '\\' in export_location:
+            pass
+        elif export_location.startswith('\\\\'):
+            return export_location.split('\\')[-1]
+        elif export_location.startswith('//'):
+            return export_location.split('/')[-1]
+
+        msg = _("Got incorrect CIFS export location '%s'.") % export_location
+        raise exception.InvalidShare(reason=msg)
+
+    def _get_export_location_template(self, export_location_or_path):
+        group_name = self._get_share_group_name_from_export_location(
+            export_location_or_path)
+        return ('\\\\%s' + ('\\%s' % group_name))
+
+
+class CIFSHelperIPAccess(CIFSHelperBase):
     """Manage shares in samba server by net conf tool.
 
     Class provides functionality to operate with CIFS shares.
@@ -321,20 +421,19 @@ class CIFSHelperIPAccess(NASHelperBase):
     """
     def __init__(self, *args):
         super(CIFSHelperIPAccess, self).__init__(*args)
-        self.export_format = '\\\\%s\\%s'
         self.parameters = {
             'browseable': 'yes',
-            '\"create mask\"': '0755',
-            '\"hosts deny\"': '0.0.0.0/0',  # deny all by default
-            '\"hosts allow\"': '127.0.0.1',
-            '\"read only\"': 'no',
+            'create mask': '0755',
+            'hosts deny': '0.0.0.0/0',  # deny all by default
+            'hosts allow': '127.0.0.1',
+            'read only': 'no',
         }
 
     def init_helper(self, server):
         # This is smoke check that we have required dependency
         self._ssh_exec(server, ['sudo', 'net', 'conf', 'list'])
 
-    def create_export(self, server, share_name, recreate=False):
+    def create_exports(self, server, share_name, recreate=False):
         """Create share at samba server."""
         share_path = os.path.join(self.configuration.share_mount_path,
                                   share_name)
@@ -349,10 +448,9 @@ class CIFSHelperIPAccess(NASHelperBase):
             # Share does not exist, create it
             try:
                 self._ssh_exec(server, create_cmd)
-            except Exception as child_e:
+            except Exception:
                 msg = _("Could not create CIFS export %s.") % share_name
-                LOG.exception(child_e)
-                LOG.error(msg)
+                LOG.exception(msg)
                 raise exception.ManilaException(reason=msg)
         else:
             # Share exists
@@ -361,10 +459,9 @@ class CIFSHelperIPAccess(NASHelperBase):
                     server, ['sudo', 'net', 'conf', 'delshare', share_name, ])
                 try:
                     self._ssh_exec(server, create_cmd)
-                except Exception as e:
+                except Exception:
                     msg = _("Could not create CIFS export %s.") % share_name
-                    LOG.exception(e)
-                    LOG.error(msg)
+                    LOG.exception(msg)
                     raise exception.ManilaException(reason=msg)
             else:
                 msg = _('Share section %s already defined.') % share_name
@@ -374,16 +471,16 @@ class CIFSHelperIPAccess(NASHelperBase):
             self._ssh_exec(server, ['sudo', 'net', 'conf', 'setparm',
                            share_name, param, value])
 
-        return self.export_format % (server['public_address'], share_name)
+        return self.get_exports_for_share(server, '\\\\%s\\' + share_name)
 
-    def remove_export(self, server, share_name):
+    def remove_exports(self, server, share_name):
         """Remove share definition from samba server."""
         try:
             self._ssh_exec(
                 server, ['sudo', 'net', 'conf', 'delshare', share_name])
         except exception.ProcessExecutionError as e:
-            LOG.warning(_LW("Caught error trying delete share: %(error)s, try"
-                            "ing delete it forcibly."), {'error': e.stderr})
+            LOG.warning("Caught error trying delete share: %(error)s, try"
+                        "ing delete it forcibly.", {'error': e.stderr})
             self._ssh_exec(server, ['sudo', 'smbcontrol', 'all', 'close-share',
                                     share_name])
 
@@ -406,32 +503,13 @@ class CIFSHelperIPAccess(NASHelperBase):
 
     def _get_allow_hosts(self, server, share_name):
         (out, _) = self._ssh_exec(server, ['sudo', 'net', 'conf', 'getparm',
-                                           share_name, '\"hosts allow\"'])
+                                           share_name, 'hosts allow'])
         return out.split()
 
     def _set_allow_hosts(self, server, hosts, share_name):
-        value = "\"" + ' '.join(hosts) + "\""
+        value = ' '.join(hosts) or ' '
         self._ssh_exec(server, ['sudo', 'net', 'conf', 'setparm', share_name,
-                                '\"hosts allow\"', value])
-
-    @staticmethod
-    def _get_share_group_name_from_export_location(export_location):
-        if '/' in export_location and '\\' in export_location:
-            pass
-        elif export_location.startswith('\\\\'):
-            return export_location.split('\\')[-1]
-        elif export_location.startswith('//'):
-            return export_location.split('/')[-1]
-
-        msg = _("Got incorrect CIFS export location '%s'.") % export_location
-        raise exception.InvalidShare(reason=msg)
-
-    def get_exports_for_share(self, server, old_export_location):
-        self._verify_server_has_public_address(server)
-        group_name = self._get_share_group_name_from_export_location(
-            old_export_location)
-        data = dict(ip=server['public_address'], share=group_name)
-        return ['\\\\%(ip)s\\%(share)s' % data]
+                                'hosts allow', value])
 
     def get_share_path_by_export_location(self, server, export_location):
         # Get name of group that contains share data on CIFS server
@@ -450,7 +528,8 @@ class CIFSHelperIPAccess(NASHelperBase):
         allowed_hosts = " ".join(self._get_allow_hosts(server, share_name))
 
         backup_exports = [
-            'echo', "'%s'" % allowed_hosts, '| sudo tee', maintenance_file
+            'echo', "'%s'" % allowed_hosts, '|', 'sudo', 'tee',
+            maintenance_file
         ]
         self._ssh_exec(server, backup_exports)
         self._set_allow_hosts(server, [], share_name)
@@ -459,7 +538,7 @@ class CIFSHelperIPAccess(NASHelperBase):
         maintenance_file = self._get_maintenance_file_path(share_name)
         (exports, __) = self._ssh_exec(server, ['cat', maintenance_file])
         self._set_allow_hosts(server, exports.split(), share_name)
-        self._ssh_exec(server, ['sudo rm -f', maintenance_file])
+        self._ssh_exec(server, ['sudo', 'rm', '-f', maintenance_file])
 
 
 class CIFSHelperUserAccess(CIFSHelperIPAccess):
@@ -472,7 +551,6 @@ class CIFSHelperUserAccess(CIFSHelperIPAccess):
     """
     def __init__(self, *args):
         super(CIFSHelperUserAccess, self).__init__(*args)
-        self.export_format = '//%s/%s'
         self.parameters = {
             'browseable': 'yes',
             'create mask': '0755',
@@ -512,7 +590,7 @@ class CIFSHelperUserAccess(CIFSHelperIPAccess):
             return 'read list'
 
     def _set_valid_users(self, server, users, share_name, access_level):
-        value = "\"" + ' '.join(users) + "\""
+        value = ' '.join(users)
         param = self._get_conf_param(access_level)
         self._ssh_exec(server, ['sudo', 'net', 'conf', 'setparm', share_name,
                                 param, value])
