@@ -25,7 +25,7 @@ from six.moves import http_cookiejar
 from six.moves.urllib import request as urlreq  # pylint: disable=E0611
 
 from manila import exception
-from manila.i18n import _, _LE, _LW
+from manila.i18n import _
 from manila.share.drivers.huawei import constants
 from manila import utils
 
@@ -77,11 +77,11 @@ class RestHelper(object):
             LOG.debug('Response Data: %(res)s.', {'res': res})
 
         except Exception as err:
-            LOG.error(_LE('\nBad response from server: %(url)s.'
-                          ' Error: %(err)s'), {'url': url, 'err': err})
-            res = '{"error":{"code":%s,' \
-                  '"description":"Connect server error"}}' \
-                  % constants.ERROR_CONNECT_TO_SERVER
+            LOG.error('\nBad response from server: %(url)s.'
+                      ' Error: %(err)s', {'url': url, 'err': err})
+            res = ('{"error":{"code":%s,'
+                   '"description":"Connect server error"}}'
+                   % constants.ERROR_CONNECT_TO_SERVER)
 
         try:
             result = jsonutils.loads(res)
@@ -110,7 +110,7 @@ class RestHelper(object):
             if((result['error']['code'] != 0)
                or ("data" not in result)
                or (result['data']['deviceid'] is None)):
-                LOG.error(_LE("Login to %s failed, try another."), item_url)
+                LOG.error("Login to %s failed, try another.", item_url)
                 continue
 
             LOG.debug('Login success: %(url)s\n',
@@ -139,7 +139,7 @@ class RestHelper(object):
         error_code = result['error']['code']
         if(error_code == constants.ERROR_CONNECT_TO_SERVER
            or error_code == constants.ERROR_UNAUTHORIZED_TO_SERVER):
-            LOG.error(_LE("Can't open the recent url, re-login."))
+            LOG.error("Can't open the recent url, re-login.")
             deviceid = self.login()
 
         if deviceid is not None:
@@ -190,12 +190,13 @@ class RestHelper(object):
         need_encode = False
         for key in ['UserName', 'UserPassword']:
             node = root.find('Storage/%s' % key)
-            if node.text.find(prefix_name) > -1:
-                logininfo[key] = base64.b64decode(six.b(node.text[4:]))
+            if node.text.startswith(prefix_name):
+                logininfo[key] = base64.b64decode(
+                    six.b(node.text[4:])).decode()
             else:
                 logininfo[key] = node.text
-                node.text = prefix_name + six.text_type(
-                    base64.b64encode(six.b(node.text)))
+                node.text = prefix_name + base64.b64encode(
+                    six.b(node.text)).decode()
                 need_encode = True
         if need_encode:
             self._change_file_mode(filename)
@@ -213,7 +214,7 @@ class RestHelper(object):
             utils.execute('chmod', '666', filepath, run_as_root=True)
 
         except Exception as err:
-            LOG.error(_LE('Bad response from change file: %s.') % err)
+            LOG.error('Bad response from change file: %s.', err)
             raise
 
     def create_share(self, share_name, fs_id, share_proto):
@@ -697,10 +698,10 @@ class RestHelper(object):
         return share_url_type
 
     def get_fsid_by_name(self, share_name):
-        url = "/FILESYSTEM?range=[0-8191]"
+        share_name = share_name.replace("-", "_")
+        url = "/FILESYSTEM?filter=NAME::%s&range=[0-8191]" % share_name
         result = self.call(url, None, "GET")
         self._assert_rest_result(result, 'Get filesystem by name error!')
-        share_name = share_name.replace("-", "_")
 
         for item in result.get('data', []):
             if share_name == item['NAME']:
@@ -1150,8 +1151,8 @@ class RestHelper(object):
         url = "/vlan/" + vlan_id
         result = self.call(url, None, 'DELETE')
         if result['error']['code'] == constants.ERROR_LOGICAL_PORT_EXIST:
-            LOG.warning(_LW('Cannot delete vlan because there is '
-                            'a logical port on vlan.'))
+            LOG.warning('Cannot delete vlan because there is '
+                        'a logical port on vlan.')
             return
 
         self._assert_rest_result(result, _('Delete vlan error.'))
@@ -1401,7 +1402,7 @@ class RestHelper(object):
 
         if (result['error']['code'] ==
                 constants.ERROR_REPLICATION_PAIR_NOT_EXIST):
-            LOG.warning(_LW('Replication pair %s was not found.'),
+            LOG.warning('Replication pair %s was not found.',
                         pair_id)
             return
 
