@@ -26,7 +26,7 @@ from oslo_log import log
 from oslo_utils import excutils
 
 from manila import exception
-from manila.i18n import _, _LE, _LW, _LI
+from manila.i18n import _
 from manila.share.drivers.netapp.dataontap.client import client_cmode
 from manila.share.drivers.netapp.dataontap.cluster_mode import lib_base
 from manila.share.drivers.netapp import utils as na_utils
@@ -47,8 +47,8 @@ class NetAppCmodeMultiSVMFileStorageLibrary(
 
         if self._have_cluster_creds:
             if self.configuration.netapp_vserver:
-                msg = _LW('Vserver is specified in the configuration. This is '
-                          'ignored when the driver is managing share servers.')
+                msg = ('Vserver is specified in the configuration. This is '
+                       'ignored when the driver is managing share servers.')
                 LOG.warning(msg)
 
         else:  # only have vserver creds, which is an error in multi_svm mode
@@ -63,8 +63,8 @@ class NetAppCmodeMultiSVMFileStorageLibrary(
                     'netapp_aggregate_name_search_pattern is set correctly.')
             raise exception.NetAppException(msg)
 
-        super(NetAppCmodeMultiSVMFileStorageLibrary, self).\
-            check_for_setup_error()
+        (super(NetAppCmodeMultiSVMFileStorageLibrary, self).
+            check_for_setup_error())
 
     @na_utils.trace
     def _get_vserver(self, share_server=None):
@@ -88,19 +88,28 @@ class NetAppCmodeMultiSVMFileStorageLibrary(
         vserver_client = self._get_api_client(vserver)
         return vserver, vserver_client
 
+    def _get_ems_pool_info(self):
+        return {
+            'pools': {
+                'vserver': None,
+                'aggregates': self._find_matching_aggregates(),
+            },
+        }
+
     @na_utils.trace
     def _handle_housekeeping_tasks(self):
         """Handle various cleanup activities."""
         self._client.prune_deleted_nfs_export_policies()
         self._client.prune_deleted_snapshots()
+        self._client.remove_unused_qos_policy_groups()
 
-        super(NetAppCmodeMultiSVMFileStorageLibrary, self).\
-            _handle_housekeeping_tasks()
+        (super(NetAppCmodeMultiSVMFileStorageLibrary, self).
+            _handle_housekeeping_tasks())
 
     @na_utils.trace
     def _find_matching_aggregates(self):
         """Find all aggregates match pattern."""
-        aggregate_names = self._client.list_aggregates()
+        aggregate_names = self._client.list_non_root_aggregates()
         pattern = self.configuration.netapp_aggregate_name_search_pattern
         return [aggr_name for aggr_name in aggregate_names
                 if re.match(pattern, aggr_name)]
@@ -173,6 +182,9 @@ class NetAppCmodeMultiSVMFileStorageLibrary(
                                            network_info,
                                            ipspace_name)
 
+            self._create_vserver_routes(vserver_client,
+                                        network_info)
+
             vserver_client.enable_nfs(
                 self.configuration.netapp_enabled_share_protocols)
 
@@ -183,7 +195,7 @@ class NetAppCmodeMultiSVMFileStorageLibrary(
                                                      vserver_name)
         except Exception:
             with excutils.save_and_reraise_exception():
-                LOG.error(_LE("Failed to configure Vserver."))
+                LOG.error("Failed to configure Vserver.")
                 self._delete_vserver(vserver_name,
                                      security_services=security_services)
 
@@ -235,7 +247,7 @@ class NetAppCmodeMultiSVMFileStorageLibrary(
 
         network_allocations = network_info.get('admin_network_allocations')
         if not network_allocations:
-            LOG.info(_LI('No admin network defined for Vserver %s.') %
+            LOG.info('No admin network defined for Vserver %s.',
                      vserver_name)
             return
 
@@ -246,6 +258,20 @@ class NetAppCmodeMultiSVMFileStorageLibrary(
         self._create_lif(vserver_client, vserver_name, ipspace_name,
                          node_name, lif_name, network_allocation)
 
+    @na_utils.trace
+    def _create_vserver_routes(self, vserver_client, network_info):
+        """Create Vserver route and set gateways."""
+        route_gateways = []
+        # NOTE(gouthamr): Use the gateway from the tenant subnet/s
+        # for the static routes. Do not configure a route for the admin
+        # subnet because fast path routing will work for incoming
+        # connections and there are no requirements for outgoing
+        # connections on the admin network yet.
+        for net_allocation in (network_info['network_allocations']):
+            if net_allocation['gateway'] not in route_gateways:
+                vserver_client.create_route(net_allocation['gateway'])
+                route_gateways.append(net_allocation['gateway'])
+
     @na_utils.trace
     def _get_node_data_port(self, node):
         port_names = self._client.list_node_data_ports(node)
@@ -302,15 +328,15 @@ class NetAppCmodeMultiSVMFileStorageLibrary(
             'vserver_name') if server_details else None
 
         if not vserver:
-            LOG.warning(_LW("Vserver not specified for share server being "
-                            "deleted. Deletion of share server record will "
-                            "proceed anyway."))
+            LOG.warning("Vserver not specified for share server being "
+                        "deleted. Deletion of share server record will "
+                        "proceed anyway.")
             return
 
         elif not self._client.vserver_exists(vserver):
-            LOG.warning(_LW("Could not find Vserver for share server being "
-                            "deleted: %s. Deletion of share server "
-                            "record will proceed anyway."), vserver)
+            LOG.warning("Could not find Vserver for share server being "
+                        "deleted: %s. Deletion of share server "
+                        "record will proceed anyway.", vserver)
             return
 
         self._delete_vserver(vserver, security_services=security_services)
@@ -324,12 +350,16 @@ class NetAppCmodeMultiSVMFileStorageLibrary(
         vserver_client = self._get_api_client(vserver=vserver)
         network_interfaces = vserver_client.get_network_interfaces()
 
-        vlan = None
-        if network_interfaces:
-            home_port = network_interfaces[0]['home-port']
-            vlan = home_port.split('-')[1]
+        interfaces_on_vlans = []
+        vlans = []
+        for interface in network_interfaces:
+            if '-' in interface['home-port']:
+                interfaces_on_vlans.append(interface)
+                vlans.append(interface['home-port'])
 
-        @utils.synchronized('netapp-VLAN-%s' % vlan, external=True)
+        vlans = '-'.join(sorted(set(vlans))) if vlans else None
+
+        @utils.synchronized('netapp-VLANs-%s' % vlans, external=True)
         def _delete_vserver_with_lock():
             self._client.delete_vserver(vserver,
                                         vserver_client,
@@ -339,19 +369,18 @@ class NetAppCmodeMultiSVMFileStorageLibrary(
                     ipspace_name):
                 self._client.delete_ipspace(ipspace_name)
 
-            self._delete_vserver_vlan(network_interfaces)
+            self._delete_vserver_vlans(interfaces_on_vlans)
 
         return _delete_vserver_with_lock()
 
     @na_utils.trace
-    def _delete_vserver_vlan(self, vserver_network_interfaces):
+    def _delete_vserver_vlans(self, network_interfaces_on_vlans):
         """Delete Vserver's VLAN configuration from ports"""
-
-        for interface in vserver_network_interfaces:
+        for interface in network_interfaces_on_vlans:
             try:
                 home_port = interface['home-port']
                 port, vlan = home_port.split('-')
                 node = interface['home-node']
                 self._client.delete_vlan(node, port, vlan)
             except exception.NetAppException:
-                LOG.exception(_LE("Deleting Vserver VLAN failed."))
+                LOG.exception("Deleting Vserver VLAN failed.")
