@@ -25,7 +25,7 @@ import re
 from oslo_log import log
 
 from manila import exception
-from manila.i18n import _, _LI
+from manila.i18n import _
 from manila.share.drivers.netapp.dataontap.cluster_mode import lib_base
 from manila.share.drivers.netapp import utils as na_utils
 
@@ -72,15 +72,15 @@ class NetAppCmodeSingleSVMFileStorageLibrary(
                     'correctly.') % self._vserver
             raise exception.NetAppException(msg)
 
-        msg = _LI('Using Vserver %(vserver)s for backend %(backend)s with '
-                  '%(creds)s credentials.')
+        msg = ('Using Vserver %(vserver)s for backend %(backend)s with '
+               '%(creds)s credentials.')
         msg_args = {'vserver': self._vserver, 'backend': self._backend_name}
         msg_args['creds'] = ('cluster' if self._have_cluster_creds
                              else 'Vserver')
-        LOG.info(msg % msg_args)
+        LOG.info(msg, msg_args)
 
-        super(NetAppCmodeSingleSVMFileStorageLibrary, self).\
-            check_for_setup_error()
+        (super(NetAppCmodeSingleSVMFileStorageLibrary, self).
+            check_for_setup_error())
 
     @na_utils.trace
     def _get_vserver(self, share_server=None):
@@ -115,8 +115,12 @@ class NetAppCmodeSingleSVMFileStorageLibrary(
         vserver_client.prune_deleted_nfs_export_policies()
         vserver_client.prune_deleted_snapshots()
 
-        super(NetAppCmodeSingleSVMFileStorageLibrary, self).\
-            _handle_housekeeping_tasks()
+        if self._have_cluster_creds:
+            # Harvest soft-deleted QoS policy groups
+            vserver_client.remove_unused_qos_policy_groups()
+
+        (super(NetAppCmodeSingleSVMFileStorageLibrary, self).
+            _handle_housekeeping_tasks())
 
     @na_utils.trace
     def _find_matching_aggregates(self):
