@@ -30,9 +30,10 @@ netapp_proxy_opts = [
                      'clustered Data ONTAP.')), ]
 
 netapp_connection_opts = [
-    cfg.StrOpt('netapp_server_hostname',
-               deprecated_name='netapp_nas_server_hostname',
-               help='The hostname (or IP address) for the storage system.'),
+    cfg.HostAddressOpt('netapp_server_hostname',
+                       deprecated_name='netapp_nas_server_hostname',
+                       help='The hostname (or IP address) for the storage '
+                            'system.'),
     cfg.PortOpt('netapp_server_port',
                 help=('The TCP port to use for communication with the storage '
                       'system or proxy server. If not specified, Data ONTAP '
@@ -71,6 +72,9 @@ netapp_provisioning_opts = [
     cfg.StrOpt('netapp_vserver_name_template',
                default='os_%s',
                help='Name template to use for new Vserver.'),
+    cfg.StrOpt('netapp_qos_policy_group_name_template',
+               help='NetApp QoS policy group name template.',
+               default='qos_share_%(share_id)s'),
     cfg.StrOpt('netapp_port_name_search_pattern',
                default='(.*)',
                help='Pattern for overriding the selection of network ports '
