@@ -28,14 +28,11 @@ import six
 import six.moves.urllib.parse as urlparse
 
 from manila import exception
-from manila.i18n import _LW
 from manila import utils
 
 LOG = log.getLogger(__name__)
 
 ERROR_ENOENT = 2
-ERROR_ENTITY_NOT_FOUND = -24
-ERROR_GARBAGE_ARGS = -3
 
 
 class JsonRpc(object):
@@ -50,9 +47,9 @@ class JsonRpc(object):
         if self._url_scheme == 'https':
             if not self._ca_file:
                 self._ca_file = False
-                LOG.warning(_LW(
+                LOG.warning(
                     "Will not verify the server certificate of the API service"
-                    " because the CA certificate is not available."))
+                    " because the CA certificate is not available.")
         self._id = 0
         self._credentials = auth.HTTPBasicAuth(
             user_credentials[0], user_credentials[1])
@@ -60,7 +57,7 @@ class JsonRpc(object):
         self._cert_file = cert_file
 
     @utils.synchronized('quobyte-request')
-    def call(self, method_name, user_parameters, expected_errors=[]):
+    def call(self, method_name, user_parameters):
         # prepare request
         self._id += 1
         parameters = {'retry': 'INFINITELY'}  # Backend specific setting
@@ -97,19 +94,17 @@ class JsonRpc(object):
         if result.status_code == codes['OK']:
             LOG.debug("Retrieved data from Quobyte backend: %s", result.text)
             response = result.json()
-            return self._checked_for_application_error(response,
-                                                       expected_errors)
+            return self._checked_for_application_error(response)
 
         # If things did not work out provide error info
-        LOG.debug("Backend request resulted in error: %s" % result.text)
+        LOG.debug("Backend request resulted in error: %s", result.text)
         result.raise_for_status()
 
-    def _checked_for_application_error(self, result, expected_errors=[]):
+    def _checked_for_application_error(self, result):
         if 'error' in result and result['error']:
             if 'message' in result['error'] and 'code' in result['error']:
-                if result["error"]["code"] in expected_errors:
-                    # hit an expected error, return empty result
-                    return None
+                if result["error"]["code"] == ERROR_ENOENT:
+                    return None  # No Entry
                 else:
                     raise exception.QBRpcException(
                         result=result["error"]["message"],
