@@ -32,7 +32,7 @@ from manila.common import constants as const
 from manila import compute
 from manila import context
 from manila import exception
-from manila.i18n import _, _LW
+from manila.i18n import _
 from manila.network.linux import ip_lib
 from manila.network.neutron import api as neutron
 from manila import utils
@@ -101,14 +101,6 @@ share_servers_handling_mode_opts = [
         help="Attach share server directly to share network. "
              "Used only with Neutron and "
              "if driver_handles_share_servers=True."),
-    cfg.StrOpt(
-        "service_instance_network_helper_type",
-        default=NEUTRON_NAME,
-        deprecated_for_removal=True,
-        deprecated_reason="This option isn't used any longer because "
-                          "nova networking is no longer supported.",
-        help="Used to select between neutron and nova helpers when "
-             "driver_handles_share_servers=True. Obsolete."),
     cfg.StrOpt(
         "admin_network_id",
         help="ID of neutron network used to communicate with admin network,"
@@ -125,17 +117,17 @@ no_share_servers_handling_mode_opts = [
         "service_instance_name_or_id",
         help="Name or ID of service instance in Nova to use for share "
              "exports. Used only when share servers handling is disabled."),
-    cfg.StrOpt(
+    cfg.HostAddressOpt(
         "service_net_name_or_ip",
         help="Can be either name of network that is used by service "
              "instance within Nova to get IP address or IP address itself "
-             "for managing shares there. "
+             "(either IPv4 or IPv6) for managing shares there. "
              "Used only when share servers handling is disabled."),
-    cfg.StrOpt(
+    cfg.HostAddressOpt(
         "tenant_net_name_or_ip",
         help="Can be either name of network that is used by service "
              "instance within Nova to get IP address or IP address itself "
-             "for exporting shares. "
+             "(either IPv4 or IPv6) for exporting shares. "
              "Used only when share servers handling is disabled."),
 ]
 
@@ -249,13 +241,13 @@ class ServiceInstanceManager(object):
             self.admin_context,
             self.get_config_option('service_instance_name_or_id'))
 
-        if netutils.is_valid_ipv4(data['service_net_name_or_ip']):
+        if netutils.is_valid_ip(data['service_net_name_or_ip']):
             data['private_address'] = [data['service_net_name_or_ip']]
         else:
             data['private_address'] = self._get_addresses_by_network_name(
                 data['service_net_name_or_ip'], data['instance'])
 
-        if netutils.is_valid_ipv4(data['tenant_net_name_or_ip']):
+        if netutils.is_valid_ip(data['tenant_net_name_or_ip']):
             data['public_address'] = [data['tenant_net_name_or_ip']]
         else:
             data['public_address'] = self._get_addresses_by_network_name(
@@ -275,13 +267,13 @@ class ServiceInstanceManager(object):
             'instance_id': data['instance']['id'],
         }
         for key in ('private_address', 'public_address'):
-            data[key + '_v4'] = None
+            data[key + '_first'] = None
             for address in data[key]:
-                if netutils.is_valid_ipv4(address):
-                    data[key + '_v4'] = address
+                if netutils.is_valid_ip(address):
+                    data[key + '_first'] = address
                     break
-        share_server['ip'] = data['private_address_v4']
-        share_server['public_address'] = data['public_address_v4']
+        share_server['ip'] = data['private_address_first']
+        share_server['public_address'] = data['public_address_first']
         return {'backend_details': share_server}
 
     def _get_addresses_by_network_name(self, net_name, server):
@@ -327,8 +319,8 @@ class ServiceInstanceManager(object):
         name = name or self.get_config_option(
             "service_instance_security_group")
         if not name:
-            LOG.warning(_LW("Name for service instance security group is not "
-                            "provided. Skipping security group step."))
+            LOG.warning("Name for service instance security group is not "
+                        "provided. Skipping security group step.")
             return None
         s_groups = self.network_helper.neutron_api.security_group_list({
             "name": name,
@@ -344,6 +336,7 @@ class ServiceInstanceManager(object):
                 name, description)['security_group']
             for protocol, ports in const.SERVICE_INSTANCE_SECGROUP_DATA:
                 self.network_helper.neutron_api.security_group_rule_create(
+                    context,
                     parent_group_id=sg['id'],
                     ip_protocol=protocol,
                     from_port=ports[0],
@@ -360,15 +353,15 @@ class ServiceInstanceManager(object):
     def ensure_service_instance(self, context, server):
         """Ensures that server exists and active."""
         if 'instance_id' not in server:
-            LOG.warning(_LW("Unable to check server existence since "
-                            "'instance_id' key is not set in share server "
-                            "backend details."))
+            LOG.warning("Unable to check server existence since "
+                        "'instance_id' key is not set in share server "
+                        "backend details.")
             return False
         try:
             inst = self.compute_api.server_get(self.admin_context,
                                                server['instance_id'])
         except exception.InstanceNotFound:
-            LOG.warning(_LW("Service instance %s does not exist."),
+            LOG.warning("Service instance %s does not exist.",
                         server['instance_id'])
             return False
         if inst['status'] == 'ACTIVE':
@@ -511,11 +504,11 @@ class ServiceInstanceManager(object):
             raise exception.ServiceInstanceException(
                 _('Neither service instance password nor key are available.'))
         if not key_path:
-            LOG.warning(_LW(
+            LOG.warning(
                 'No key path is available. May be non-existent key path is '
                 'provided. Check path_to_private_key (current value '
                 '%(private_path)s) and path_to_public_key (current value '
-                '%(public_path)s) in manila configuration file.'), dict(
+                '%(public_path)s) in manila configuration file.', dict(
                     private_path=self.path_to_private_key,
                     public_path=self.path_to_public_key))
         network_data = self.network_helper.setup_network(network_info)
@@ -649,7 +642,7 @@ class ServiceInstanceManager(object):
                 break
 
             LOG.debug("Waiting for instance %(instance_id)s to be active. "
-                      "Current status: %(instance_status)s." %
+                      "Current status: %(instance_status)s.",
                       dict(instance_id=instance_id,
                            instance_status=instance_status))
             time.sleep(1)
@@ -966,8 +959,8 @@ class NeutronNetworkHelper(BaseNetworkhelper):
             addr_list = device.addr.list()
         except Exception as e:
             if 'does not exist' in six.text_type(e):
-                LOG.warning(_LW(
-                    "Device %s does not exist anymore.") % device.name)
+                LOG.warning(
+                    "Device %s does not exist anymore.", device.name)
             else:
                 raise
         for addr in addr_list:
@@ -992,8 +985,7 @@ class NeutronNetworkHelper(BaseNetworkhelper):
         elif not ports:
             port = self.neutron_api.create_port(
                 self.admin_project_id, network_id, subnet_id=subnet_id,
-                device_id=device_id, device_owner='manila:share', host_id=host,
-                port_security_enabled=False)
+                device_id=device_id, device_owner='manila:share', host_id=host)
         else:
             port = ports[0]
         return port
