@@ -30,6 +30,7 @@ from oslo_concurrency import lockutils
 from oslo_config import cfg
 from oslo_config import fixture as config_fixture
 import oslo_i18n
+import oslo_messaging
 from oslo_messaging import conffixture as messaging_conffixture
 from oslo_utils import uuidutils
 import oslotest.base as base_test
@@ -140,6 +141,11 @@ class TestCase(base_test.BaseTestCase):
         self.messaging_conf.transport_driver = 'fake'
         self.messaging_conf.response_timeout = 15
         self.useFixture(self.messaging_conf)
+
+        oslo_messaging.get_notification_transport(CONF)
+        self.override_config('driver', ['test'],
+                             group='oslo_messaging_notifications')
+
         rpc.init(CONF)
 
         mock.patch('keystoneauth1.loading.load_auth_from_conf_options').start()
@@ -181,7 +187,7 @@ class TestCase(base_test.BaseTestCase):
     def flags(self, **kw):
         """Override flag variables for a test."""
         for k, v in kw.items():
-            CONF.set_override(k, v, enforce_type=True)
+            CONF.set_override(k, v)
 
     def start_service(self, name, host=None, **kwargs):
         host = host and host or uuidutils.generate_uuid()
@@ -350,7 +356,7 @@ class TestCase(base_test.BaseTestCase):
     def _dict_from_object(self, obj, ignored_keys):
         if ignored_keys is None:
             ignored_keys = []
-        return {k: v for k, v in obj.iteritems()
+        return {k: v for k, v in obj.items()
                 if k not in ignored_keys}
 
     def _assertEqualListsOfObjects(self, objs1, objs2, ignored_keys=None):
@@ -363,3 +369,18 @@ class TestCase(base_test.BaseTestCase):
     def is_microversion_ge(self, left, right):
         return (api_version.APIVersionRequest(left) >=
                 api_version.APIVersionRequest(right))
+
+    def assert_notify_called(self, mock_notify, calls):
+        for i in range(0, len(calls)):
+            mock_call = mock_notify.call_args_list[i]
+            call = calls[i]
+
+            posargs = mock_call[0]
+
+            self.assertEqual(call[0], posargs[0])
+            self.assertEqual(call[1], posargs[2])
+
+    def override_config(self, name, override, group=None):
+        """Cleanly override CONF variables."""
+        CONF.set_override(name, override, group)
+        self.addCleanup(CONF.clear_override, name, group)
