@@ -98,8 +98,8 @@ def make_create_body(name="test_share_1", extra_specs=None,
         extra_specs = {}
 
     if spec_driver_handles_share_servers is not None:
-        extra_specs[constants.ExtraSpecs.DRIVER_HANDLES_SHARE_SERVERS] =\
-            spec_driver_handles_share_servers
+        extra_specs[constants.ExtraSpecs.DRIVER_HANDLES_SHARE_SERVERS] = (
+            spec_driver_handles_share_servers)
 
     body = {
         "share_type": {
@@ -564,7 +564,6 @@ class ShareTypeAccessTest(test.TestCase):
         super(self.__class__, self).setUp()
         self.controller = types.ShareTypesController()
         self.req = FakeRequest()
-        self.context = self.req.environ['manila.context']
         self.mock_object(db, 'share_type_get', fake_share_type_get)
         self.mock_object(db, 'share_type_get_all', fake_share_type_get_all)
 
