@@ -2169,3 +2169,300 @@ class ShareGroupNewConsistentSnapshotSupportColumnChecks(BaseMigrationChecks):
         self.test_case.assertEqual(1, db_result.rowcount)
         for sg in db_result:
             self.test_case.assertFalse(hasattr(sg, self.new_attr_name))
+
+
+@map_to_migration('7d142971c4ef')
+class ReservationExpireIndexChecks(BaseMigrationChecks):
+
+    def setup_upgrade_data(self, engine):
+        pass
+
+    def _get_reservations_expire_delete_index(self, engine):
+        reservation_table = utils.load_table('reservations', engine)
+        members = ['deleted', 'expire']
+        for idx in reservation_table.indexes:
+            if sorted(idx.columns.keys()) == members:
+                return idx
+
+    def check_upgrade(self, engine, data):
+        self.test_case.assertTrue(
+            self._get_reservations_expire_delete_index(engine))
+
+    def check_downgrade(self, engine):
+        self.test_case.assertFalse(
+            self._get_reservations_expire_delete_index(engine))
+
+
+@map_to_migration('5237b6625330')
+class ShareGroupNewAvailabilityZoneIDColumnChecks(BaseMigrationChecks):
+    table_name = 'share_groups'
+    new_attr_name = 'availability_zone_id'
+    share_group_type_id = uuidutils.generate_uuid()
+    share_group_id = uuidutils.generate_uuid()
+    availability_zone_id = uuidutils.generate_uuid()
+
+    def setup_upgrade_data(self, engine):
+        # Setup AZ
+        az_data = {
+            'id': self.availability_zone_id,
+            'name': uuidutils.generate_uuid(),
+        }
+        az_table = utils.load_table('availability_zones', engine)
+        engine.execute(az_table.insert(az_data))
+
+        # Setup share group type
+        sgt_data = {
+            'id': self.share_group_type_id,
+            'name': uuidutils.generate_uuid(),
+        }
+        sgt_table = utils.load_table('share_group_types', engine)
+        engine.execute(sgt_table.insert(sgt_data))
+
+        # Setup share group
+        sg_data = {
+            'id': self.share_group_id,
+            'project_id': 'fake_project_id',
+            'user_id': 'fake_user_id',
+            'share_group_type_id': self.share_group_type_id,
+        }
+        sg_table = utils.load_table('share_groups', engine)
+        engine.execute(sg_table.insert(sg_data))
+
+    def check_upgrade(self, engine, data):
+        sg_table = utils.load_table(self.table_name, engine)
+        db_result = engine.execute(sg_table.select().where(
+            sg_table.c.id == self.share_group_id))
+        self.test_case.assertEqual(1, db_result.rowcount)
+        for sg in db_result:
+            self.test_case.assertTrue(hasattr(sg, self.new_attr_name))
+
+            # Check that we can write proper data to the new field
+            for value in (None, self.availability_zone_id):
+                engine.execute(sg_table.update().where(
+                    sg_table.c.id == self.share_group_id,
+                ).values({self.new_attr_name: value}))
+
+    def check_downgrade(self, engine):
+        sg_table = utils.load_table(self.table_name, engine)
+        db_result = engine.execute(sg_table.select().where(
+            sg_table.c.id == self.share_group_id))
+        self.test_case.assertEqual(1, db_result.rowcount)
+        for sg in db_result:
+            self.test_case.assertFalse(hasattr(sg, self.new_attr_name))
+
+
+@map_to_migration('31252d671ae5')
+class SquashSGSnapshotMembersAndSSIModelsChecks(BaseMigrationChecks):
+    old_table_name = 'share_group_snapshot_members'
+    new_table_name = 'share_snapshot_instances'
+    share_group_type_id = uuidutils.generate_uuid()
+    share_group_id = uuidutils.generate_uuid()
+    share_id = uuidutils.generate_uuid()
+    share_instance_id = uuidutils.generate_uuid()
+    share_group_snapshot_id = uuidutils.generate_uuid()
+    share_group_snapshot_member_id = uuidutils.generate_uuid()
+    keys = (
+        'user_id', 'project_id', 'size', 'share_proto',
+        'share_group_snapshot_id',
+    )
+
+    def setup_upgrade_data(self, engine):
+        # Setup share group type
+        sgt_data = {
+            'id': self.share_group_type_id,
+            'name': uuidutils.generate_uuid(),
+        }
+        sgt_table = utils.load_table('share_group_types', engine)
+        engine.execute(sgt_table.insert(sgt_data))
+
+        # Setup share group
+        sg_data = {
+            'id': self.share_group_id,
+            'project_id': 'fake_project_id',
+            'user_id': 'fake_user_id',
+            'share_group_type_id': self.share_group_type_id,
+        }
+        sg_table = utils.load_table('share_groups', engine)
+        engine.execute(sg_table.insert(sg_data))
+
+        # Setup shares
+        share_data = {
+            'id': self.share_id,
+            'share_group_id': self.share_group_id,
+        }
+        s_table = utils.load_table('shares', engine)
+        engine.execute(s_table.insert(share_data))
+
+        # Setup share instances
+        share_instance_data = {
+            'id': self.share_instance_id,
+            'share_id': share_data['id'],
+            'cast_rules_to_readonly': False,
+        }
+        si_table = utils.load_table('share_instances', engine)
+        engine.execute(si_table.insert(share_instance_data))
+
+        # Setup share group snapshot
+        sgs_data = {
+            'id': self.share_group_snapshot_id,
+            'share_group_id': self.share_group_id,
+            'project_id': 'fake_project_id',
+            'user_id': 'fake_user_id',
+        }
+        sgs_table = utils.load_table('share_group_snapshots', engine)
+        engine.execute(sgs_table.insert(sgs_data))
+
+        # Setup share group snapshot member
+        sgsm_data = {
+            'id': self.share_group_snapshot_member_id,
+            'share_group_snapshot_id': self.share_group_snapshot_id,
+            'share_id': self.share_id,
+            'share_instance_id': self.share_instance_id,
+            'project_id': 'fake_project_id',
+            'user_id': 'fake_user_id',
+        }
+        sgsm_table = utils.load_table(self.old_table_name, engine)
+        engine.execute(sgsm_table.insert(sgsm_data))
+
+    def check_upgrade(self, engine, data):
+        ssi_table = utils.load_table(self.new_table_name, engine)
+        db_result = engine.execute(ssi_table.select().where(
+            ssi_table.c.id == self.share_group_snapshot_member_id))
+        self.test_case.assertEqual(1, db_result.rowcount)
+        for ssi in db_result:
+            for key in self.keys:
+                self.test_case.assertTrue(hasattr(ssi, key))
+
+            # Check that we can write string data to the new fields
+            engine.execute(ssi_table.update().where(
+                ssi_table.c.id == self.share_group_snapshot_member_id,
+            ).values({
+                'user_id': ('u' * 255),
+                'project_id': ('p' * 255),
+                'share_proto': ('s' * 255),
+                'size': 123456789,
+                'share_group_snapshot_id': self.share_group_snapshot_id,
+            }))
+
+        # Check that table 'share_group_snapshot_members' does not
+        # exist anymore
+        self.test_case.assertRaises(
+            sa_exc.NoSuchTableError,
+            utils.load_table, 'share_group_snapshot_members', engine)
+
+    def check_downgrade(self, engine):
+        sgsm_table = utils.load_table(self.old_table_name, engine)
+        db_result = engine.execute(sgsm_table.select().where(
+            sgsm_table.c.id == self.share_group_snapshot_member_id))
+        self.test_case.assertEqual(1, db_result.rowcount)
+        for sgsm in db_result:
+            for key in self.keys:
+                self.test_case.assertTrue(hasattr(sgsm, key))
+
+        # Check that create SGS member is absent in SSI table
+        ssi_table = utils.load_table(self.new_table_name, engine)
+        db_result = engine.execute(ssi_table.select().where(
+            ssi_table.c.id == self.share_group_snapshot_member_id))
+        self.test_case.assertEqual(0, db_result.rowcount)
+
+
+@map_to_migration('238720805ce1')
+class MessagesTableChecks(BaseMigrationChecks):
+    new_table_name = 'messages'
+
+    def setup_upgrade_data(self, engine):
+        pass
+
+    def check_upgrade(self, engine, data):
+        message_data = {
+            'id': uuidutils.generate_uuid(),
+            'project_id': 'x' * 255,
+            'request_id': 'x' * 255,
+            'resource_type': 'x' * 255,
+            'resource_id': 'y' * 36,
+            'action_id': 'y' * 10,
+            'detail_id': 'y' * 10,
+            'message_level': 'x' * 255,
+            'created_at': datetime.datetime(2017, 7, 10, 18, 5, 58),
+            'updated_at': None,
+            'deleted_at': None,
+            'deleted': 0,
+            'expires_at': datetime.datetime(2017, 7, 11, 18, 5, 58),
+        }
+
+        new_table = utils.load_table(self.new_table_name, engine)
+        engine.execute(new_table.insert(message_data))
+
+    def check_downgrade(self, engine):
+        self.test_case.assertRaises(sa_exc.NoSuchTableError, utils.load_table,
+                                    'messages', engine)
+
+
+@map_to_migration('b516de97bfee')
+class ProjectShareTypesQuotasChecks(BaseMigrationChecks):
+    new_table_name = 'project_share_type_quotas'
+    usages_table = 'quota_usages'
+    reservations_table = 'reservations'
+    st_record_id = uuidutils.generate_uuid()
+
+    def setup_upgrade_data(self, engine):
+        # Create share type
+        self.st_data = {
+            'id': self.st_record_id,
+            'name': uuidutils.generate_uuid(),
+            'deleted': "False",
+        }
+        st_table = utils.load_table('share_types', engine)
+        engine.execute(st_table.insert(self.st_data))
+
+    def check_upgrade(self, engine, data):
+        # Create share type quota
+        self.quota_data = {
+            'project_id': 'x' * 255,
+            'resource': 'y' * 255,
+            'hard_limit': 987654321,
+            'created_at': datetime.datetime(2017, 4, 11, 18, 5, 58),
+            'updated_at': None,
+            'deleted_at': None,
+            'deleted': 0,
+            'share_type_id': self.st_record_id,
+        }
+        new_table = utils.load_table(self.new_table_name, engine)
+        engine.execute(new_table.insert(self.quota_data))
+
+        # Create usage record
+        self.usages_data = {
+            'project_id': 'x' * 255,
+            'user_id': None,
+            'share_type_id': self.st_record_id,
+            'resource': 'y' * 255,
+            'in_use': 13,
+            'reserved': 15,
+        }
+        usages_table = utils.load_table(self.usages_table, engine)
+        engine.execute(usages_table.insert(self.usages_data))
+
+        # Create reservation record
+        self.reservations_data = {
+            'uuid': uuidutils.generate_uuid(),
+            'usage_id': 1,
+            'project_id': 'x' * 255,
+            'user_id': None,
+            'share_type_id': self.st_record_id,
+            'resource': 'y' * 255,
+            'delta': 13,
+            'expire': datetime.datetime(2399, 4, 11, 18, 5, 58),
+        }
+        reservations_table = utils.load_table(self.reservations_table, engine)
+        engine.execute(reservations_table.insert(self.reservations_data))
+
+    def check_downgrade(self, engine):
+        self.test_case.assertRaises(
+            sa_exc.NoSuchTableError,
+            utils.load_table, self.new_table_name, engine)
+        for table_name in (self.usages_table, self.reservations_table):
+            table = utils.load_table(table_name, engine)
+            db_result = engine.execute(table.select())
+            self.test_case.assertGreater(db_result.rowcount, 0)
+            for row in db_result:
+                self.test_case.assertFalse(hasattr(row, 'share_type_id'))
