@@ -231,10 +231,11 @@ class HitachiHNASTestCase(test.TestCase):
         # mocking common backend calls
         self.mock_object(ssh.HNASSSHBackend, "check_fs_mounted", mock.Mock(
             return_value=True))
-        self.mock_object(ssh.HNASSSHBackend, "check_vvol", mock.Mock())
-        self.mock_object(ssh.HNASSSHBackend, "check_quota", mock.Mock())
-        self.mock_object(ssh.HNASSSHBackend, "check_cifs", mock.Mock())
-        self.mock_object(ssh.HNASSSHBackend, "check_export", mock.Mock())
+        self.mock_object(ssh.HNASSSHBackend, "check_vvol")
+        self.mock_object(ssh.HNASSSHBackend, "check_quota")
+        self.mock_object(ssh.HNASSSHBackend, "check_cifs")
+        self.mock_object(ssh.HNASSSHBackend, "check_export")
+        self.mock_object(ssh.HNASSSHBackend, 'check_directory')
 
     @ddt.data('hitachi_hnas_driver_helper', 'hitachi_hnas_evs_id',
               'hitachi_hnas_evs_ip', 'hitachi_hnas_ip', 'hitachi_hnas_user')
@@ -254,27 +255,34 @@ class HitachiHNASTestCase(test.TestCase):
         self.assertRaises(exception.InvalidParameterValue,
                           self._driver.__init__)
 
-    def test_update_access_nfs(self):
-        access1 = {
-            'access_type': 'ip',
-            'access_to': '172.24.10.10',
-            'access_level': 'rw'
-        }
-        access2 = {
-            'access_type': 'ip',
-            'access_to': '188.100.20.10',
-            'access_level': 'ro'
-        }
-        access_list = [access1, access2]
+    @ddt.data(True, False)
+    def test_update_access_nfs(self, empty_rules):
+        if not empty_rules:
+            access1 = {
+                'access_type': 'ip',
+                'access_to': '172.24.10.10',
+                'access_level': 'rw'
+            }
+            access2 = {
+                'access_type': 'ip',
+                'access_to': '188.100.20.10',
+                'access_level': 'ro'
+            }
+            access_list = [access1, access2]
+            access_list_updated = (
+                [access1['access_to'] + '(' + access1['access_level'] +
+                 ',norootsquash)', access2['access_to'] + '(' +
+                 access2['access_level'] + ')', ])
+        else:
+            access_list = []
+            access_list_updated = []
 
         self.mock_object(ssh.HNASSSHBackend, "update_nfs_access_rule",
                          mock.Mock())
         self._driver.update_access('context', share_nfs, access_list, [], [])
 
         ssh.HNASSSHBackend.update_nfs_access_rule.assert_called_once_with(
-            [access1['access_to'] + '(' + access1['access_level'] +
-             ',norootsquash)', access2['access_to'] + '(' +
-             access2['access_level'] + ')', ], share_id=share_nfs['id'])
+            access_list_updated, share_id=share_nfs['id'])
         self.assertTrue(self.mock_log.debug.called)
 
     def test_update_access_ip_exception(self):
@@ -319,7 +327,7 @@ class HitachiHNASTestCase(test.TestCase):
     def test_allow_access_cifs(self, access_cifs, permission):
         access_list_allow = [access_cifs]
 
-        self.mock_object(ssh.HNASSSHBackend, 'cifs_allow_access', mock.Mock())
+        self.mock_object(ssh.HNASSSHBackend, 'cifs_allow_access')
 
         self._driver.update_access('context', share_cifs, [],
                                    access_list_allow, [])
@@ -345,7 +353,7 @@ class HitachiHNASTestCase(test.TestCase):
     def test_deny_access_cifs(self):
         access_list_deny = [access_cifs_rw]
 
-        self.mock_object(ssh.HNASSSHBackend, 'cifs_deny_access', mock.Mock())
+        self.mock_object(ssh.HNASSSHBackend, 'cifs_deny_access')
 
         self._driver.update_access('context', share_cifs, [], [],
                                    access_list_deny)
@@ -364,14 +372,14 @@ class HitachiHNASTestCase(test.TestCase):
         }
         access_list_deny = [access_cifs_type_ip]
 
-        self.mock_object(ssh.HNASSSHBackend, 'cifs_deny_access', mock.Mock())
+        self.mock_object(ssh.HNASSSHBackend, 'cifs_deny_access')
 
         self._driver.update_access('context', share_cifs, [], [],
                                    access_list_deny)
         self.assertTrue(self.mock_log.warning.called)
 
     def test_update_access_invalid_share_protocol(self):
-        self.mock_object(self._driver, '_ensure_share', mock.Mock())
+        self.mock_object(self._driver, '_ensure_share')
         ex = self.assertRaises(exception.ShareBackendException,
                                self._driver.update_access, 'context',
                                invalid_share, [], [], [])
@@ -383,8 +391,8 @@ class HitachiHNASTestCase(test.TestCase):
 
         self.mock_object(ssh.HNASSSHBackend, 'list_cifs_permissions',
                          mock.Mock(return_value=permission_list))
-        self.mock_object(ssh.HNASSSHBackend, 'cifs_deny_access', mock.Mock())
-        self.mock_object(ssh.HNASSSHBackend, 'cifs_allow_access', mock.Mock())
+        self.mock_object(ssh.HNASSSHBackend, 'cifs_deny_access')
+        self.mock_object(ssh.HNASSSHBackend, 'cifs_allow_access')
 
         self._driver.update_access('context', share_cifs, access_list, [], [])
 
@@ -413,11 +421,11 @@ class HitachiHNASTestCase(test.TestCase):
     def test_create_share(self, share):
         self.mock_object(driver.HitachiHNASDriver, "_check_fs_mounted",
                          mock.Mock())
-        self.mock_object(ssh.HNASSSHBackend, "vvol_create", mock.Mock())
-        self.mock_object(ssh.HNASSSHBackend, "quota_add", mock.Mock())
+        self.mock_object(ssh.HNASSSHBackend, "vvol_create")
+        self.mock_object(ssh.HNASSSHBackend, "quota_add")
         self.mock_object(ssh.HNASSSHBackend, "nfs_export_add", mock.Mock(
             return_value='/shares/' + share['id']))
-        self.mock_object(ssh.HNASSSHBackend, "cifs_share_add", mock.Mock())
+        self.mock_object(ssh.HNASSSHBackend, "cifs_share_add")
 
         result = self._driver.create_share('context', share)
 
@@ -446,11 +454,11 @@ class HitachiHNASTestCase(test.TestCase):
     def test_create_share_export_error(self):
         self.mock_object(driver.HitachiHNASDriver, "_check_fs_mounted",
                          mock.Mock())
-        self.mock_object(ssh.HNASSSHBackend, "vvol_create", mock.Mock())
-        self.mock_object(ssh.HNASSSHBackend, "quota_add", mock.Mock())
+        self.mock_object(ssh.HNASSSHBackend, "vvol_create")
+        self.mock_object(ssh.HNASSSHBackend, "quota_add")
         self.mock_object(ssh.HNASSSHBackend, "nfs_export_add", mock.Mock(
             side_effect=exception.HNASBackendException('msg')))
-        self.mock_object(ssh.HNASSSHBackend, "vvol_delete", mock.Mock())
+        self.mock_object(ssh.HNASSSHBackend, "vvol_delete")
 
         self.assertRaises(exception.HNASBackendException,
                           self._driver.create_share, 'context', share_nfs)
@@ -475,9 +483,9 @@ class HitachiHNASTestCase(test.TestCase):
     def test_delete_share(self, share):
         self.mock_object(driver.HitachiHNASDriver, "_check_fs_mounted",
                          mock.Mock())
-        self.mock_object(ssh.HNASSSHBackend, "nfs_export_del", mock.Mock())
-        self.mock_object(ssh.HNASSSHBackend, "cifs_share_del", mock.Mock())
-        self.mock_object(ssh.HNASSSHBackend, "vvol_delete", mock.Mock())
+        self.mock_object(ssh.HNASSSHBackend, "nfs_export_del")
+        self.mock_object(ssh.HNASSSHBackend, "cifs_share_del")
+        self.mock_object(ssh.HNASSSHBackend, "vvol_delete")
 
         self._driver.delete_share('context', share)
 
@@ -533,7 +541,7 @@ class HitachiHNASTestCase(test.TestCase):
                          mock.Mock())
         self.mock_object(ssh.HNASSSHBackend, "is_cifs_in_use", mock.Mock(
             return_value=False))
-        self.mock_object(ssh.HNASSSHBackend, "tree_clone", mock.Mock())
+        self.mock_object(ssh.HNASSSHBackend, "tree_clone")
         self.mock_object(ssh.HNASSSHBackend, "nfs_export_add")
         self.mock_object(ssh.HNASSSHBackend, "cifs_share_add")
 
@@ -556,7 +564,7 @@ class HitachiHNASTestCase(test.TestCase):
                 hnas_id)
 
     def test_create_snapshot_invalid_protocol(self):
-        self.mock_object(self._driver, '_ensure_share', mock.Mock())
+        self.mock_object(self._driver, '_ensure_share')
         ex = self.assertRaises(exception.ShareBackendException,
                                self._driver.create_snapshot, 'context',
                                invalid_snapshot)
@@ -584,7 +592,7 @@ class HitachiHNASTestCase(test.TestCase):
                          mock.Mock())
         self.mock_object(ssh.HNASSSHBackend, "tree_clone", mock.Mock(
             side_effect=exception.HNASNothingToCloneException('msg')))
-        self.mock_object(ssh.HNASSSHBackend, "create_directory", mock.Mock())
+        self.mock_object(ssh.HNASSSHBackend, "create_directory")
         self.mock_object(ssh.HNASSSHBackend, "nfs_export_add")
         self.mock_object(ssh.HNASSSHBackend, "cifs_share_add")
 
@@ -685,7 +693,7 @@ class HitachiHNASTestCase(test.TestCase):
     def test_shrink_share(self):
         self.mock_object(ssh.HNASSSHBackend, "get_share_usage", mock.Mock(
             return_value=10))
-        self.mock_object(ssh.HNASSSHBackend, "modify_quota", mock.Mock())
+        self.mock_object(ssh.HNASSSHBackend, "modify_quota")
 
         self._driver.shrink_share(share_nfs, 11)
 
@@ -706,7 +714,7 @@ class HitachiHNASTestCase(test.TestCase):
     def test_extend_share(self):
         self.mock_object(ssh.HNASSSHBackend, "get_stats", mock.Mock(
             return_value=(500, 200, True)))
-        self.mock_object(ssh.HNASSSHBackend, "modify_quota", mock.Mock())
+        self.mock_object(ssh.HNASSSHBackend, "modify_quota")
 
         self._driver.extend_share(share_nfs, 150)
 
@@ -717,7 +725,7 @@ class HitachiHNASTestCase(test.TestCase):
     def test_extend_share_with_no_available_space_in_fs(self):
         self.mock_object(ssh.HNASSSHBackend, "get_stats", mock.Mock(
             return_value=(500, 200, False)))
-        self.mock_object(ssh.HNASSSHBackend, "modify_quota", mock.Mock())
+        self.mock_object(ssh.HNASSSHBackend, "modify_quota")
 
         self.assertRaises(exception.HNASBackendException,
                           self._driver.extend_share, share_nfs, 1000)
@@ -764,16 +772,31 @@ class HitachiHNASTestCase(test.TestCase):
 
     @ddt.data(':/', '1.1.1.1:/share_id', '1.1.1.1:/shares',
               '1.1.1.1:shares/share_id', ':/share_id')
-    def test_manage_existing_wrong_path_format(self, wrong_location):
+    def test_manage_existing_wrong_path_format_nfs(self, wrong_location):
         expected_exception = ("Share backend error: Incorrect path. It "
                               "should have the following format: "
                               "IP:/shares/share_id.")
-        share_copy = share_nfs.copy()
-        share_copy['export_locations'] = [{'path': wrong_location}]
+
+        self._test_manage_existing_wrong_path(
+            share_nfs.copy(), expected_exception, wrong_location)
+
+    @ddt.data('\\\\1.1.1.1', '1.1.1.1\\share_id', '1.1.1.1\\shares\\share_id',
+              '\\\\1.1.1.1\\shares\\share_id', '\\\\share_id')
+    def test_manage_existing_wrong_path_format_cifs(self, wrong_location):
+        expected_exception = ("Share backend error: Incorrect path. It should "
+                              "have the following format: \\\\IP\\share_id.")
+
+        self._test_manage_existing_wrong_path(
+            share_cifs.copy(), expected_exception, wrong_location)
+
+    def _test_manage_existing_wrong_path(
+            self, share, expected_exception, wrong_location):
+
+        share['export_locations'] = [{'path': wrong_location}]
 
         ex = self.assertRaises(exception.ShareBackendException,
-                               self._driver.manage_existing, share_copy,
-                               'option')
+                               self._driver.manage_existing, share, 'option')
+
         self.assertEqual(expected_exception, ex.msg)
 
     def test_manage_existing_wrong_evs_ip(self):
@@ -794,8 +817,13 @@ class HitachiHNASTestCase(test.TestCase):
                           self._driver.manage_existing, invalid_share,
                           'option')
 
-    def test_unmanage(self):
-        self._driver.unmanage(share_nfs)
+    @ddt.data(True, False)
+    def test_unmanage(self, has_export_locations):
+        share_copy = share_nfs.copy()
+        if not has_export_locations:
+            share_copy['export_locations'] = []
+
+        self._driver.unmanage(share_copy)
 
         self.assertTrue(self.fake_private_storage.delete.called)
         self.assertTrue(self.mock_log.info.called)
@@ -810,11 +838,11 @@ class HitachiHNASTestCase(test.TestCase):
     def test_create_share_from_snapshot(self, share, snapshot):
         self.mock_object(driver.HitachiHNASDriver, "_check_fs_mounted",
                          mock.Mock())
-        self.mock_object(ssh.HNASSSHBackend, "vvol_create", mock.Mock())
-        self.mock_object(ssh.HNASSSHBackend, "quota_add", mock.Mock())
-        self.mock_object(ssh.HNASSSHBackend, "tree_clone", mock.Mock())
-        self.mock_object(ssh.HNASSSHBackend, "cifs_share_add", mock.Mock())
-        self.mock_object(ssh.HNASSSHBackend, "nfs_export_add", mock.Mock())
+        self.mock_object(ssh.HNASSSHBackend, "vvol_create")
+        self.mock_object(ssh.HNASSSHBackend, "quota_add")
+        self.mock_object(ssh.HNASSSHBackend, "tree_clone")
+        self.mock_object(ssh.HNASSSHBackend, "cifs_share_add")
+        self.mock_object(ssh.HNASSSHBackend, "nfs_export_add")
 
         result = self._driver.create_share_from_snapshot('context',
                                                          share,
@@ -849,11 +877,11 @@ class HitachiHNASTestCase(test.TestCase):
     def test_create_share_from_snapshot_empty_snapshot(self):
         self.mock_object(driver.HitachiHNASDriver, "_check_fs_mounted",
                          mock.Mock())
-        self.mock_object(ssh.HNASSSHBackend, "vvol_create", mock.Mock())
-        self.mock_object(ssh.HNASSSHBackend, "quota_add", mock.Mock())
+        self.mock_object(ssh.HNASSSHBackend, "vvol_create")
+        self.mock_object(ssh.HNASSSHBackend, "quota_add")
         self.mock_object(ssh.HNASSSHBackend, "tree_clone", mock.Mock(
             side_effect=exception.HNASNothingToCloneException('msg')))
-        self.mock_object(ssh.HNASSSHBackend, "nfs_export_add", mock.Mock())
+        self.mock_object(ssh.HNASSSHBackend, "nfs_export_add")
 
         result = self._driver.create_share_from_snapshot('context', share_nfs,
                                                          snapshot_nfs)
@@ -879,9 +907,9 @@ class HitachiHNASTestCase(test.TestCase):
     def test_create_share_from_snapshot_invalid_protocol(self):
         self.mock_object(driver.HitachiHNASDriver, "_check_fs_mounted",
                          mock.Mock())
-        self.mock_object(ssh.HNASSSHBackend, "vvol_create", mock.Mock())
-        self.mock_object(ssh.HNASSSHBackend, "quota_add", mock.Mock())
-        self.mock_object(ssh.HNASSSHBackend, "tree_clone", mock.Mock())
+        self.mock_object(ssh.HNASSSHBackend, "vvol_create")
+        self.mock_object(ssh.HNASSSHBackend, "quota_add")
+        self.mock_object(ssh.HNASSSHBackend, "tree_clone")
 
         ex = self.assertRaises(exception.ShareBackendException,
                                self._driver.create_share_from_snapshot,
@@ -954,7 +982,7 @@ class HitachiHNASTestCase(test.TestCase):
         self.mock_object(driver.HitachiHNASDriver, "_check_fs_mounted",
                          mock.Mock())
         self.mock_object(manila.share.driver.ShareDriver,
-                         '_update_share_stats', mock.Mock())
+                         '_update_share_stats')
 
         self._driver._update_share_stats()
 
@@ -989,10 +1017,12 @@ class HitachiHNASTestCase(test.TestCase):
         else:
             expected = None
 
+        ssh.HNASSSHBackend.check_directory.assert_called_once_with(
+            snapshot['provider_location'])
         self.assertEqual(expected, result)
 
     def test_manage_existing_snapshot(self):
-        self.mock_object(ssh.HNASSSHBackend, 'check_snapshot',
+        self.mock_object(ssh.HNASSSHBackend, 'check_directory',
                          mock.Mock(return_value=True))
         self.mock_object(self._driver, '_ensure_snapshot',
                          mock.Mock(return_value=[]))
@@ -1003,7 +1033,7 @@ class HitachiHNASTestCase(test.TestCase):
         out = self._driver.manage_existing_snapshot(manage_snapshot,
                                                     {'size': 20})
 
-        ssh.HNASSSHBackend.check_snapshot.assert_called_with(
+        ssh.HNASSSHBackend.check_directory.assert_called_with(
             '/snapshots/aa4a7710-f326-41fb-ad18-b4ad587fc87a'
             '/snapshot18-05-2106')
         self._driver._ensure_snapshot.assert_called_with(
@@ -1019,7 +1049,7 @@ class HitachiHNASTestCase(test.TestCase):
             'path': '172.24.44.10:/snapshots/'
                     '3377b015-a695-4a5a-8aa5-9b931b023380'}]
 
-        self.mock_object(ssh.HNASSSHBackend, 'check_snapshot',
+        self.mock_object(ssh.HNASSSHBackend, 'check_directory',
                          mock.Mock(return_value=True))
         self.mock_object(self._driver, '_ensure_snapshot',
                          mock.Mock(return_value=[], side_effect=exc))
@@ -1035,7 +1065,7 @@ class HitachiHNASTestCase(test.TestCase):
             snapshot_mount_support_nfs,
             {'size': 20, 'export_locations': export_locations})
 
-        ssh.HNASSSHBackend.check_snapshot.assert_called_with(
+        ssh.HNASSSHBackend.check_directory.assert_called_with(
             '/snapshots/62125744-fcdd-4f55-a8c1-d1498102f634'
             '/3377b015-a695-4a5a-8aa5-9b931b023380')
         self._driver._ensure_snapshot.assert_called_with(
@@ -1078,7 +1108,7 @@ class HitachiHNASTestCase(test.TestCase):
         self.assertTrue(self.mock_log.debug.called)
 
     def test_manage_inexistent_snapshot_exception(self):
-        self.mock_object(ssh.HNASSSHBackend, 'check_snapshot',
+        self.mock_object(ssh.HNASSSHBackend, 'check_directory',
                          mock.Mock(return_value=False))
 
         self.assertRaises(exception.ManageInvalidShareSnapshot,
@@ -1105,7 +1135,7 @@ class HitachiHNASTestCase(test.TestCase):
         self.mock_object(ssh.HNASSSHBackend, 'tree_clone',
                          mock.Mock(side_effect=exc))
 
-        self._driver.revert_to_snapshot('context', snap, None)
+        self._driver.revert_to_snapshot('context', snap, None, None)
 
         driver.HitachiHNASDriver._check_fs_mounted.assert_called_once_with()
         ssh.HNASSSHBackend.tree_delete.assert_called_once_with(
@@ -1117,6 +1147,8 @@ class HitachiHNASTestCase(test.TestCase):
         ssh.HNASSSHBackend.tree_clone.assert_called_once_with(
             '/'.join(('/snapshots', snap['share_id'], snap['id'])),
             '/'.join(('/shares', snap['share_id'])))
+        ssh.HNASSSHBackend.check_directory.assert_called_once_with(
+            snap['provider_location'])
 
         if exc:
             self.assertTrue(self.mock_log.warning.called)
@@ -1141,6 +1173,8 @@ class HitachiHNASTestCase(test.TestCase):
         ssh.HNASSSHBackend.update_nfs_access_rule.assert_called_once_with(
             [access1['access_to'] + '(ro)', access2['access_to'] + '(ro)'],
             snapshot_id=snapshot_nfs['id'])
+        ssh.HNASSSHBackend.check_directory.assert_called_once_with(
+            snapshot_nfs['provider_location'])
         self.assertTrue(self.mock_log.debug.called)
 
     def test_nfs_snapshot_update_access_deny(self):
@@ -1156,6 +1190,8 @@ class HitachiHNASTestCase(test.TestCase):
 
         ssh.HNASSSHBackend.update_nfs_access_rule.assert_called_once_with(
             [], snapshot_id=snapshot_nfs['id'])
+        ssh.HNASSSHBackend.check_directory.assert_called_once_with(
+            snapshot_nfs['provider_location'])
         self.assertTrue(self.mock_log.debug.called)
 
     def test_nfs_snapshot_update_access_invalid_access_type(self):
@@ -1167,6 +1203,8 @@ class HitachiHNASTestCase(test.TestCase):
         self.assertRaises(exception.InvalidSnapshotAccess,
                           self._driver.snapshot_update_access, 'ctxt',
                           snapshot_nfs, [access1], [], [])
+        ssh.HNASSSHBackend.check_directory.assert_called_once_with(
+            snapshot_nfs['provider_location'])
 
     def test_cifs_snapshot_update_access_allow(self):
         access1 = {
@@ -1181,6 +1219,8 @@ class HitachiHNASTestCase(test.TestCase):
 
         ssh.HNASSSHBackend.cifs_allow_access.assert_called_with(
             snapshot_cifs['id'], access1['access_to'], 'ar', is_snapshot=True)
+        ssh.HNASSSHBackend.check_directory.assert_called_once_with(
+            snapshot_cifs['provider_location'])
         self.assertTrue(self.mock_log.debug.called)
 
     def test_cifs_snapshot_update_access_deny(self):
@@ -1196,6 +1236,8 @@ class HitachiHNASTestCase(test.TestCase):
 
         ssh.HNASSSHBackend.cifs_deny_access.assert_called_with(
             snapshot_cifs['id'], access1['access_to'], is_snapshot=True)
+        ssh.HNASSSHBackend.check_directory.assert_called_once_with(
+            snapshot_cifs['provider_location'])
         self.assertTrue(self.mock_log.debug.called)
 
     def test_cifs_snapshot_update_access_recovery_mode(self):
@@ -1226,4 +1268,6 @@ class HitachiHNASTestCase(test.TestCase):
         ssh.HNASSSHBackend.cifs_allow_access.assert_called_with(
             snapshot_cifs['id'], access2['access_to'].replace('\\', '\\\\'),
             'ar', is_snapshot=True)
+        ssh.HNASSSHBackend.check_directory.assert_called_once_with(
+            snapshot_cifs['provider_location'])
         self.assertTrue(self.mock_log.debug.called)
