@@ -80,12 +80,57 @@ class NFSHelperTestCase(test.TestCase):
         self._helper._ssh_exec.assert_called_once_with(
             self.server, ['sudo', 'exportfs'])
 
-    def test_create_export(self):
-        ret = self._helper.create_export(self.server, self.share_name)
-        expected_location = ':'.join([self.server['public_address'],
-                                      os.path.join(CONF.share_mount_path,
-                                                   self.share_name)])
-        self.assertEqual(expected_location, ret)
+    @ddt.data(
+        {"server": {"public_address": "1.2.3.4"}, "version": 4},
+        {"server": {"public_address": "1001::1002"}, "version": 6},
+        {"server": {"public_address": "1.2.3.4", "admin_ip": "5.6.7.8"},
+         "version": 4},
+        {"server": {"public_address": "1.2.3.4", "ip": "9.10.11.12"},
+         "version": 4},
+        {"server": {"public_address": "1001::1001", "ip": "1001::1002"},
+         "version": 6},
+        {"server": {"public_address": "1001::1002", "admin_ip": "1001::1002"},
+         "version": 6},
+        {"server": {"public_addresses": ["1001::1002"]}, "version": 6},
+        {"server": {"public_addresses": ["1.2.3.4", "1001::1002"]},
+         "version": {"1.2.3.4": 4, "1001::1002": 6}},
+    )
+    @ddt.unpack
+    def test_create_exports(self, server, version):
+        result = self._helper.create_exports(server, self.share_name)
+
+        expected_export_locations = []
+        path = os.path.join(CONF.share_mount_path, self.share_name)
+        service_address = server.get("admin_ip", server.get("ip"))
+        version_copy = version
+
+        def convert_address(address, version):
+            if version == 4:
+                return address
+            return "[%s]" % address
+
+        if 'public_addresses' in server:
+            pairs = list(map(lambda addr: (addr, False),
+                             server['public_addresses']))
+        else:
+            pairs = [(server['public_address'], False)]
+
+        service_address = server.get("admin_ip", server.get("ip"))
+        if service_address:
+            pairs.append((service_address, True))
+
+        for ip, is_admin in pairs:
+            if isinstance(version_copy, dict):
+                version = version_copy.get(ip)
+
+            expected_export_locations.append({
+                "path": "%s:%s" % (convert_address(ip, version), path),
+                "is_admin_only": is_admin,
+                "metadata": {
+                    "export_location_metadata_example": "example",
+                },
+            })
+        self.assertEqual(expected_export_locations, result)
 
     @ddt.data(const.ACCESS_LEVEL_RW, const.ACCESS_LEVEL_RO)
     def test_update_access(self, access_level):
@@ -105,11 +150,11 @@ class NFSHelperTestCase(test.TestCase):
         add_rules = [
             test_generic.get_fake_access_rule('2.2.2.2', access_level),
             test_generic.get_fake_access_rule('2.2.2.3', access_level),
-            test_generic.get_fake_access_rule('5.5.5.5/24', access_level)]
+            test_generic.get_fake_access_rule('5.5.5.0/24', access_level)]
         delete_rules = [
             test_generic.get_fake_access_rule('3.3.3.3', access_level),
             test_generic.get_fake_access_rule('4.4.4.4', access_level, 'user'),
-            test_generic.get_fake_access_rule('6.6.6.6/0', access_level)]
+            test_generic.get_fake_access_rule('0.0.0.0/0', access_level)]
         self._helper.update_access(self.server, self.share_name, access_rules,
                                    add_rules=add_rules,
                                    delete_rules=delete_rules)
@@ -119,19 +164,36 @@ class NFSHelperTestCase(test.TestCase):
             mock.call(self.server, ['sudo', 'exportfs', '-u',
                                     ':'.join(['3.3.3.3', local_path])]),
             mock.call(self.server, ['sudo', 'exportfs', '-u',
-                                    ':'.join(['6.6.6.6/0.0.0.0',
+                                    ':'.join(['*',
                                               local_path])]),
             mock.call(self.server, ['sudo', 'exportfs', '-o',
                                     expected_mount_options % access_level,
                                     ':'.join(['2.2.2.2', local_path])]),
             mock.call(self.server, ['sudo', 'exportfs', '-o',
                                     expected_mount_options % access_level,
-                                    ':'.join(['5.5.5.5/255.255.255.0',
+                                    ':'.join(['5.5.5.0/24',
                                               local_path])]),
         ])
         self._helper._sync_nfs_temp_and_perm_files.assert_has_calls([
             mock.call(self.server), mock.call(self.server)])
 
+    @ddt.data({'access': '10.0.0.1', 'result': '10.0.0.1'},
+              {'access': '10.0.0.1/32', 'result': '10.0.0.1'},
+              {'access': '10.0.0.0/24', 'result': '10.0.0.0/24'},
+              {'access': '1001::1001', 'result': '[1001::1001]'},
+              {'access': '1001::1000/128', 'result': '[1001::1000]'},
+              {'access': '1001::1000/124', 'result': '[1001::1000]/124'})
+    @ddt.unpack
+    def test__get_parsed_address_or_cidr(self, access, result):
+        self.assertEqual(result,
+                         self._helper._get_parsed_address_or_cidr(access))
+
+    @ddt.data('10.0.0.265', '10.0.0.1/33', '1001::10069', '1001::1000/129')
+    def test__get_parsed_address_or_cidr_with_invalid_access(self, access):
+        self.assertRaises(ValueError,
+                          self._helper._get_parsed_address_or_cidr,
+                          access)
+
     def test_update_access_invalid_type(self):
         access_rules = [test_generic.get_fake_access_rule(
             '2.2.2.2', const.ACCESS_LEVEL_RW, access_type='fake'), ]
@@ -164,7 +226,7 @@ class NFSHelperTestCase(test.TestCase):
                          '/shares/share-3\n\t\t30.0.0.4\n'
                          '/shares/share-3\n\t\t30.0.0.7\n')
         expected = ['20.0.0.3', '20.0.0.6']
-        result = self._helper._get_host_list(fake_exportfs, '/shares/share-1')
+        result = self._helper.get_host_list(fake_exportfs, '/shares/share-1')
         self.assertEqual(expected, result)
 
     @ddt.data(const.ACCESS_LEVEL_RW, const.ACCESS_LEVEL_RO)
@@ -176,7 +238,7 @@ class NFSHelperTestCase(test.TestCase):
         access_rules = [test_generic.get_fake_access_rule(
             '1.1.1.1', access_level), ]
         self.mock_object(self._helper, '_sync_nfs_temp_and_perm_files')
-        self.mock_object(self._helper, '_get_host_list',
+        self.mock_object(self._helper, 'get_host_list',
                          mock.Mock(return_value=['1.1.1.1']))
         self._helper.update_access(self.server, self.share_name, access_rules,
                                    [], [])
@@ -199,14 +261,37 @@ class NFSHelperTestCase(test.TestCase):
         self._helper._ssh_exec.assert_has_calls(
             [mock.call(self.server, mock.ANY) for i in range(1)])
 
-    @ddt.data('/foo/bar', '5.6.7.8:/bar/quuz', '5.6.7.88:/foo/quuz')
-    def test_get_exports_for_share(self, export_location):
+    @ddt.data('/foo/bar', '5.6.7.8:/bar/quuz', '5.6.7.9:/foo/quuz',
+              '[1001::1001]:/foo/bar', '[1001::1000]/:124:/foo/bar')
+    def test_get_exports_for_share_single_ip(self, export_location):
         server = dict(public_address='1.2.3.4')
 
         result = self._helper.get_exports_for_share(server, export_location)
 
         path = export_location.split(':')[-1]
-        self.assertEqual([':'.join([server['public_address'], path])], result)
+        expected_export_locations = [
+            {"is_admin_only": False,
+             "path": "%s:%s" % (server["public_address"], path),
+             "metadata": {"export_location_metadata_example": "example"}}
+        ]
+        self.assertEqual(expected_export_locations, result)
+
+    @ddt.data('/foo/bar', '5.6.7.8:/bar/quuz', '5.6.7.9:/foo/quuz')
+    def test_get_exports_for_share_multi_ip(self, export_location):
+        server = dict(public_addresses=['1.2.3.4', '1.2.3.5'])
+
+        result = self._helper.get_exports_for_share(server, export_location)
+
+        path = export_location.split(':')[-1]
+        expected_export_locations = list(map(
+            lambda addr: {
+                "is_admin_only": False,
+                "path": "%s:%s" % (addr, path),
+                "metadata": {"export_location_metadata_example": "example"}
+            },
+            server['public_addresses'])
+        )
+        self.assertEqual(expected_export_locations, result)
 
     @ddt.data(
         {'public_address_with_suffix': 'foo'},
@@ -219,18 +304,40 @@ class NFSHelperTestCase(test.TestCase):
             exception.ManilaException,
             self._helper.get_exports_for_share, server, export_location)
 
-    @ddt.data('/foo/bar', '5.6.7.8:/foo/bar', '5.6.7.88:fake:/foo/bar')
+    @ddt.data('/foo/bar', '5.6.7.8:/foo/bar', '5.6.7.88:fake:/foo/bar',
+              '[1001::1002]:/foo/bar', '[1001::1000]/124:/foo/bar')
     def test_get_share_path_by_export_location(self, export_location):
         result = self._helper.get_share_path_by_export_location(
             dict(), export_location)
 
         self.assertEqual('/foo/bar', result)
 
-    def test_disable_access_for_maintenance(self):
+    @ddt.data(
+        ('/shares/fake_share1\n\t\t1.1.1.10\n'
+         '/shares/fake_share2\n\t\t1.1.1.16\n'
+         '/mnt/fake_share1 1.1.1.11', False),
+        ('/shares/fake_share_name\n\t\t1.1.1.10\n'
+         '/shares/fake_share_name\n\t\t1.1.1.16\n'
+         '/mnt/fake_share1\n\t\t1.1.1.11', True),
+        ('/mnt/fake_share_name\n\t\t1.1.1.11\n'
+         '/shares/fake_share_name\n\t\t1.1.1.10\n'
+         '/shares/fake_share_name\n\t\t1.1.1.16\n', True))
+    @ddt.unpack
+    def test_disable_access_for_maintenance(self, output, hosts_match):
         fake_maintenance_path = "fake.path"
-        share_mount_path = os.path.join(
-            self._helper.configuration.share_mount_path, self.share_name)
-        self.mock_object(self._helper, '_ssh_exec')
+        self._helper.configuration.share_mount_path = '/shares'
+        local_path = os.path.join(self._helper.configuration.share_mount_path,
+                                  self.share_name)
+
+        def fake_ssh_exec(*args, **kwargs):
+            if 'exportfs' in args[1] and '-u' not in args[1]:
+                return output, ''
+            else:
+                return '', ''
+
+        self.mock_object(self._helper, '_ssh_exec',
+                         mock.Mock(side_effect=fake_ssh_exec))
+
         self.mock_object(self._helper, '_sync_nfs_temp_and_perm_files')
         self.mock_object(self._helper, '_get_maintenance_file_path',
                          mock.Mock(return_value=fake_maintenance_path))
@@ -241,13 +348,21 @@ class NFSHelperTestCase(test.TestCase):
         self._helper._ssh_exec.assert_any_call(
             self.server,
             ['cat', const.NFS_EXPORTS_FILE,
-             '| grep', self.share_name,
-             '| sudo tee', fake_maintenance_path]
-        )
-        self._helper._ssh_exec.assert_any_call(
-            self.server,
-            ['sudo', 'exportfs', '-u', share_mount_path]
+             '|', 'grep', self.share_name,
+             '|', 'sudo', 'tee', fake_maintenance_path]
         )
+        self._helper._ssh_exec.assert_has_calls([
+            mock.call(self.server, ['sudo', 'exportfs']),
+        ])
+
+        if hosts_match:
+            self._helper._ssh_exec.assert_has_calls([
+                mock.call(self.server, ['sudo', 'exportfs', '-u',
+                                        ':'.join(['1.1.1.10', local_path])]),
+                mock.call(self.server, ['sudo', 'exportfs', '-u',
+                                        ':'.join(['1.1.1.16', local_path])]),
+            ])
+
         self._helper._sync_nfs_temp_and_perm_files.assert_called_once_with(
             self.server
         )
@@ -264,8 +379,8 @@ class NFSHelperTestCase(test.TestCase):
         self._helper._ssh_exec.assert_called_once_with(
             self.server,
             ['cat', fake_maintenance_path,
-             '| sudo tee -a', const.NFS_EXPORTS_FILE,
-             '&& sudo exportfs -r', '&& sudo rm -f',
+             '|', 'sudo', 'tee', '-a', const.NFS_EXPORTS_FILE,
+             '&&', 'sudo', 'exportfs', '-r', '&&', 'sudo', 'rm', '-f',
              fake_maintenance_path]
         )
 
@@ -307,9 +422,14 @@ class CIFSHelperIPAccessTestCase(test.TestCase):
         self.mock_object(self._helper, '_ssh_exec',
                          mock.Mock(side_effect=fake_ssh_exec))
 
-        ret = self._helper.create_export(self.server_details, self.share_name)
-        expected_location = '\\\\%s\\%s' % (
-            self.server_details['public_address'], self.share_name)
+        ret = self._helper.create_exports(self.server_details, self.share_name)
+
+        expected_location = [{
+            "is_admin_only": False,
+            "path": "\\\\%s\\%s" % (
+                self.server_details['public_address'], self.share_name),
+            "metadata": {"export_location_metadata_example": "example"}
+        }]
         self.assertEqual(expected_location, ret)
         share_path = os.path.join(
             self._helper.configuration.share_mount_path,
@@ -338,14 +458,19 @@ class CIFSHelperIPAccessTestCase(test.TestCase):
                          ))
 
         self.assertRaises(
-            exception.ManilaException, self._helper.create_export,
+            exception.ManilaException, self._helper.create_exports,
             self.server_details, self.share_name)
 
-    def test_create_export_share_exist_recreate_true(self):
-        ret = self._helper.create_export(self.server_details, self.share_name,
-                                         recreate=True)
-        expected_location = '\\\\%s\\%s' % (
-            self.server_details['public_address'], self.share_name)
+    def test_create_exports_share_exist_recreate_true(self):
+        ret = self._helper.create_exports(
+            self.server_details, self.share_name, recreate=True)
+
+        expected_location = [{
+            "is_admin_only": False,
+            "path": "\\\\%s\\%s" % (
+                self.server_details['public_address'], self.share_name),
+            "metadata": {"export_location_metadata_example": "example"}
+        }]
         self.assertEqual(expected_location, ret)
         share_path = os.path.join(
             self._helper.configuration.share_mount_path,
@@ -372,7 +497,7 @@ class CIFSHelperIPAccessTestCase(test.TestCase):
     def test_create_export_share_exist_recreate_false(self):
         self.assertRaises(
             exception.ShareBackendException,
-            self._helper.create_export,
+            self._helper.create_exports,
             self.server_details,
             self.share_name,
             recreate=False,
@@ -384,8 +509,9 @@ class CIFSHelperIPAccessTestCase(test.TestCase):
             ),
         ])
 
-    def test_remove_export(self):
-        self._helper.remove_export(self.server_details, self.share_name)
+    def test_remove_exports(self):
+        self._helper.remove_exports(self.server_details, self.share_name)
+
         self._helper._ssh_exec.assert_called_once_with(
             self.server_details,
             ['sudo', 'net', 'conf', 'delshare', self.share_name],
@@ -403,7 +529,7 @@ class CIFSHelperIPAccessTestCase(test.TestCase):
         self.mock_object(self._helper, '_ssh_exec',
                          mock.Mock(side_effect=fake_ssh_exec))
 
-        self._helper.remove_export(self.server_details, self.share_name)
+        self._helper.remove_exports(self.server_details, self.share_name)
 
         self._helper._ssh_exec.assert_has_calls([
             mock.call(
@@ -448,8 +574,8 @@ class CIFSHelperIPAccessTestCase(test.TestCase):
                                    access_rules, [], [])
         self._helper._ssh_exec.assert_called_once_with(
             self.server_details, ['sudo', 'net', 'conf', 'setparm',
-                                  self.share_name, '"hosts allow"',
-                                  '"1.1.1.1"'])
+                                  self.share_name, 'hosts allow',
+                                  '1.1.1.1'])
 
     def test_get_allow_hosts(self):
         self.mock_object(self._helper, '_ssh_exec',
@@ -460,7 +586,7 @@ class CIFSHelperIPAccessTestCase(test.TestCase):
             self.server_details, self.share_name)
         self.assertEqual(expected, result)
         cmd = ['sudo', 'net', 'conf', 'getparm', self.share_name,
-               '\"hosts allow\"']
+               'hosts allow']
         self._helper._ssh_exec.assert_called_once_with(
             self.server_details, cmd)
 
@@ -484,10 +610,14 @@ class CIFSHelperIPAccessTestCase(test.TestCase):
 
         result = self._helper.get_exports_for_share(server, export_location)
 
-        expected_export_location = ['\\\\%s\\foo' % server['public_address']]
+        expected_export_location = [{
+            "is_admin_only": False,
+            "path": "\\\\%s\\foo" % server['public_address'],
+            "metadata": {"export_location_metadata_example": "example"}
+        }]
         self.assertEqual(expected_export_location, result)
-        self._helper._get_share_group_name_from_export_location.\
-            assert_called_once_with(export_location)
+        (self._helper._get_share_group_name_from_export_location.
+            assert_called_once_with(export_location))
 
     @ddt.data(
         {'public_address_with_suffix': 'foo'},
@@ -518,8 +648,8 @@ class CIFSHelperIPAccessTestCase(test.TestCase):
         self.assertEqual('/bar/quuz', result)
         self._helper._ssh_exec.assert_called_once_with(
             fake_server, ['sudo', 'net', 'conf', 'getparm', 'foo', 'path'])
-        self._helper._get_share_group_name_from_export_location.\
-            assert_called_once_with(export_location)
+        (self._helper._get_share_group_name_from_export_location.
+            assert_called_once_with(export_location))
 
     def test_disable_access_for_maintenance(self):
         allowed_hosts = ['test', 'test2']
@@ -537,7 +667,8 @@ class CIFSHelperIPAccessTestCase(test.TestCase):
             self.server_details, self.share_name)
         self._helper._set_allow_hosts.assert_called_once_with(
             self.server_details, [], self.share_name)
-        valid_cmd = ['echo', "'test test2'", '| sudo tee', maintenance_path]
+        valid_cmd = ['echo', "'test test2'", '|', 'sudo', 'tee',
+                     maintenance_path]
         self._helper._ssh_exec.assert_called_once_with(
             self.server_details, valid_cmd)
 
@@ -557,7 +688,7 @@ class CIFSHelperIPAccessTestCase(test.TestCase):
         self._helper._ssh_exec.assert_any_call(
             self.server_details, ['cat', fake_maintenance_path])
         self._helper._ssh_exec.assert_any_call(
-            self.server_details, ['sudo rm -f', fake_maintenance_path])
+            self.server_details, ['sudo', 'rm', '-f', fake_maintenance_path])
 
 
 @ddt.ddt
@@ -601,10 +732,10 @@ class CIFSHelperUserAccessTestCase(test.TestCase):
         self._helper._ssh_exec.assert_has_calls([
             mock.call(self.server_details,
                       ['sudo', 'net', 'conf', 'setparm', self.share_name,
-                       'valid users', '"user1"']),
+                       'valid users', 'user1']),
             mock.call(self.server_details,
                       ['sudo', 'net', 'conf', 'setparm', self.share_name,
-                       'read list', '"user2"'])
+                       'read list', 'user2'])
         ])
 
     def test_update_access_exception_level(self):
