@@ -22,6 +22,7 @@ from manila.common import constants
 from manila import context
 from manila import db
 from manila import exception
+from manila.share import access as access_helper
 from manila.share import api as share_api
 from manila.share import migration
 from manila import test
@@ -39,9 +40,10 @@ class ShareMigrationHelperTestCase(test.TestCase):
         self.share_instance = db_utils.create_share_instance(
             share_id=self.share['id'],
             share_network_id='fake_network_id')
+        self.access_helper = access_helper.ShareInstanceAccess(db, None)
         self.context = context.get_admin_context()
         self.helper = migration.ShareMigrationHelper(
-            self.context, db, self.share)
+            self.context, db, self.share, self.access_helper)
 
     def test_delete_instance_and_wait(self):
 
@@ -113,7 +115,7 @@ class ShareMigrationHelperTestCase(test.TestCase):
 
     def test_create_instance_and_wait(self):
 
-        host = {'host': 'fake_host'}
+        host = 'fake_host'
 
         share_instance_creating = db_utils.create_share_instance(
             share_id=self.share['id'], status=constants.STATUS_CREATING,
@@ -131,13 +133,13 @@ class ShareMigrationHelperTestCase(test.TestCase):
         self.mock_object(time, 'sleep')
 
         # run
-        self.helper.create_instance_and_wait(self.share,
-                                             share_instance_creating, host)
+        self.helper.create_instance_and_wait(
+            self.share, host, 'fake_net_id', 'fake_az_id', 'fake_type_id')
 
         # asserts
         share_api.API.create_instance.assert_called_once_with(
-            self.context, self.share, self.share_instance['share_network_id'],
-            'fake_host')
+            self.context, self.share, 'fake_net_id', 'fake_host', 'fake_az_id',
+            share_type_id='fake_type_id')
 
         db.share_instance_get.assert_has_calls([
             mock.call(self.context, share_instance_creating['id'],
@@ -149,7 +151,7 @@ class ShareMigrationHelperTestCase(test.TestCase):
 
     def test_create_instance_and_wait_status_error(self):
 
-        host = {'host': 'fake_host'}
+        host = 'fake_host'
 
         share_instance_error = db_utils.create_share_instance(
             share_id=self.share['id'], status=constants.STATUS_ERROR,
@@ -163,14 +165,15 @@ class ShareMigrationHelperTestCase(test.TestCase):
                          mock.Mock(return_value=share_instance_error))
 
         # run
-        self.assertRaises(exception.ShareMigrationFailed,
-                          self.helper.create_instance_and_wait,
-                          self.share, self.share_instance, host)
+        self.assertRaises(
+            exception.ShareMigrationFailed,
+            self.helper.create_instance_and_wait, self.share,
+            host, 'fake_net_id', 'fake_az_id', 'fake_type_id')
 
         # asserts
         share_api.API.create_instance.assert_called_once_with(
-            self.context, self.share, self.share_instance['share_network_id'],
-            'fake_host')
+            self.context, self.share, 'fake_net_id', 'fake_host', 'fake_az_id',
+            share_type_id='fake_type_id')
 
         db.share_instance_get.assert_called_once_with(
             self.context, share_instance_error['id'], with_share_data=True)
@@ -180,7 +183,7 @@ class ShareMigrationHelperTestCase(test.TestCase):
 
     def test_create_instance_and_wait_timeout(self):
 
-        host = {'host': 'fake_host'}
+        host = 'fake_host'
 
         share_instance_creating = db_utils.create_share_instance(
             share_id=self.share['id'], status=constants.STATUS_CREATING,
@@ -202,14 +205,15 @@ class ShareMigrationHelperTestCase(test.TestCase):
         self.mock_object(time, 'time', mock.Mock(side_effect=[now, timeout]))
 
         # run
-        self.assertRaises(exception.ShareMigrationFailed,
-                          self.helper.create_instance_and_wait,
-                          self.share, self.share_instance, host)
+        self.assertRaises(
+            exception.ShareMigrationFailed,
+            self.helper.create_instance_and_wait,  self.share,
+            host, 'fake_net_id', 'fake_az_id', 'fake_type_id')
 
         # asserts
         share_api.API.create_instance.assert_called_once_with(
-            self.context, self.share, self.share_instance['share_network_id'],
-            'fake_host')
+            self.context, self.share, 'fake_net_id', 'fake_host', 'fake_az_id',
+            share_type_id='fake_type_id')
 
         db.share_instance_get.assert_called_once_with(
             self.context, share_instance_creating['id'], with_share_data=True)
@@ -219,63 +223,32 @@ class ShareMigrationHelperTestCase(test.TestCase):
         self.helper.cleanup_new_instance.assert_called_once_with(
             share_instance_creating)
 
-    def test_change_to_read_only_with_ro_support(self):
+    @ddt.data(constants.STATUS_ACTIVE, constants.STATUS_ERROR,
+              constants.STATUS_CREATING)
+    def test_wait_for_share_server(self, status):
 
-        share_instance = db_utils.create_share_instance(
-            share_id=self.share['id'], status=constants.STATUS_AVAILABLE)
-
-        access = db_utils.create_access(share_id=self.share['id'],
-                                        access_to='fake_ip',
-                                        access_level='rw')
-
-        server = db_utils.create_share_server(share_id=self.share['id'])
+        server = db_utils.create_share_server(status=status)
 
         # mocks
-        share_driver = mock.Mock()
-        self.mock_object(share_driver, 'update_access')
-
-        self.mock_object(db, 'share_access_get_all_for_instance',
-                         mock.Mock(return_value=[access]))
+        self.mock_object(db, 'share_server_get',
+                         mock.Mock(return_value=server))
 
         # run
-        self.helper.change_to_read_only(share_instance, server, True,
-                                        share_driver)
+        if status == constants.STATUS_ACTIVE:
+            result = self.helper.wait_for_share_server('fake_server_id')
+            self.assertEqual(server, result)
+        elif status == constants.STATUS_ERROR:
+            self.assertRaises(
+                exception.ShareServerNotCreated,
+                self.helper.wait_for_share_server, 'fake_server_id')
+        else:
+            self.mock_object(time, 'sleep')
+            self.assertRaises(
+                exception.ShareServerNotReady,
+                self.helper.wait_for_share_server, 'fake_server_id')
 
         # asserts
-        db.share_access_get_all_for_instance.assert_called_once_with(
-            self.context, share_instance['id'])
-        share_driver.update_access.assert_called_once_with(
-            self.context, share_instance, [access], add_rules=[],
-            delete_rules=[], share_server=server)
-
-    def test_change_to_read_only_without_ro_support(self):
-
-        share_instance = db_utils.create_share_instance(
-            share_id=self.share['id'], status=constants.STATUS_AVAILABLE)
-
-        access = db_utils.create_access(share_id=self.share['id'],
-                                        access_to='fake_ip',
-                                        access_level='rw')
-
-        server = db_utils.create_share_server(share_id=self.share['id'])
-
-        # mocks
-        share_driver = mock.Mock()
-        self.mock_object(share_driver, 'update_access')
-
-        self.mock_object(db, 'share_access_get_all_for_instance',
-                         mock.Mock(return_value=[access]))
-
-        # run
-        self.helper.change_to_read_only(share_instance, server, False,
-                                        share_driver)
-
-        # asserts
-        db.share_access_get_all_for_instance.assert_called_once_with(
-            self.context, share_instance['id'])
-        share_driver.update_access.assert_called_once_with(
-            self.context, share_instance, [], add_rules=[],
-            delete_rules=[access], share_server=server)
+        db.share_server_get.assert_called_with(self.context, 'fake_server_id')
 
     def test_revert_access_rules(self):
 
@@ -289,36 +262,37 @@ class ShareMigrationHelperTestCase(test.TestCase):
         server = db_utils.create_share_server(share_id=self.share['id'])
 
         # mocks
-        share_driver = mock.Mock()
-        self.mock_object(share_driver, 'update_access')
-
-        self.mock_object(db, 'share_access_get_all_for_instance',
-                         mock.Mock(return_value=[access]))
+        self.mock_object(self.access_helper, 'update_access_rules')
+        get_and_update_call = self.mock_object(
+            self.access_helper, 'get_and_update_share_instance_access_rules',
+            mock.Mock(return_value=[access]))
 
         # run
-        self.helper.revert_access_rules(share_instance, server, share_driver)
+        self.helper.revert_access_rules(share_instance, server)
 
         # asserts
-        db.share_access_get_all_for_instance.assert_called_once_with(
-            self.context, share_instance['id'])
-        share_driver.update_access.assert_called_once_with(
-            self.context, share_instance, [access], add_rules=[],
-            delete_rules=[], share_server=server)
+        get_and_update_call.assert_called_once_with(
+            self.context, share_instance_id=share_instance['id'],
+            updates={'state': constants.ACCESS_STATE_QUEUED_TO_APPLY})
+        self.access_helper.update_access_rules.assert_called_once_with(
+            self.context, share_instance['id'], share_server=server)
 
-    def test_apply_new_access_rules(self):
+    @ddt.data(True, False)
+    def test_apply_new_access_rules_there_are_rules(self, prior_rules):
 
         new_share_instance = db_utils.create_share_instance(
             share_id=self.share['id'], status=constants.STATUS_AVAILABLE,
             access_rules_status='active')
-
-        access = db_utils.create_access(share_id=self.share['id'],
-                                        access_to='fake_ip',
-                                        access_level='rw')
+        rules = None
+        if prior_rules:
+            rules = [
+                db_utils.create_access(
+                    share_id=self.share['id'], access_to='fake_ip')
+            ]
 
         # mocks
-        self.mock_object(db, 'share_instance_access_copy')
-        self.mock_object(db, 'share_access_get_all_for_instance',
-                         mock.Mock(return_value=[access]))
+        self.mock_object(db, 'share_instance_access_copy', mock.Mock(
+            return_value=rules))
         self.mock_object(share_api.API, 'allow_access_to_instance')
         self.mock_object(utils, 'wait_for_access_update')
 
@@ -326,15 +300,17 @@ class ShareMigrationHelperTestCase(test.TestCase):
         self.helper.apply_new_access_rules(new_share_instance)
 
         # asserts
-        db.share_instance_access_copy(self.context, self.share['id'],
-                                      new_share_instance['id'])
-        db.share_access_get_all_for_instance.assert_called_once_with(
-            self.context, new_share_instance['id'])
-        share_api.API.allow_access_to_instance.assert_called_with(
-            self.context, new_share_instance, [access])
-        utils.wait_for_access_update.assert_called_with(
-            self.context, db, new_share_instance,
-            self.helper.migration_wait_access_rules_timeout)
+        db.share_instance_access_copy.assert_called_once_with(
+            self.context, self.share['id'], new_share_instance['id'])
+        if prior_rules:
+            share_api.API.allow_access_to_instance.assert_called_with(
+                self.context, new_share_instance)
+            utils.wait_for_access_update.assert_called_with(
+                self.context, db, new_share_instance,
+                self.helper.migration_wait_access_rules_timeout)
+        else:
+            self.assertFalse(share_api.API.allow_access_to_instance.called)
+            self.assertFalse(utils.wait_for_access_update.called)
 
     @ddt.data(None, Exception('fake'))
     def test_cleanup_new_instance(self, exc):
@@ -353,26 +329,24 @@ class ShareMigrationHelperTestCase(test.TestCase):
             self.share_instance)
 
         if exc:
-            migration.LOG.warning.called
+            self.assertEqual(1, migration.LOG.warning.call_count)
 
     @ddt.data(None, Exception('fake'))
     def test_cleanup_access_rules(self, exc):
 
         # mocks
         server = db_utils.create_share_server()
-        share_driver = mock.Mock()
         self.mock_object(self.helper, 'revert_access_rules',
                          mock.Mock(side_effect=exc))
 
         self.mock_object(migration.LOG, 'warning')
 
         # run
-        self.helper.cleanup_access_rules(self.share_instance, server,
-                                         share_driver)
+        self.helper.cleanup_access_rules(self.share_instance, server)
 
         # asserts
         self.helper.revert_access_rules.assert_called_once_with(
-            self.share_instance, server, share_driver)
+            self.share_instance, server)
 
         if exc:
-            migration.LOG.warning.called
+            self.assertEqual(1, migration.LOG.warning.call_count)
