@@ -16,6 +16,7 @@
 
 import datetime
 import errno
+import json
 import socket
 import time
 
@@ -25,6 +26,7 @@ from oslo_config import cfg
 from oslo_utils import timeutils
 from oslo_utils import uuidutils
 import paramiko
+import six
 from webob import exc
 
 import manila
@@ -114,25 +116,19 @@ class GenericUtilsTestCase(test.TestCase):
     @ddt.data(
         (("3G", "G"), 3.0),
         (("4.1G", "G"), 4.1),
-        (("4,1G", "G"), 4.1),
         (("5.23G", "G"), 5.23),
-        (("5,23G", "G"), 5.23),
         (("9728M", "G"), 9.5),
         (("8192K", "G"), 0.0078125),
         (("2T", "G"), 2048.0),
         (("2.1T", "G"), 2150.4),
-        (("2,1T", "G"), 2150.4),
         (("3P", "G"), 3145728.0),
         (("3.4P", "G"), 3565158.4),
-        (("3,4P", "G"), 3565158.4),
         (("9728M", "M"), 9728.0),
         (("9728.2381T", "T"), 9728.2381),
-        (("9728,2381T", "T"), 9728.2381),
         (("0", "G"), 0.0),
         (("512", "M"), 0.00048828125),
         (("2097152.", "M"), 2.0),
         ((".1024", "K"), 0.0001),
-        ((",1024", "K"), 0.0001),
         (("2048G", "T"), 2.0),
         (("65536G", "P"), 0.0625),
     )
@@ -149,14 +145,6 @@ class GenericUtilsTestCase(test.TestCase):
         ("1KM", "G"),
         ("K1M", "G"),
         ("M1K", "G"),
-        ("1.2fake", "G"),
-        ("1,2fake", "G"),
-        ("2.2GG", "G"),
-        ("1.1KM", "G"),
-        ("K2.2M", "G"),
-        ("K2,2M", "G"),
-        ("M2.2K", "G"),
-        ("M2,2K", "G"),
         ("", "G"),
         (23, "G"),
         (23.0, "G"),
@@ -537,9 +525,6 @@ class TestComparableMixin(test.TestCase):
 
 
 class TestRetryDecorator(test.TestCase):
-    def setUp(self):
-        super(TestRetryDecorator, self).setUp()
-
     def test_no_retry_required(self):
         self.counter = 0
 
@@ -662,6 +647,28 @@ class TestRetryDecorator(test.TestCase):
             self.assertRaises(ValueError, raise_unexpected_error)
             self.assertFalse(mock_sleep.called)
 
+    def test_wrong_retries_num(self):
+        self.assertRaises(ValueError, utils.retry, exception.ManilaException,
+                          retries=-1)
+
+    def test_max_backoff_sleep(self):
+        self.counter = 0
+
+        with mock.patch.object(time, 'sleep') as mock_sleep:
+            @utils.retry(exception.ManilaException,
+                         retries=0,
+                         backoff_rate=2,
+                         backoff_sleep_max=4)
+            def fails_then_passes():
+                self.counter += 1
+                if self.counter < 5:
+                    raise exception.ManilaException(data='fake')
+                else:
+                    return 'success'
+
+            self.assertEqual('success', fails_then_passes())
+            mock_sleep.assert_has_calls(map(mock.call, [2, 4, 4, 4]))
+
 
 @ddt.ddt
 class RequireDriverInitializedTestCase(test.TestCase):
@@ -758,3 +765,74 @@ class ShareMigrationHelperTestCase(test.TestCase):
         self.assertRaises(expected_exc,
                           utils.wait_for_access_update, self.context,
                           db, fake_instance, 1)
+
+
+@ddt.ddt
+class ConvertStrTestCase(test.TestCase):
+
+    def test_convert_str_str_input(self):
+        self.mock_object(utils.encodeutils, 'safe_encode')
+        input_value = six.text_type("string_input")
+
+        output_value = utils.convert_str(input_value)
+
+        if six.PY2:
+            utils.encodeutils.safe_encode.assert_called_once_with(input_value)
+            self.assertEqual(
+                utils.encodeutils.safe_encode.return_value, output_value)
+        else:
+            self.assertEqual(0, utils.encodeutils.safe_encode.call_count)
+            self.assertEqual(input_value, output_value)
+
+    def test_convert_str_bytes_input(self):
+        self.mock_object(utils.encodeutils, 'safe_encode')
+        if six.PY2:
+            input_value = six.binary_type("binary_input")
+        else:
+            input_value = six.binary_type("binary_input", "utf-8")
+
+        output_value = utils.convert_str(input_value)
+
+        if six.PY2:
+            utils.encodeutils.safe_encode.assert_called_once_with(input_value)
+            self.assertEqual(
+                utils.encodeutils.safe_encode.return_value, output_value)
+        else:
+            self.assertEqual(0, utils.encodeutils.safe_encode.call_count)
+            self.assertIsInstance(output_value, six.string_types)
+            self.assertEqual(six.text_type("binary_input"), output_value)
+
+
+@ddt.ddt
+class TestDisableNotifications(test.TestCase):
+    def test_do_nothing_getter(self):
+        """Test any attribute will always return the same instance (self)."""
+        donothing = utils.DoNothing()
+        self.assertIs(donothing, donothing.anyname)
+
+    def test_do_nothing_caller(self):
+        """Test calling the object will always return the same instance."""
+        donothing = utils.DoNothing()
+        self.assertIs(donothing, donothing())
+
+    def test_do_nothing_json_serializable(self):
+        """Test calling the object will always return the same instance."""
+        donothing = utils.DoNothing()
+        self.assertEqual('""', json.dumps(donothing))
+
+    @utils.if_notifications_enabled
+    def _decorated_method(self):
+        return mock.sentinel.success
+
+    def test_if_notification_enabled_when_enabled(self):
+        """Test method is called when notifications are enabled."""
+        result = self._decorated_method()
+        self.assertEqual(mock.sentinel.success, result)
+
+    @ddt.data([], ['noop'], ['noop', 'noop'])
+    def test_if_notification_enabled_when_disabled(self, driver):
+        """Test method is not called when notifications are disabled."""
+        self.override_config('driver', driver,
+                             group='oslo_messaging_notifications')
+        result = self._decorated_method()
+        self.assertEqual(utils.DO_NOTHING, result)
