@@ -23,7 +23,6 @@ from cinderclient import exceptions as cinder_exception
 from cinderclient.v2 import client as cinder_client
 from keystoneauth1 import loading as ks_loading
 from oslo_config import cfg
-from oslo_log import log
 import six
 
 from manila.common import client_auth
@@ -34,6 +33,7 @@ from manila import exception
 from manila.i18n import _
 
 CINDER_GROUP = 'cinder'
+AUTH_OBJ = None
 
 cinder_deprecated_opts = [
     cfg.StrOpt('cinder_catalog_info',
@@ -96,6 +96,11 @@ cinder_opts = [
                 help='Allow to perform insecure SSL requests to cinder.',
                 deprecated_group='DEFAULT',
                 deprecated_name="cinder_api_insecure"),
+    cfg.StrOpt('endpoint_type',
+               default='publicURL',
+               help='Endpoint type to be used with cinder client calls.'),
+    cfg.StrOpt('region_name',
+               help='Region name for connecting to cinder.'),
     ]
 
 CONF = cfg.CONF
@@ -106,34 +111,30 @@ ks_loading.register_session_conf_options(CONF, CINDER_GROUP)
 ks_loading.register_auth_conf_options(CONF, CINDER_GROUP)
 
 
-LOG = log.getLogger(__name__)
-
-
 def list_opts():
     return client_auth.AuthClientLoader.list_opts(CINDER_GROUP)
 
 
-auth_obj = None
-
-
 def cinderclient(context):
-    global auth_obj
-    if not auth_obj:
+    global AUTH_OBJ
+    if not AUTH_OBJ:
         deprecated_opts_for_v2 = {
-            'username': CONF.nova_admin_username,
-            'password': CONF.nova_admin_password,
-            'tenant_name': CONF.nova_admin_tenant_name,
-            'auth_url': CONF.nova_admin_auth_url,
+            'username': CONF.cinder_admin_username,
+            'password': CONF.cinder_admin_password,
+            'tenant_name': CONF.cinder_admin_tenant_name,
+            'auth_url': CONF.cinder_admin_auth_url,
         }
-        auth_obj = client_auth.AuthClientLoader(
+        AUTH_OBJ = client_auth.AuthClientLoader(
             client_class=cinder_client.Client,
             exception_module=cinder_exception,
             cfg_group=CINDER_GROUP,
             deprecated_opts_for_v2=deprecated_opts_for_v2)
-    return auth_obj.get_client(context,
+    return AUTH_OBJ.get_client(context,
                                insecure=CONF[CINDER_GROUP].api_insecure,
                                cacert=CONF[CINDER_GROUP].ca_certificates_file,
-                               retries=CONF[CINDER_GROUP].http_retries)
+                               retries=CONF[CINDER_GROUP].http_retries,
+                               endpoint_type=CONF[CINDER_GROUP].endpoint_type,
+                               region_name=CONF[CINDER_GROUP].region_name)
 
 
 def _untranslate_volume_summary_view(context, vol):
