@@ -30,7 +30,7 @@ ShareGroup = [
                help="The minimum api microversion is configured to be the "
                     "value of the minimum microversion supported by Manila."),
     cfg.StrOpt("max_api_microversion",
-               default="2.32",
+               default="2.40",
                help="The maximum api microversion is configured to be the "
                     "value of the latest microversion supported by Manila."),
     cfg.StrOpt("region",
@@ -104,10 +104,19 @@ ShareGroup = [
                      "False if the driver being tested does not support "
                      "creating shares from snapshots."),
     cfg.BoolOpt("capability_revert_to_snapshot_support",
+                deprecated_for_removal=True,
+                deprecated_reason="Redundant configuration option. Please use "
+                                  "'run_revert_to_snapshot_tests' config "
+                                  "option instead.",
                 help="Defines extra spec that satisfies specific back end "
                      "capability called 'revert_to_snapshot_support' "
                      "and will be used for setting up custom share type. "
                      "Defaults to the value of run_revert_to_snapshot_tests."),
+    cfg.StrOpt("capability_sg_consistent_snapshot_support",
+               choices=["host", "pool", None],
+               help="Backend capability to create consistent snapshots of "
+                    "share group members. Will be used with creation "
+                    "of new share group types as group spec."),
     cfg.StrOpt("share_network_id",
                default="",
                help="Some backend drivers requires share network "
