@@ -35,18 +35,12 @@ class SharesClient(rest_client.RestClient):
     It handles shares and access to it in OpenStack.
     """
 
-    def __init__(self, auth_provider):
-        super(SharesClient, self).__init__(
-            auth_provider,
-            CONF.share.catalog_type,
-            CONF.share.region or CONF.identity.region,
-            endpoint_type=CONF.share.endpoint_type)
+    def __init__(self, auth_provider, **kwargs):
+        super(SharesClient, self).__init__(auth_provider, **kwargs)
         self.share_protocol = None
         if CONF.share.enable_protocols:
             self.share_protocol = CONF.share.enable_protocols[0]
         self.share_network_id = CONF.share.share_network_id
-        self.build_interval = CONF.share.build_interval
-        self.build_timeout = CONF.share.build_timeout
         self.share_size = CONF.share.share_size
 
     def create_share(self, share_protocol=None, size=None,
@@ -238,8 +232,8 @@ class SharesClient(rest_client.RestClient):
             if share_status == status:
                 return
             elif 'error' in share_status.lower():
-                raise share_exceptions.\
-                    ShareBuildErrorException(share_id=share_id)
+                raise share_exceptions.ShareBuildErrorException(
+                    share_id=share_id)
 
             if int(time.time()) - start >= self.build_timeout:
                 message = ('Share %s failed to reach %s status within '
@@ -259,8 +253,8 @@ class SharesClient(rest_client.RestClient):
             body = self.get_snapshot(snapshot_id)
             snapshot_status = body['status']
             if 'error' in snapshot_status:
-                raise share_exceptions.\
-                    SnapshotBuildErrorException(snapshot_id=snapshot_id)
+                raise share_exceptions.SnapshotBuildErrorException(
+                    snapshot_id=snapshot_id)
 
             if int(time.time()) - start >= self.build_timeout:
                 message = ('Share Snapshot %s failed to reach %s status '
@@ -280,8 +274,8 @@ class SharesClient(rest_client.RestClient):
                     rule_status = rule['state']
                     break
             if 'error' in rule_status:
-                raise share_exceptions.\
-                    AccessRuleBuildErrorException(rule_id=rule_id)
+                raise share_exceptions.AccessRuleBuildErrorException(
+                    rule_id=rule_id)
 
             if int(time.time()) - start >= self.build_timeout:
                 message = ('Share Access Rule %s failed to reach %s status '
