@@ -15,36 +15,27 @@
 
 from tempest import config
 from tempest.lib import exceptions as lib_exc
-from tempest import test
+from testtools import testcase as tc
 
-from manila_tempest_tests import clients_share as clients
 from manila_tempest_tests.tests.api import base
 
 CONF = config.CONF
 
 
 @base.skip_if_microversion_not_supported("2.9")
-class ExportLocationsNegativeTest(base.BaseSharesAdminTest):
+class ExportLocationsNegativeTest(base.BaseSharesMixedTest):
 
     @classmethod
     def resource_setup(cls):
         super(ExportLocationsNegativeTest, cls).resource_setup()
-        cls.admin_client = cls.shares_v2_client
-        cls.member_client = clients.Manager().shares_v2_client
-        cls.share = cls.create_share()
-        cls.share = cls.shares_v2_client.get_share(cls.share['id'])
-        cls.share_instances = cls.shares_v2_client.get_instances_of_share(
+        cls.admin_client = cls.admin_shares_v2_client
+        cls.member_client = cls.shares_v2_client
+        cls.share = cls.create_share(client=cls.admin_client)
+        cls.share = cls.admin_client.get_share(cls.share['id'])
+        cls.share_instances = cls.admin_client.get_instances_of_share(
             cls.share['id'])
 
-    @test.attr(type=["gate", "negative"])
-    def test_get_export_locations_by_inexistent_share(self):
-        self.assertRaises(
-            lib_exc.NotFound,
-            self.admin_client.list_share_export_locations,
-            "fake-inexistent-share-id",
-        )
-
-    @test.attr(type=["gate", "negative"])
+    @tc.attr(base.TAG_NEGATIVE, base.TAG_API_WITH_BACKEND)
     def test_get_inexistent_share_export_location(self):
         self.assertRaises(
             lib_exc.NotFound,
@@ -53,15 +44,7 @@ class ExportLocationsNegativeTest(base.BaseSharesAdminTest):
             "fake-inexistent-share-instance-id",
         )
 
-    @test.attr(type=["gate", "negative"])
-    def test_get_export_locations_by_inexistent_share_instance(self):
-        self.assertRaises(
-            lib_exc.NotFound,
-            self.admin_client.list_share_instance_export_locations,
-            "fake-inexistent-share-instance-id",
-        )
-
-    @test.attr(type=["gate", "negative"])
+    @tc.attr(base.TAG_NEGATIVE, base.TAG_API_WITH_BACKEND)
     def test_get_inexistent_share_instance_export_location(self):
         for share_instance in self.share_instances:
             self.assertRaises(
@@ -71,7 +54,7 @@ class ExportLocationsNegativeTest(base.BaseSharesAdminTest):
                 "fake-inexistent-share-instance-id",
             )
 
-    @test.attr(type=["gate", "negative"])
+    @tc.attr(base.TAG_NEGATIVE, base.TAG_API_WITH_BACKEND)
     def test_list_share_instance_export_locations_by_member(self):
         for share_instance in self.share_instances:
             self.assertRaises(
@@ -80,7 +63,7 @@ class ExportLocationsNegativeTest(base.BaseSharesAdminTest):
                 "fake-inexistent-share-instance-id",
             )
 
-    @test.attr(type=["gate", "negative"])
+    @tc.attr(base.TAG_NEGATIVE, base.TAG_API_WITH_BACKEND)
     def test_get_share_instance_export_location_by_member(self):
         for share_instance in self.share_instances:
             export_locations = (
@@ -92,3 +75,23 @@ class ExportLocationsNegativeTest(base.BaseSharesAdminTest):
                     self.member_client.get_share_instance_export_location,
                     share_instance['id'], el['id'],
                 )
+
+
+@base.skip_if_microversion_not_supported("2.9")
+class ExportLocationsAPIOnlyNegativeTest(base.BaseSharesAdminTest):
+
+    @tc.attr(base.TAG_NEGATIVE, base.TAG_API)
+    def test_get_export_locations_by_nonexistent_share(self):
+        self.assertRaises(
+            lib_exc.NotFound,
+            self.shares_v2_client.list_share_export_locations,
+            "fake-inexistent-share-id",
+        )
+
+    @tc.attr(base.TAG_NEGATIVE, base.TAG_API)
+    def test_get_export_locations_by_nonexistent_share_instance(self):
+        self.assertRaises(
+            lib_exc.NotFound,
+            self.shares_v2_client.list_share_instance_export_locations,
+            "fake-inexistent-share-instance-id",
+        )
