@@ -33,27 +33,27 @@ class ShareGroupsTest(base.BaseSharesAdminTest):
     def resource_setup(cls):
         super(ShareGroupsTest, cls).resource_setup()
         # Create 2 share_types
-        cls.share_type = cls._create_share_type()
-        cls.share_type_id = cls.share_type['id']
+        name = data_utils.rand_name("tempest-manila")
+        extra_specs = cls.add_extra_specs_to_dict()
+        share_type = cls.create_share_type(name, extra_specs=extra_specs)
+        cls.share_type = share_type['share_type']
 
-        cls.share_type2 = cls._create_share_type()
-        cls.share_type_id2 = cls.share_type2['id']
+        name = data_utils.rand_name("tempest-manila")
+        share_type = cls.create_share_type(name, extra_specs=extra_specs)
+        cls.share_type2 = share_type['share_type']
 
-        # Create a share group type
-        name = data_utils.rand_name("unique_sgt_name")
         cls.sg_type = cls.create_share_group_type(
             name=name,
-            share_types=[cls.share_type_id, cls.share_type_id2],
+            share_types=[cls.share_type['id'], cls.share_type2['id']],
             cleanup_in_class=True,
             version=constants.MIN_SHARE_GROUP_MICROVERSION)
-        cls.sg_type_id = cls.sg_type['id']
 
-    @tc.attr(base.TAG_POSITIVE, base.TAG_API)
+    @tc.attr(base.TAG_POSITIVE, base.TAG_API_WITH_BACKEND)
     def test_create_share_group_with_single_share_type_min(self):
         share_group = self.create_share_group(
-            share_group_type_id=self.sg_type_id,
+            share_group_type_id=self.sg_type['id'],
             cleanup_in_class=False,
-            share_type_ids=[self.share_type_id],
+            share_type_ids=[self.share_type['id']],
             version=constants.MIN_SHARE_GROUP_MICROVERSION)
 
         keys = set(share_group.keys())
@@ -65,7 +65,7 @@ class ShareGroupsTest(base.BaseSharesAdminTest):
                 "actual": keys})
 
         actual_sg_type = share_group['share_group_type_id']
-        expected_sg_type = self.sg_type_id
+        expected_sg_type = self.sg_type['id']
         self.assertEqual(
             expected_sg_type, actual_sg_type,
             'Incorrect share group type applied to share group '
@@ -73,7 +73,7 @@ class ShareGroupsTest(base.BaseSharesAdminTest):
                 share_group['id'], expected_sg_type, actual_sg_type))
 
         actual_share_types = share_group['share_types']
-        expected_share_types = [self.share_type_id]
+        expected_share_types = [self.share_type['id']]
         self.assertEqual(
             sorted(expected_share_types),
             sorted(actual_share_types),
@@ -81,12 +81,12 @@ class ShareGroupsTest(base.BaseSharesAdminTest):
             'Expected %s, got %s' % (
                 share_group['id'], expected_share_types, actual_share_types))
 
-    @tc.attr(base.TAG_POSITIVE, base.TAG_API)
+    @tc.attr(base.TAG_POSITIVE, base.TAG_API_WITH_BACKEND)
     def test_create_share_group_with_multiple_share_types_min(self):
         share_group = self.create_share_group(
-            share_group_type_id=self.sg_type_id,
+            share_group_type_id=self.sg_type['id'],
             cleanup_in_class=False,
-            share_type_ids=[self.share_type_id, self.share_type_id2],
+            share_type_ids=[self.share_type['id'], self.share_type2['id']],
             version=constants.MIN_SHARE_GROUP_MICROVERSION)
 
         keys = set(share_group.keys())
@@ -98,7 +98,7 @@ class ShareGroupsTest(base.BaseSharesAdminTest):
                 "actual": keys})
 
         actual_sg_type = share_group['share_group_type_id']
-        expected_sg_type = self.sg_type_id
+        expected_sg_type = self.sg_type['id']
         self.assertEqual(
             expected_sg_type, actual_sg_type,
             'Incorrect share group type applied to share group %s. '
@@ -106,7 +106,7 @@ class ShareGroupsTest(base.BaseSharesAdminTest):
                 share_group['id'], expected_sg_type, actual_sg_type))
 
         actual_share_types = share_group['share_types']
-        expected_share_types = [self.share_type_id, self.share_type_id2]
+        expected_share_types = [self.share_type['id'], self.share_type2['id']]
         self.assertEqual(
             sorted(expected_share_types),
             sorted(actual_share_types),
@@ -114,7 +114,7 @@ class ShareGroupsTest(base.BaseSharesAdminTest):
             'Expected %s, got %s' % (
                 share_group['id'], expected_share_types, actual_share_types))
 
-    @tc.attr(base.TAG_POSITIVE, base.TAG_API)
+    @tc.attr(base.TAG_POSITIVE, base.TAG_API_WITH_BACKEND)
     def test_default_share_group_type_applied(self):
         default_type = self.shares_v2_client.get_default_share_group_type()
         default_share_types = default_type['share_types']
@@ -142,13 +142,13 @@ class ShareGroupsTest(base.BaseSharesAdminTest):
 
     @testtools.skipUnless(
         CONF.share.multitenancy_enabled, "Only for multitenancy.")
-    @tc.attr(base.TAG_POSITIVE, base.TAG_API)
+    @tc.attr(base.TAG_POSITIVE, base.TAG_API_WITH_BACKEND)
     def test_create_sg_from_snapshot_verify_share_server_information_min(self):
         # Create a share group
         orig_sg = self.create_share_group(
-            share_group_type_id=self.sg_type_id,
+            share_group_type_id=self.sg_type['id'],
             cleanup_in_class=False,
-            share_type_ids=[self.share_type_id],
+            share_type_ids=[self.share_type['id']],
             version=constants.MIN_SHARE_GROUP_MICROVERSION)
 
         # Get latest share group information
@@ -163,7 +163,7 @@ class ShareGroupsTest(base.BaseSharesAdminTest):
             orig_sg['id'], cleanup_in_class=False,
             version=constants.MIN_SHARE_GROUP_MICROVERSION)
         new_sg = self.create_share_group(
-            share_group_type_id=self.sg_type_id,
+            share_group_type_id=self.sg_type['id'],
             cleanup_in_class=False,
             version=constants.MIN_SHARE_GROUP_MICROVERSION,
             source_share_group_snapshot_id=sg_snapshot['id'])
@@ -173,3 +173,19 @@ class ShareGroupsTest(base.BaseSharesAdminTest):
             orig_sg['share_network_id'], new_sg['share_network_id'])
         self.assertEqual(
             orig_sg['share_server_id'], new_sg['share_server_id'])
+
+    @tc.attr(base.TAG_POSITIVE, base.TAG_API_WITH_BACKEND)
+    def test_create_sg_with_sg_type_but_without_any_group_specs(self):
+        # Create share group type not specifying any group specs
+        sg_type = self.create_share_group_type(
+            name=data_utils.rand_name("tempest-manila"),
+            share_types=[self.share_type['id']],
+            group_specs={},
+            cleanup_in_class=False)
+
+        # Create share group, it should be created always, because we do not
+        # restrict choice anyhow.
+        self.create_share_group(
+            share_type_ids=[self.share_type['id']],
+            share_group_type_id=sg_type['id'],
+            cleanup_in_class=False)
