@@ -21,18 +21,16 @@ import traceback
 from oslo_concurrency import lockutils
 from oslo_log import log
 import six
-from tempest import clients
 from tempest.common import credentials_factory as common_creds
-from tempest.common import dynamic_creds
+
 from tempest import config
+from tempest.lib.common import dynamic_creds
 from tempest.lib.common.utils import data_utils
 from tempest.lib import exceptions
 from tempest import test
 
+from manila_tempest_tests import clients
 from manila_tempest_tests.common import constants
-from manila_tempest_tests.services.share.json import shares_client
-from manila_tempest_tests.services.share.v2.json import (
-    shares_client as shares_v2_client)
 from manila_tempest_tests import share_exceptions
 from manila_tempest_tests import utils
 
@@ -90,7 +88,7 @@ class handle_cleanup_exceptions(object):
             return False  # Do not suppress error if any
         if exc_traceback:
             LOG.error("Suppressed cleanup error in Manila: "
-                      "\n%s" % traceback.format_exc())
+                      "\n%s", traceback.format_exc())
         return True  # Suppress error if any
 
 
@@ -137,6 +135,10 @@ class BaseSharesTest(test.BaseTestCase):
     # Will be cleaned up in tearDown method
     method_isolated_creds = []
 
+    # NOTE(andreaf) Override the client manager class to be used, so that
+    # a stable class is used, which includes plugin registered services as well
+    client_manager = clients.Clients
+
     def skip_if_microversion_not_supported(self, microversion):
         if not utils.is_microversion_supported(microversion):
             raise self.skipException(
@@ -151,8 +153,16 @@ class BaseSharesTest(test.BaseTestCase):
 
     @classmethod
     def _get_dynamic_creds(cls, name, network_resources=None):
+        identity_version = CONF.identity.auth_version
+        if identity_version == 'v3':
+            identity_uri = CONF.identity.uri_v3
+            identity_admin_endpoint_type = CONF.identity.v3_endpoint_type
+        elif identity_version == 'v2':
+            identity_uri = CONF.identity.uri
+            identity_admin_endpoint_type = CONF.identity.v2_admin_endpoint_type
+
         return dynamic_creds.DynamicCredentialProvider(
-            identity_version=CONF.identity.auth_version,
+            identity_version=identity_version,
             name=name,
             network_resources=network_resources,
             credentials_domain=CONF.auth.default_credentials_domain_name,
@@ -167,7 +177,9 @@ class BaseSharesTest(test.BaseTestCase):
             project_network_cidr=CONF.network.project_network_cidr,
             project_network_mask_bits=CONF.network.project_network_mask_bits,
             public_network_id=CONF.network.public_network_id,
-            resource_prefix=CONF.resources_prefix)
+            resource_prefix=CONF.resources_prefix,
+            identity_admin_endpoint_type=identity_admin_endpoint_type,
+            identity_uri=identity_uri)
 
     @classmethod
     def get_client_with_isolated_creds(cls,
@@ -201,11 +213,11 @@ class BaseSharesTest(test.BaseTestCase):
         ic.type_of_creds = type_of_creds
 
         # create client with isolated creds
-        os = clients.Manager(credentials=creds)
+        os = clients.Clients(creds)
         if client_version == '1':
-            client = shares_client.SharesClient(os.auth_provider)
+            client = os.share_v1.SharesClient()
         elif client_version == '2':
-            client = shares_v2_client.SharesV2Client(os.auth_provider)
+            client = os.share_v2.SharesV2Client()
 
         # Set place where will be deleted isolated creds
         ic_res = {
@@ -222,7 +234,7 @@ class BaseSharesTest(test.BaseTestCase):
             if (not CONF.service_available.neutron and
                     CONF.share.create_networks_when_multitenancy_enabled):
                 raise cls.skipException("Neutron support is required")
-            nc = os.networks_client
+            nc = os.network.NetworksClient()
             share_network_id = cls.provide_share_network(client, nc, ic)
             client.share_network_id = share_network_id
             resource = {
@@ -252,7 +264,16 @@ class BaseSharesTest(test.BaseTestCase):
     def setup_clients(cls):
         super(BaseSharesTest, cls).setup_clients()
         os = getattr(cls, 'os_%s' % cls.credentials[0])
-        os.shares_client = shares_client.SharesClient(os.auth_provider)
+        # Initialise share clients for test credentials
+        cls.shares_client = os.share_v1.SharesClient()
+        cls.shares_v2_client = os.share_v2.SharesV2Client()
+        # Initialise network clients for test credentials
+        if CONF.service_available.neutron:
+            cls.networks_client = os.network.NetworksClient()
+            cls.subnets_client = os.network.SubnetsClient()
+        else:
+            cls.networks_client = None
+            cls.subnets_client = None
 
         if CONF.identity.auth_version == 'v3':
             project_id = os.auth_provider.auth_data[1]['project']['id']
@@ -261,16 +282,12 @@ class BaseSharesTest(test.BaseTestCase):
         cls.tenant_id = project_id
         cls.user_id = os.auth_provider.auth_data[1]['user']['id']
 
-        cls.shares_client = os.shares_client
-        os.shares_v2_client = shares_v2_client.SharesV2Client(
-            os.auth_provider)
-        cls.shares_v2_client = os.shares_v2_client
         if CONF.share.multitenancy_enabled:
             if (not CONF.service_available.neutron and
                     CONF.share.create_networks_when_multitenancy_enabled):
                 raise cls.skipException("Neutron support is required")
             share_network_id = cls.provide_share_network(
-                cls.shares_v2_client, os.networks_client)
+                cls.shares_v2_client, cls.networks_client)
             cls.shares_client.share_network_id = share_network_id
             cls.shares_v2_client.share_network_id = share_network_id
 
@@ -597,6 +614,12 @@ class BaseSharesTest(test.BaseTestCase):
                                 group_specs=None, client=None,
                                 cleanup_in_class=True, **kwargs):
         client = client or cls.shares_v2_client
+        if (group_specs is None and
+                CONF.share.capability_sg_consistent_snapshot_support):
+            group_specs = {
+                'consistent_snapshot_support': (
+                    CONF.share.capability_sg_consistent_snapshot_support),
+            }
         share_group_type = client.create_share_group_type(
             name=name,
             share_types=share_types,
@@ -807,8 +830,6 @@ class BaseSharesTest(test.BaseTestCase):
             CONF.share.capability_snapshot_support)
         create_from_snapshot_support = six.text_type(
             CONF.share.capability_create_share_from_snapshot_support)
-        revert_to_snapshot_support = six.text_type(
-            CONF.share.capability_revert_to_snapshot_support)
 
         extra_specs_dict = {
             "driver_handles_share_servers": dhss,
@@ -817,7 +838,6 @@ class BaseSharesTest(test.BaseTestCase):
         optional = {
             "snapshot_support": snapshot_support,
             "create_share_from_snapshot_support": create_from_snapshot_support,
-            "revert_to_snapshot_support": revert_to_snapshot_support,
         }
         # NOTE(gouthamr): In micro-versions < 2.24, snapshot_support is a
         # required extra-spec
@@ -914,7 +934,7 @@ class BaseSharesTest(test.BaseTestCase):
                         client.wait_for_resource_deletion(replica_id=res_id)
                     else:
                         LOG.warning("Provided unsupported resource type for "
-                                    "cleanup '%s'. Skipping." % res["type"])
+                                    "cleanup '%s'. Skipping.", res["type"])
                 res["deleted"] = True
 
     @classmethod
@@ -998,6 +1018,25 @@ class BaseSharesTest(test.BaseTestCase):
                                     "d2value": d2value
                                 })
 
+    def create_user_message(self):
+        """Trigger a 'no valid host' situation to generate a message."""
+        extra_specs = {
+            'vendor_name': 'foobar',
+            'driver_handles_share_servers': CONF.share.multitenancy_enabled,
+        }
+        share_type_name = data_utils.rand_name("share-type")
+
+        bogus_type = self.create_share_type(
+            name=share_type_name,
+            extra_specs=extra_specs)['share_type']
+
+        params = {'share_type_id': bogus_type['id'],
+                  'share_network_id': self.shares_v2_client.share_network_id}
+        share = self.shares_v2_client.create_share(**params)
+        self.addCleanup(self.shares_v2_client.delete_share, share['id'])
+        self.shares_v2_client.wait_for_share_status(share['id'], "error")
+        return self.shares_v2_client.wait_for_message(share['id'])
+
 
 class BaseSharesAltTest(BaseSharesTest):
     """Base test case class for all Shares Alt API tests."""
@@ -1008,28 +1047,6 @@ class BaseSharesAdminTest(BaseSharesTest):
     """Base test case class for all Shares Admin API tests."""
     credentials = ('admin', )
 
-    @classmethod
-    def setup_clients(cls):
-        super(BaseSharesAdminTest, cls).setup_clients()
-        # Initialise share clients
-        cls.admin_shares_v2_client = shares_v2_client.SharesV2Client(
-            cls.os_admin.auth_provider)
-
-    @classmethod
-    def _create_share_type(cls, specs=None):
-        name = data_utils.rand_name("unique_st_name")
-        extra_specs = cls.add_extra_specs_to_dict(specs)
-        return cls.create_share_type(
-            name, extra_specs=extra_specs,
-            client=cls.admin_shares_v2_client)['share_type']
-
-    @classmethod
-    def _create_share_group_type(cls):
-        share_group_type_name = data_utils.rand_name("unique_sgtype_name")
-        return cls.create_share_group_type(
-            name=share_group_type_name, share_types=[cls.share_type_id],
-            client=cls.admin_shares_v2_client)
-
 
 class BaseSharesMixedTest(BaseSharesTest):
     """Base test case class for all Shares API tests with all user roles."""
@@ -1038,14 +1055,14 @@ class BaseSharesMixedTest(BaseSharesTest):
     @classmethod
     def setup_clients(cls):
         super(BaseSharesMixedTest, cls).setup_clients()
-        cls.admin_shares_client = shares_client.SharesClient(
-            cls.os_admin.auth_provider)
-        cls.admin_shares_v2_client = shares_v2_client.SharesV2Client(
-            cls.os_admin.auth_provider)
-        cls.alt_shares_client = shares_client.SharesClient(
-            cls.os_alt.auth_provider)
-        cls.alt_shares_v2_client = shares_v2_client.SharesV2Client(
-            cls.os_alt.auth_provider)
+        # Initialise share clients
+        cls.admin_shares_client = cls.os_admin.share_v1.SharesClient()
+        cls.admin_shares_v2_client = cls.os_admin.share_v2.SharesV2Client()
+        cls.alt_shares_client = cls.os_alt.share_v1.SharesClient()
+        cls.alt_shares_v2_client = cls.os_alt.share_v2.SharesV2Client()
+        # Initialise network clients
+        cls.os_admin.networks_client = cls.os_admin.network.NetworksClient()
+        cls.os_alt.networks_client = cls.os_alt.network.NetworksClient()
 
         if CONF.share.multitenancy_enabled:
             admin_share_network_id = cls.provide_share_network(
@@ -1058,18 +1075,3 @@ class BaseSharesMixedTest(BaseSharesTest):
                 cls.alt_shares_v2_client, cls.os_alt.networks_client)
             cls.alt_shares_client.share_network_id = alt_share_network_id
             cls.alt_shares_v2_client.share_network_id = alt_share_network_id
-
-    @classmethod
-    def _create_share_type(cls, specs=None):
-        name = data_utils.rand_name("unique_st_name")
-        extra_specs = cls.add_extra_specs_to_dict(specs)
-        return cls.create_share_type(
-            name, extra_specs=extra_specs,
-            client=cls.admin_shares_v2_client)['share_type']
-
-    @classmethod
-    def _create_share_group_type(cls):
-        share_group_type_name = data_utils.rand_name("unique_sgtype_name")
-        return cls.create_share_group_type(
-            name=share_group_type_name, share_types=[cls.share_type_id],
-            client=cls.admin_shares_v2_client)
