@@ -13,20 +13,20 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from tempest.lib import exceptions as lib_exc  # noqa
-from tempest import test  # noqa
+from tempest.lib import exceptions as lib_exc
+from testtools import testcase as tc
 
 from manila_tempest_tests.tests.api import base
 
 
 class SchedulerStatsNegativeTest(base.BaseSharesTest):
 
-    @test.attr(type=["gate", "smoke", "negative", ])
+    @tc.attr(base.TAG_NEGATIVE, base.TAG_API)
     def test_try_list_pools_with_user(self):
         self.assertRaises(lib_exc.Forbidden,
                           self.shares_client.list_pools)
 
-    @test.attr(type=["gate", "smoke", "negative", ])
+    @tc.attr(base.TAG_NEGATIVE, base.TAG_API)
     def test_try_list_pools_detailed_with_user(self):
         self.assertRaises(lib_exc.Forbidden,
                           self.shares_client.list_pools,
