@@ -26,14 +26,7 @@ CONF = config.CONF
 LOG = log.getLogger(__name__)
 
 
-class SecurityServicesNegativeTest(base.BaseSharesMixedTest):
-
-    @classmethod
-    def resource_setup(cls):
-        super(SecurityServicesNegativeTest, cls).resource_setup()
-        # create share_type
-        cls.share_type = cls._create_share_type()
-        cls.share_type_id = cls.share_type['id']
+class SecurityServicesNegativeTest(base.BaseSharesTest):
 
     @tc.attr(base.TAG_NEGATIVE, base.TAG_API)
     def test_try_create_security_service_with_empty_type(self):
@@ -88,7 +81,7 @@ class SecurityServicesNegativeTest(base.BaseSharesMixedTest):
         ss = self.create_security_service(**ss_data)
 
         sn = self.shares_client.get_share_network(
-            self.os.shares_client.share_network_id)
+            self.shares_client.share_network_id)
         fresh_sn = self.create_share_network(
             neutron_net_id=sn["neutron_net_id"],
             neutron_subnet_id=sn["neutron_subnet_id"])
@@ -100,16 +93,15 @@ class SecurityServicesNegativeTest(base.BaseSharesMixedTest):
         # that fails on wrong data, we expect error here.
         # We require any share that uses our share-network.
         try:
-            self.create_share(share_type_id=self.share_type_id,
-                              share_network_id=fresh_sn["id"],
-                              cleanup_in_class=False)
+            self.create_share(
+                share_network_id=fresh_sn["id"], cleanup_in_class=False)
         except Exception as e:
             # we do wait for either 'error' or 'available' status because
             # it is the only available statuses for proper deletion.
             LOG.warning("Caught exception. It is expected in case backend "
                         "fails having security-service with improper data "
                         "that leads to share-server creation error. "
-                        "%s" % six.text_type(e))
+                        "%s", six.text_type(e))
 
         self.assertRaises(lib_exc.Forbidden,
                           self.shares_client.update_security_service,
@@ -128,3 +120,9 @@ class SecurityServicesNegativeTest(base.BaseSharesMixedTest):
         self.assertRaises(lib_exc.NotFound,
                           self.shares_client.get_security_service,
                           ss["id"])
+
+    @tc.attr(base.TAG_NEGATIVE, base.TAG_API)
+    def test_try_list_security_services_all_tenants(self):
+        self.assertRaises(lib_exc.Forbidden,
+                          self.shares_client.list_security_services,
+                          params={'all_tenants': 1})
