@@ -13,19 +13,20 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import six  # noqa
-from tempest import config  # noqa
-from tempest import test  # noqa
-import testtools  # noqa
+from tempest import config
+import testtools
+from testtools import testcase as tc
 
 from manila_tempest_tests.tests.api import base
+from manila_tempest_tests import utils
 
 CONF = config.CONF
 
 
 class ShareNetworkListMixin(object):
 
-    @test.attr(type=["gate", "smoke", ])
+    @tc.attr("gate", "smoke", )
+    @tc.attr(base.TAG_POSITIVE, base.TAG_API)
     def test_list_share_networks(self):
         listed = self.shares_client.list_share_networks()
         any(self.sn_with_ldap_ss["id"] in sn["id"] for sn in listed)
@@ -34,9 +35,9 @@ class ShareNetworkListMixin(object):
         keys = ["name", "id"]
         [self.assertIn(key, sn.keys()) for sn in listed for key in keys]
 
-    @test.attr(type=["gate", "smoke", ])
+    @tc.attr(base.TAG_POSITIVE, base.TAG_API)
     def test_list_share_networks_with_detail(self):
-        listed = self.shares_client.list_share_networks_with_detail()
+        listed = self.shares_v2_client.list_share_networks_with_detail()
         any(self.sn_with_ldap_ss["id"] in sn["id"] for sn in listed)
 
         # verify keys
@@ -46,9 +47,18 @@ class ShareNetworkListMixin(object):
             "neutron_net_id", "neutron_subnet_id",
             "created_at", "updated_at", "segmentation_id",
         ]
+
+        # In v2.18 and beyond, we expect gateway.
+        if utils.is_microversion_supported('2.18'):
+            keys.append('gateway')
+
+        # In v2.20 and beyond, we expect mtu.
+        if utils.is_microversion_supported('2.20'):
+            keys.append('mtu')
+
         [self.assertIn(key, sn.keys()) for sn in listed for key in keys]
 
-    @test.attr(type=["gate", "smoke", ])
+    @tc.attr(base.TAG_POSITIVE, base.TAG_API)
     def test_list_share_networks_filter_by_ss(self):
         listed = self.shares_client.list_share_networks_with_detail(
             {'security_service_id': self.ss_ldap['id']})
@@ -60,7 +70,23 @@ class ShareNetworkListMixin(object):
             self.assertTrue(any(ss['id'] == self.ss_ldap['id']
                                 for ss in ss_list))
 
-    @test.attr(type=["gate", "smoke", ])
+    @tc.attr(base.TAG_POSITIVE, base.TAG_API)
+    @base.skip_if_microversion_lt("2.36")
+    def test_list_share_networks_like_filter(self):
+        valid_filter_opts = {
+            'name': 'sn_with_ldap_ss',
+            'description': 'fake',
+        }
+
+        listed = self.shares_v2_client.list_share_networks_with_detail(
+            {'name~': 'ldap_ss', 'description~': 'fa'})
+        self.assertTrue(any(self.sn_with_ldap_ss['id'] == sn['id']
+                            for sn in listed))
+        for sn in listed:
+            self.assertTrue(all(value in sn[key] for key, value in
+                                valid_filter_opts.items()))
+
+    @tc.attr(base.TAG_POSITIVE, base.TAG_API)
     def test_list_share_networks_all_filter_opts(self):
         valid_filter_opts = {
             'created_before': '2002-10-10',
@@ -82,9 +108,9 @@ class ShareNetworkListMixin(object):
         created_since = valid_filter_opts.pop('created_since')
         for sn in listed:
             self.assertTrue(all(sn[key] == value for key, value in
-                                six.iteritems(valid_filter_opts)))
-            self.assertTrue(sn['created_at'] <= created_before)
-            self.assertTrue(sn['created_at'] >= created_since)
+                                valid_filter_opts.items()))
+            self.assertLessEqual(sn['created_at'], created_before)
+            self.assertGreaterEqual(sn['created_at'], created_since)
 
 
 class ShareNetworksTest(base.BaseSharesTest, ShareNetworkListMixin):
@@ -140,7 +166,7 @@ class ShareNetworksTest(base.BaseSharesTest, ShareNetworkListMixin):
             cls.sn_with_kerberos_ss["id"],
             cls.ss_kerberos["id"])
 
-    @test.attr(type=["gate", "smoke", ])
+    @tc.attr(base.TAG_POSITIVE, base.TAG_API)
     def test_create_delete_share_network(self):
         # generate data for share network
         data = self.generate_share_network_data()
@@ -152,7 +178,7 @@ class ShareNetworksTest(base.BaseSharesTest, ShareNetworkListMixin):
         # Delete share_network
         self.shares_client.delete_share_network(created["id"])
 
-    @test.attr(type=["gate", "smoke", ])
+    @tc.attr(base.TAG_POSITIVE, base.TAG_API)
     def test_get_share_network(self):
         get = self.shares_client.get_share_network(self.sn_with_ldap_ss["id"])
         self.assertEqual('2002-02-02T00:00:00.000000', get['created_at'])
@@ -160,7 +186,7 @@ class ShareNetworksTest(base.BaseSharesTest, ShareNetworkListMixin):
         del data['created_at']
         self.assertDictContainsSubset(data, get)
 
-    @test.attr(type=["gate", "smoke", ])
+    @tc.attr(base.TAG_POSITIVE, base.TAG_API)
     def test_update_share_network(self):
         update_data = self.generate_share_network_data()
         updated = self.shares_client.update_share_network(
@@ -168,7 +194,7 @@ class ShareNetworksTest(base.BaseSharesTest, ShareNetworkListMixin):
             **update_data)
         self.assertDictContainsSubset(update_data, updated)
 
-    @test.attr(type=["gate", "smoke"])
+    @tc.attr(base.TAG_POSITIVE, base.TAG_API_WITH_BACKEND)
     @testtools.skipIf(
         not CONF.share.multitenancy_enabled, "Only for multitenancy.")
     def test_update_valid_keys_sh_server_exists(self):
@@ -181,7 +207,7 @@ class ShareNetworksTest(base.BaseSharesTest, ShareNetworkListMixin):
             self.shares_client.share_network_id, **update_dict)
         self.assertDictContainsSubset(update_dict, updated)
 
-    @test.attr(type=["gate", "smoke", ])
+    @tc.attr(base.TAG_POSITIVE, base.TAG_API)
     def test_recreate_share_network(self):
         # generate data for share network
         data = self.generate_share_network_data()
@@ -200,7 +226,7 @@ class ShareNetworksTest(base.BaseSharesTest, ShareNetworkListMixin):
         # Delete second share network
         self.shares_client.delete_share_network(sn2["id"])
 
-    @test.attr(type=["gate", "smoke", ])
+    @tc.attr(base.TAG_POSITIVE, base.TAG_API)
     def test_create_two_share_networks_with_same_net_and_subnet(self):
         # generate data for share network
         data = self.generate_share_network_data()
@@ -212,3 +238,41 @@ class ShareNetworksTest(base.BaseSharesTest, ShareNetworkListMixin):
         # create second share network
         sn2 = self.create_share_network(**data)
         self.assertDictContainsSubset(data, sn2)
+
+    @testtools.skipUnless(CONF.share.create_networks_when_multitenancy_enabled,
+                          "Only for setups with network creation.")
+    @testtools.skipUnless(CONF.share.multitenancy_enabled,
+                          "Only for multitenancy.")
+    @testtools.skipUnless(CONF.service_available.neutron, "Only with neutron.")
+    @base.skip_if_microversion_lt("2.18")
+    @tc.attr(base.TAG_POSITIVE, base.TAG_API_WITH_BACKEND)
+    def test_gateway_with_neutron(self):
+        subnet_client = self.subnets_client
+
+        self.create_share(cleanup_in_class=False)
+        share_net_details = self.shares_v2_client.get_share_network(
+            self.shares_v2_client.share_network_id)
+        subnet_details = subnet_client.show_subnet(
+            share_net_details['neutron_subnet_id'])
+
+        self.assertEqual(subnet_details['subnet']['gateway_ip'],
+                         share_net_details['gateway'])
+
+    @testtools.skipUnless(CONF.share.create_networks_when_multitenancy_enabled,
+                          "Only for setups with network creation.")
+    @testtools.skipUnless(CONF.share.multitenancy_enabled,
+                          "Only for multitenancy.")
+    @testtools.skipUnless(CONF.service_available.neutron, "Only with neutron.")
+    @base.skip_if_microversion_lt("2.20")
+    @tc.attr(base.TAG_POSITIVE, base.TAG_API_WITH_BACKEND)
+    def test_mtu_with_neutron(self):
+        network_client = self.networks_client
+
+        self.create_share(cleanup_in_class=False)
+        share_net_details = self.shares_v2_client.get_share_network(
+            self.shares_v2_client.share_network_id)
+        network_details = network_client.show_network(
+            share_net_details['neutron_net_id'])
+
+        self.assertEqual(network_details['network']['mtu'],
+                         share_net_details['mtu'])
