@@ -29,7 +29,7 @@ LATEST_MICROVERSION = CONF.share.max_api_microversion
 
 
 @ddt.ddt
-class SharesActionsTest(base.BaseSharesMixedTest):
+class SharesActionsTest(base.BaseSharesTest):
     """Covers share functionality, that doesn't related to share type."""
 
     @classmethod
@@ -38,10 +38,6 @@ class SharesActionsTest(base.BaseSharesMixedTest):
 
         cls.shares = []
 
-        # create share_type
-        cls.share_type = cls._create_share_type()
-        cls.share_type_id = cls.share_type['id']
-
         # create share
         cls.share_name = data_utils.rand_name("tempest-share-name")
         cls.share_desc = data_utils.rand_name("tempest-share-description")
@@ -53,7 +49,6 @@ class SharesActionsTest(base.BaseSharesMixedTest):
             name=cls.share_name,
             description=cls.share_desc,
             metadata=cls.metadata,
-            share_type_id=cls.share_type_id,
         ))
 
         if CONF.share.run_snapshot_tests:
@@ -120,9 +115,9 @@ class SharesActionsTest(base.BaseSharesMixedTest):
                                                           share["name"])
         self.assertEqual(self.share_name, six.text_type(share["name"]), msg)
 
-        msg = "Expected description: '%s', "\
-              "actual description: '%s'" % (self.share_desc,
-                                            share["description"])
+        msg = ("Expected description: '%s', "
+               "actual description: '%s'" % (self.share_desc,
+                                             share["description"]))
         self.assertEqual(
             self.share_desc, six.text_type(share["description"]), msg)
 
@@ -341,6 +336,23 @@ class SharesActionsTest(base.BaseSharesMixedTest):
         shares = self.shares_client.list_shares_with_detail(params)
         self.assertEqual(self.share_name, shares[0]["name"])
 
+    @tc.attr(base.TAG_POSITIVE, base.TAG_API_WITH_BACKEND)
+    @base.skip_if_microversion_lt("2.36")
+    def test_list_shares_with_detail_filter_by_existed_description(self):
+        # list shares by description, at least one share is expected
+        params = {"description": self.share_desc}
+        shares = self.shares_v2_client.list_shares_with_detail(params)
+        self.assertEqual(self.share_name, shares[0]["name"])
+
+    @tc.attr(base.TAG_POSITIVE, base.TAG_API_WITH_BACKEND)
+    @base.skip_if_microversion_lt("2.36")
+    def test_list_shares_with_detail_filter_by_inexact_name(self):
+        # list shares by name, at least one share is expected
+        params = {"name~": 'tempest-share'}
+        shares = self.shares_v2_client.list_shares_with_detail(params)
+        for share in shares:
+            self.assertIn('tempest-share', share["name"])
+
     @tc.attr(base.TAG_POSITIVE, base.TAG_API_WITH_BACKEND)
     def test_list_shares_with_detail_filter_by_fake_name(self):
         # list shares by fake name, no shares are expected
@@ -382,14 +394,12 @@ class SharesActionsTest(base.BaseSharesMixedTest):
         public_share = self.create_share(
             name='public_share',
             description='public_share_desc',
-            share_type_id=self.share_type_id,
             is_public=True,
             cleanup_in_class=False
         )
         private_share = self.create_share(
             name='private_share',
             description='private_share_desc',
-            share_type_id=self.share_type_id,
             is_public=False,
             cleanup_in_class=False
         )
@@ -488,16 +498,18 @@ class SharesActionsTest(base.BaseSharesMixedTest):
     @tc.attr(base.TAG_POSITIVE, base.TAG_API_WITH_BACKEND)
     @testtools.skipUnless(CONF.share.run_snapshot_tests,
                           "Snapshot tests are disabled.")
-    @ddt.data(None, '2.16', LATEST_MICROVERSION)
+    @ddt.data(None, '2.16', '2.36', LATEST_MICROVERSION)
     def test_list_snapshots_with_detail(self, version):
-
+        params = None
+        if version and utils.is_microversion_ge(version, '2.36'):
+            params = {'name~': 'tempest', 'description~': 'tempest'}
         # list share snapshots
         if version is None:
             snaps = self.shares_client.list_snapshots_with_detail()
         else:
             utils.skip_if_microversion_not_supported(version)
             snaps = self.shares_v2_client.list_snapshots_with_detail(
-                version=version)
+                version=version, params=params)
 
         # verify keys
         expected_keys = ["status", "links", "share_id", "name",
@@ -556,6 +568,22 @@ class SharesActionsTest(base.BaseSharesMixedTest):
             self.assertEqual(filters['status'], snap['status'])
             self.assertEqual(filters['name'], snap['name'])
 
+    @tc.attr(base.TAG_POSITIVE, base.TAG_API_WITH_BACKEND)
+    @testtools.skipUnless(CONF.share.run_snapshot_tests,
+                          "Snapshot tests are disabled.")
+    @base.skip_if_microversion_not_supported("2.35")
+    def test_list_snapshots_with_detail_filter_by_description(self):
+        filters = {'description': self.snap_desc}
+
+        # list snapshots
+        snaps = self.shares_client.list_snapshots_with_detail(
+            params=filters)
+
+        # verify response
+        self.assertGreater(len(snaps), 0)
+        for snap in snaps:
+            self.assertEqual(filters['description'], snap['description'])
+
     @tc.attr(base.TAG_POSITIVE, base.TAG_API_WITH_BACKEND)
     @testtools.skipUnless(CONF.share.run_snapshot_tests,
                           "Snapshot tests are disabled.")
@@ -576,8 +604,7 @@ class SharesActionsTest(base.BaseSharesMixedTest):
         CONF.share.run_extend_tests,
         "Share extend tests are disabled.")
     def test_extend_share(self):
-        share = self.create_share(share_type_id=self.share_type_id,
-                                  cleanup_in_class=False)
+        share = self.create_share(cleanup_in_class=False)
         new_size = int(share['size']) + 1
 
         # extend share and wait for active status
@@ -601,9 +628,7 @@ class SharesActionsTest(base.BaseSharesMixedTest):
         "Share shrink tests are disabled.")
     def test_shrink_share(self):
         size = CONF.share.share_size + 1
-        share = self.create_share(size=size,
-                                  share_type_id=self.share_type_id,
-                                  cleanup_in_class=False)
+        share = self.create_share(size=size, cleanup_in_class=False)
         new_size = int(share['size']) - 1
 
         # shrink share and wait for active status
@@ -622,23 +647,17 @@ class SharesActionsTest(base.BaseSharesMixedTest):
         self.assertEqual(new_size, share_get['size'], msg)
 
 
-class SharesRenameTest(base.BaseSharesMixedTest):
+class SharesRenameTest(base.BaseSharesTest):
 
     @classmethod
     def resource_setup(cls):
         super(SharesRenameTest, cls).resource_setup()
 
-        # create share_type
-        cls.share_type = cls._create_share_type()
-        cls.share_type_id = cls.share_type['id']
-
         # create share
         cls.share_name = data_utils.rand_name("tempest-share-name")
         cls.share_desc = data_utils.rand_name("tempest-share-description")
         cls.share = cls.create_share(
-            name=cls.share_name,
-            description=cls.share_desc,
-            share_type_id=cls.share_type_id)
+            name=cls.share_name, description=cls.share_desc)
 
         if CONF.share.run_snapshot_tests:
             # create snapshot
