@@ -18,13 +18,10 @@ import six
 
 from tempest import config
 from tempest.lib.common.utils import data_utils
-from tempest.scenario import manager
 
 from manila_tempest_tests.common import constants
 from manila_tempest_tests.common import remote_client
-from manila_tempest_tests.services.share.json import shares_client
-from manila_tempest_tests.services.share.v2.json import (
-    shares_client as shares_v2_client)
+from manila_tempest_tests.tests.scenario import manager
 
 CONF = config.CONF
 LOG = log.getLogger(__name__)
@@ -41,14 +38,10 @@ class ShareScenarioTest(manager.NetworkScenarioTest):
         super(ShareScenarioTest, cls).resource_setup()
 
         # Manila clients
-        cls.shares_client = shares_client.SharesClient(
-            cls.os_primary.auth_provider)
-        cls.shares_v2_client = shares_v2_client.SharesV2Client(
-            cls.os_primary.auth_provider)
-        cls.shares_admin_client = shares_client.SharesClient(
-            cls.os_admin.auth_provider)
-        cls.shares_admin_v2_client = shares_v2_client.SharesV2Client(
-            cls.os_admin.auth_provider)
+        cls.shares_client = cls.os_primary.share_v1.SharesClient()
+        cls.shares_v2_client = cls.os_primary.share_v2.SharesV2Client()
+        cls.shares_admin_client = cls.os_admin.share_v1.SharesClient()
+        cls.shares_admin_v2_client = cls.os_admin.share_v2.SharesV2Client()
 
     @classmethod
     def skip_checks(cls):
@@ -212,7 +205,8 @@ class ShareScenarioTest(manager.NetworkScenarioTest):
         if isinstance(server_or_ip, six.string_types):
             ip = server_or_ip
         else:
-            addr = server_or_ip['addresses'][CONF.compute.network_for_ssh][0]
+            addr = server_or_ip['addresses'][
+                CONF.validation.network_for_ssh][0]
             ip = addr['addr']
 
         # NOTE(u_glide): Both options (pkey and password) are required here to
@@ -227,7 +221,7 @@ class ShareScenarioTest(manager.NetworkScenarioTest):
         try:
             linux_client.validate_authentication()
         except Exception:
-            LOG.exception('Initializing SSH connection to %s failed' % ip)
+            LOG.exception('Initializing SSH connection to %s failed', ip)
             self._log_console_output()
             raise
 
