@@ -23,9 +23,9 @@ show_diff () {
     diff -U 0 $1 $2 | sed 1,2d
 }
 
-# Stash uncommited changes, checkout master and save coverage report
-uncommited=$(git status --porcelain | grep -v "^??")
-[[ -n $uncommited ]] && git stash > /dev/null
+# Stash uncommitted changes, checkout master and save coverage report
+uncommitted=$(git status --porcelain | grep -v "^??")
+[[ -n $uncommitted ]] && git stash > /dev/null
 git checkout HEAD^
 
 baseline_report=$(mktemp -t manila_coverageXXXXXXX)
@@ -33,9 +33,9 @@ find . -type f -name "*.pyc" -delete && python setup.py testr --coverage --testr
 coverage report --ignore-errors > $baseline_report
 baseline_missing=$(awk 'END { print $3 }' $baseline_report)
 
-# Checkout back and unstash uncommited changes (if any)
+# Checkout back and unstash uncommitted changes (if any)
 git checkout -
-[[ -n $uncommited ]] && git stash pop > /dev/null
+[[ -n $uncommitted ]] && git stash pop > /dev/null
 
 # Generate and save coverage report
 current_report=$(mktemp -t manila_coverageXXXXXXX)
